@@ -121,8 +121,8 @@ do iscl=1,maxscl
     fr2(ir)=sum*ri(ir)
     rho(ir)=(1.d0/fourpi)*sum*ri(ir)**2
   end do
-  call fderiv(-1,nr,r,fr1,gr1)
-  call fderiv(-1,nr,r,fr2,gr2)
+  call splintp(nr,r,fr1,gr1)
+  call splintp(nr,r,fr2,gr2)
 ! find the Hartree potential
   t1=gr2(nr)
   do ir=1,nr
