@@ -9,6 +9,7 @@
 subroutine bandstr
 ! !USES:
 use modmain
+use modomp
 ! !DESCRIPTION:
 !   Produces a band structure along the path in reciprocal space which connects
 !   the vertices in the array {\tt vvlp1d}. The band structure is obtained from
@@ -26,7 +27,7 @@ use modmain
 implicit none
 ! local variables
 integer ik,ist,ispn,is,ia,ias
-integer lmax,lmmax,l,m,lm,iv
+integer lmax,lmmax,l,m,lm,iv,nthd
 real(8) emin,emax,sum
 character(256) fname
 ! allocatable arrays
@@ -48,44 +49,42 @@ if (task.eq.21) then
 end if
 ! read density and potentials from file
 call readstate
+! Fourier transform Kohn-Sham potential to G-space
+call genvsig
 ! read Fermi energy from file
 call readfermi
 ! find the new linearisation energies
 call linengy
-! generate the APW radial functions
-call genapwfr
-! generate the local-orbital radial functions
-call genlofr
-! compute the overlap radial integrals
-call olprad
-! compute the Hamiltonian radial integrals
-call hmlrad
+! generate the APW and local-orbital radial functions and integrals
+call genapwlofr
 ! generate the spin-orbit coupling radial functions
 call gensocfr
 emin=1.d5
 emax=-1.d5
 ! begin parallel loop over k-points
+call omp_hold(nkpt,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(evalfv,evecfv,evecsv) &
 !$OMP PRIVATE(ist,dmat,apwalm,ispn) &
-!$OMP PRIVATE(ias,l,m,lm,sum)
+!$OMP PRIVATE(ias,l,m,lm,sum) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ik=1,nkpt
   allocate(evalfv(nstfv,nspnfv))
   allocate(evecfv(nmatmax,nstfv,nspnfv))
   allocate(evecsv(nstsv,nstsv))
-!$OMP CRITICAL
+!$OMP CRITICAL(bandstr_1)
   write(*,'("Info(bandstr): ",I6," of ",I6," k-points")') ik,nkpt
-!$OMP END CRITICAL
+!$OMP END CRITICAL(bandstr_1)
 ! solve the first- and second-variational eigenvalue equations
   call eveqn(ik,evalfv,evecfv,evecsv)
   do ist=1,nstsv
 ! subtract the Fermi energy
     e(ist,ik)=evalsv(ist,ik)-efermi
-!$OMP CRITICAL
+!$OMP CRITICAL(bandstr_2)
     emin=min(emin,e(ist,ik))
     emax=max(emax,e(ist,ik))
-!$OMP END CRITICAL
+!$OMP END CRITICAL(bandstr_2)
   end do
 ! compute the band characters if required
   if (task.eq.21) then
@@ -121,11 +120,12 @@ do ik=1,nkpt
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 emax=emax+(emax-emin)*0.5d0
 emin=emin-(emax-emin)*0.5d0
 ! output the band structure
 if (task.eq.20) then
-  open(50,file='BAND.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='BAND.OUT',form='FORMATTED')
   do ist=1,nstsv
     do ik=1,nkpt
       write(50,'(2G18.10)') dpp1d(ik),e(ist,ik)
@@ -141,7 +141,7 @@ else
     do ia=1,natoms(is)
       ias=idxas(ia,is)
       write(fname,'("BAND_S",I2.2,"_A",I4.4,".OUT")') is,ia
-      open(50,file=trim(fname),action='WRITE',form='FORMATTED')
+      open(50,file=trim(fname),form='FORMATTED')
       do ist=1,nstsv
         do ik=1,nkpt
 ! sum band character over l
@@ -160,12 +160,12 @@ else
   write(*,*)
   write(*,'("Info(bandstr):")')
   write(*,'(" band structure plot written to BAND_Sss_Aaaaa.OUT")')
-  write(*,'("  for all species and atoms")')
+  write(*,'(" for all species and atoms")')
 end if
 write(*,*)
 write(*,'(" Fermi energy is at zero in plot")')
 ! output the vertex location lines
-open(50,file='BANDLINES.OUT',action='WRITE',form='FORMATTED')
+open(50,file='BANDLINES.OUT',form='FORMATTED')
 do iv=1,nvp1d
   write(50,'(2G18.10)') dvp1d(iv),emin
   write(50,'(2G18.10)') dvp1d(iv),emax
@@ -179,3 +179,4 @@ if (task.eq.21) deallocate(bc)
 return
 end subroutine
 !EOC
+
