@@ -49,8 +49,8 @@ do idm=1,3
 end do
 select case(task)
 case(91)
-  open(50,file='DBXC1D.OUT',action='WRITE',form='FORMATTED')
-  open(51,file='DBXCLINES.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='DBXC1D.OUT',form='FORMATTED')
+  open(51,file='DBXCLINES.OUT',form='FORMATTED')
   call plot1d(50,51,1,rfmt,rfir)
   close(50)
   close(51)
@@ -60,14 +60,14 @@ case(91)
    &DBXC1D.OUT")')
   write(*,'(" vertex location lines written to DBXCLINES.OUT")')
 case(92)
-  open(50,file='DBXC2D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='DBXC2D.OUT',form='FORMATTED')
   call plot2d(50,1,rfmt,rfir)
   close(50)
   write(*,'("Info(dbxcplot):")')
   write(*,'(" 2D divergence of exchange-correlation field written to &
    &DBXC2D.OUT")')
 case(93)
-  open(50,file='DBXC3D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='DBXC3D.OUT',form='FORMATTED')
   call plot3d(50,1,rfmt,rfir)
   close(50)
   write(*,'("Info(dbxcplot):")')
