@@ -18,12 +18,14 @@ use modmain
 !EOP
 !BOC
 implicit none
+! local variables
+integer iostat
 ! delete the first-variational eigenvector file
-open(70,file=trim(scrpath)//'EVECFV'//trim(filext))
-close(70,status='DELETE')
+open(122,file=trim(scrpath)//'EVECFV'//trim(filext),iostat=iostat)
+close(122,status='DELETE')
 ! delete the second-variational eigenvector file
-open(70,file=trim(scrpath)//'EVECSV'//trim(filext))
-close(70,status='DELETE')
+open(126,file=trim(scrpath)//'EVECSV'//trim(filext),iostat=iostat)
+close(126,status='DELETE')
 return
 end subroutine
 !EOC
