@@ -6,16 +6,14 @@
 subroutine dforce(dyn)
 use modmain
 use modphonon
+use modomp
 implicit none
 ! arguments
 complex(8), intent(out) :: dyn(3,natmtot)
 ! local variables
-integer ik,is,ias
-integer nr,nri,ir
-integer np,igq0,i
-complex(8) zrho0,zsum,z1
-! automatic arrays
-real(8) vn(nrmtmax)
+integer ik,is,ias,nthd
+integer nr,nri,ir,np,i
+complex(8) zsum,z1
 ! allocatable arrays
 complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
 complex(8), allocatable :: grhomt(:,:,:),grhoir(:,:)
@@ -23,9 +21,8 @@ complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 complex(8), allocatable :: gvclmt(:,:,:),gvclir(:,:)
 complex(8), allocatable :: zfmt(:),gzfmt(:,:)
 ! external functions
-real(8) fintgt
-complex(8) zfinp,zfmtinp
-external fintgt,zfinp,zfmtinp
+complex(8) zfmtinp
+external zfmtinp
 allocate(zrhomt(npmtmax,natmtot),zrhoir(ngtot))
 allocate(grhomt(npmtmax,natmtot,3),grhoir(ngtot,3))
 allocate(zvclmt(npmtmax,natmtot),zvclir(ngtot))
@@ -42,26 +39,19 @@ call gradzf(zrhomt,zrhoir,grhomt,grhoir)
 !--------------------------------------------------------------!
 !     Hellmann-Feynman force derivative for displaced atom     !
 !--------------------------------------------------------------!
-if (tphq0) then
-  igq0=1
-else
-  igq0=0
-end if
 nr=nrmt(isph)
 nri=nrmti(isph)
 np=npmt(isph)
 ! zero the interstitial density
 zrhoir(:)=0.d0
-! compute the gradient of the nuclear potential
-call potnucl(.false.,nr,rsp(:,isph),spzn(isph),vn)
 zfmt(1:np)=0.d0
 i=1
 do ir=1,nri
-  zfmt(i)=vn(ir)/y00
+  zfmt(i)=vcln(ir,isph)
   i=i+lmmaxi
 end do
 do ir=nri+1,nr
-  zfmt(i)=vn(ir)/y00
+  zfmt(i)=vcln(ir,isph)
   i=i+lmmaxo
 end do
 call gradzfmt(nr,nri,rsp(:,isph),zfmt,npmtmax,gzfmt)
@@ -69,8 +59,8 @@ call gradzfmt(nr,nri,rsp(:,isph),zfmt,npmtmax,gzfmt)
 zvclmt(:,:)=0.d0
 zvclmt(1:np,iasph)=gzfmt(1:np,ipph)
 tphdyn=.true.
-call zpotcoul(nrmt,nrmti,npmt,npmti,nrspmax,rsp,igq0,gqc,jlgqr,ylmgq,sfacgq, &
- zrhoir,npmtmax,zvclmt,zvclir,zrho0)
+call zpotcoul(nrmt,nrmti,npmt,npmti,nrspmax,rsp,ngridg,igfft,ngvec,gqc,gclgq, &
+ ngvec,jlgqrmt,ylmgq,sfacgq,zrhoir,npmtmax,zvclmt,zvclir)
 zfmt(1:np)=zvnmt(1:np)
 ! multiply with density derivative and integrate
 zsum=0.d0
@@ -87,8 +77,8 @@ dyn(ipph,iasph)=-zsum
 ! compute the lattice-periodic nuclear Coulomb potential derivative
 zvclmt(:,:)=0.d0
 zvclmt(1:np,iasph)=gzfmt(1:np,ipph)
-call zpotcoul(nrmt,nrmti,npmt,npmti,nrspmax,rsp,1,gc,jlgr,ylmg,sfacg,zrhoir, &
- npmtmax,zvclmt,zvclir,zrho0)
+call zpotcoul(nrmt,nrmti,npmt,npmti,nrspmax,rsp,ngridg,igfft,ngvec,gc,gclg, &
+ ngvec,jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
 tphdyn=.false.
 ! multiply with density gradient and integrate
 zsum=0.d0
@@ -135,13 +125,16 @@ end do
 !     IBS correction to force derivative     !
 !--------------------------------------------!
 ! k-point dependent part
-!$OMP PARALLEL DEFAULT(SHARED)
+call omp_hold(nkptnr,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ik=1,nkptnr
   call dforcek(ik,dyn)
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 ! k-point independent part
 do ias=1,natmtot
   is=idxis(ias)
