@@ -16,8 +16,8 @@ real(8) t1,t2
 ! automatic arrays
 real(8) fr1(nrmtmax),fr2(nrmtmax)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 ! begin loops over atoms and species
 do ias=1,natmtot
   is=idxis(ias)
@@ -29,9 +29,9 @@ do ias=1,natmtot
 !---------------------------!
 !     APW-APW integrals     !
 !---------------------------!
-  do l1=0,lmaxmat
+  do l1=0,lmaxapw
     do io=1,apword(l1,is)
-      do l3=0,lmaxmat
+      do l3=0,lmaxapw
         do jo=1,apword(l3,is)
           lm2=0
           do l2=0,lmaxi
@@ -50,8 +50,8 @@ do ias=1,natmtot
                 fr2(ir)=t1*aimag(dvsmt(i,ias))
                 i=i+lmmaxo
               end do
-              t1=fintgt(-1,nr,rsp(:,is),fr1)
-              t2=fintgt(-1,nr,rsp(:,is),fr2)
+              t1=splint(nr,rsp(:,is),fr1)
+              t2=splint(nr,rsp(:,is),fr2)
               dhaa(lm2,jo,l3,io,l1,ias)=cmplx(t1,t2,8)
             end do
           end do
@@ -65,8 +65,8 @@ do ias=1,natmtot
                 fr2(ir)=t1*aimag(dvsmt(i,ias))
                 i=i+lmmaxo
               end do
-              t1=fintgt(-1,nro,rsp(iro,is),fr1(iro))
-              t2=fintgt(-1,nro,rsp(iro,is),fr2(iro))
+              t1=splint(nro,rsp(iro,is),fr1(iro))
+              t2=splint(nro,rsp(iro,is),fr2(iro))
               dhaa(lm2,jo,l3,io,l1,ias)=cmplx(t1,t2,8)
             end do
           end do
@@ -79,7 +79,7 @@ do ias=1,natmtot
 !-------------------------------------!
   do ilo=1,nlorb(is)
     l1=lorbl(ilo,is)
-    do l3=0,lmaxmat
+    do l3=0,lmaxapw
       do io=1,apword(l3,is)
         lm2=0
         do l2=0,lmaxi
@@ -98,8 +98,8 @@ do ias=1,natmtot
               fr2(ir)=t1*aimag(dvsmt(i,ias))
               i=i+lmmaxo
             end do
-            t1=fintgt(-1,nr,rsp(:,is),fr1)
-            t2=fintgt(-1,nr,rsp(:,is),fr2)
+            t1=splint(nr,rsp(:,is),fr1)
+            t2=splint(nr,rsp(:,is),fr2)
             dhloa(lm2,io,l3,ilo,ias)=cmplx(t1,t2,8)
           end do
         end do
@@ -113,8 +113,8 @@ do ias=1,natmtot
               fr2(ir)=t1*aimag(dvsmt(i,ias))
               i=i+lmmaxo
             end do
-            t1=fintgt(-1,nro,rsp(iro,is),fr1(iro))
-            t2=fintgt(-1,nro,rsp(iro,is),fr2(iro))
+            t1=splint(nro,rsp(iro,is),fr1(iro))
+            t2=splint(nro,rsp(iro,is),fr2(iro))
             dhloa(lm2,io,l3,ilo,ias)=cmplx(t1,t2,8)
           end do
         end do
@@ -145,8 +145,8 @@ do ias=1,natmtot
             fr2(ir)=t1*aimag(dvsmt(i,ias))
             i=i+lmmaxo
           end do
-          t1=fintgt(-1,nr,rsp(:,is),fr1)
-          t2=fintgt(-1,nr,rsp(:,is),fr2)
+          t1=splint(nr,rsp(:,is),fr1)
+          t2=splint(nr,rsp(:,is),fr2)
           dhlolo(lm2,jlo,ilo,ias)=cmplx(t1,t2,8)
         end do
       end do
@@ -160,8 +160,8 @@ do ias=1,natmtot
             fr2(ir)=t1*aimag(dvsmt(i,ias))
             i=i+lmmaxo
           end do
-          t1=fintgt(-1,nro,rsp(iro,is),fr1(iro))
-          t2=fintgt(-1,nro,rsp(iro,is),fr2(iro))
+          t1=splint(nro,rsp(iro,is),fr1(iro))
+          t2=splint(nro,rsp(iro,is),fr2(iro))
           dhlolo(lm2,jlo,ilo,ias)=cmplx(t1,t2,8)
         end do
       end do
