@@ -23,14 +23,14 @@ complex(8) x(ngpq)
 if (ias.ne.iasph) return
 is=idxis(ias)
 lm=0
-do l=0,lmaxmat
+do l=0,lmaxapw
   do m=-l,l
     lm=lm+1
     do io=1,apword(l,is)
       x(1:ngpq)=conjg(apwalmq(1:ngpq,io,lm))
-      call zgerci(ngpq,ngp,zone,x,dapwalm(:,io,lm),ld,od)
+      call zgerci(ngpq,ngp,x,dapwalm(:,io,lm),ld,od)
       x(1:ngpq)=conjg(dapwalmq(1:ngpq,io,lm))
-      call zgerci(ngpq,ngp,zone,x,apwalm(:,io,lm),ld,od)
+      call zgerci(ngpq,ngp,x,apwalm(:,io,lm),ld,od)
     end do
   end do
 end do
