@@ -144,8 +144,8 @@ call symrf(nrmt,nrmti,npmt,npmtmax,elfmt,elfir)
 ! plot the ELF to file
 select case(task)
 case(51)
-  open(50,file='ELF1D.OUT',action='WRITE',form='FORMATTED')
-  open(51,file='ELFLINES.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='ELF1D.OUT',form='FORMATTED')
+  open(51,file='ELFLINES.OUT',form='FORMATTED')
   call plot1d(50,51,1,elfmt,elfir)
   close(50)
   close(51)
@@ -154,13 +154,13 @@ case(51)
   write(*,'(" 1D ELF plot written to ELF1D.OUT")')
   write(*,'(" vertex location lines written to ELFLINES.OUT")')
 case(52)
-  open(50,file='ELF2D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='ELF2D.OUT',form='FORMATTED')
   call plot2d(50,1,elfmt,elfir)
   close(50)
   write(*,*)
   write(*,'("Info(elfplot): 2D ELF plot written to ELF2D.OUT")')
 case(53)
-  open(50,file='ELF3D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='ELF3D.OUT',form='FORMATTED')
   call plot3d(50,1,elfmt,elfir)
   close(50)
   write(*,*)
