@@ -7,6 +7,7 @@
 program elk
 use modmain
 use modmpi
+use modomp
 use modvars
 implicit none
 ! local variables
@@ -15,11 +16,11 @@ integer itask
 ! initialise MPI execution environment
 call mpi_init(ierror)
 ! duplicate mpi_comm_world
-call mpi_comm_dup(mpi_comm_world,mpi_comm_kpt,ierror)
+call mpi_comm_dup(mpi_comm_world,mpicom,ierror)
 ! determine the number of MPI processes
-call mpi_comm_size(mpi_comm_kpt,np_mpi,ierror)
+call mpi_comm_size(mpicom,np_mpi,ierror)
 ! determine the local MPI process number
-call mpi_comm_rank(mpi_comm_kpt,lp_mpi,ierror)
+call mpi_comm_rank(mpicom,lp_mpi,ierror)
 ! determine if the local process is the master
 if (lp_mpi.eq.0) then
   mp_mpi=.true.
@@ -34,6 +35,22 @@ else
 end if
 ! read input files
 call readinput
+! initialise OpenMP variables
+call omp_init
+! initialise the MKL library
+call mkl_init
+! initialise the OpenBLAS library
+call oblas_init
+! initialise the BLIS library
+call blis_init
+if (mp_mpi) then
+  write(*,*)
+  write(*,'("Number of MPI processes : ",I6)') np_mpi
+  write(*,'("Number of CPUs per MPI process : ",I4)') ncpu
+  write(*,'("Number of OpenMP threads per MPI process : ",I4)') maxthd
+  write(*,'("Nested OpenMP : ",L1)') omp_get_nested()
+  write(*,'("OpenMP dynamic thread adjustment : ",L1)') omp_get_dynamic()
+end if
 ! delete the VARIABLES.OUT file
 call delvars
 ! write version number to VARIABLES.OUT
@@ -59,12 +76,13 @@ do itask=1,ntasks
     write(*,'("Info(elk): current task : ",I6)') task
   end if
 ! synchronise MPI processes
-  call mpi_barrier(mpi_comm_kpt,ierror)
+  call mpi_barrier(mpicom,ierror)
 ! check if task can be run with MPI
   if (lp_mpi.gt.0) then
     select case(task)
-    case(0,1,2,3,5,28,29,120,135,136,170,180,185,188,200,201,205,240,300,320, &
-     330,331,440,460,461)
+    case(0,1,2,3,5,28,29,61,62,63,120,135,136,162,170,180,185,188,200,201,205, &
+     240,300,320,330,331,350,351,360,372,373,440,460,461,600,610,620,630,640, &
+     700,701)
       continue
     case default
       write(*,'("Info(elk): MPI process ",I6," idle for task ",I6)') lp_mpi,task
@@ -134,12 +152,14 @@ do itask=1,ntasks
     call elnes
   case(150)
     call writeevsp
+  case(160)
+    call torque
   case(170)
     call writeemd
   case(171,172,173)
     call emdplot
   case(180)
-    call epsinv_rpa
+    call writeepsinv
   case(185)
     call writehmlbse
   case(186)
@@ -174,28 +194,54 @@ do itask=1,ntasks
     call scdft
   case(300)
     call rdmft
-  case(188,320)
+  case(320)
     call tddftlr
   case(330,331)
     call tddftsplr
+  case(341,342,343)
+    call wxcplot
   case(350,351,352)
     call spiralsc
+  case(360)
+    call ssfsmjx
+  case(372,373)
+    call curdenplot
   case(400)
     call writetmdu
+  case(430)
+    call writestrain
   case(440)
     call writestress
   case(450)
     call genafieldt
   case(460,461)
     call tddft
+  case(480,481)
+    call dielectric_tdrt
   case(500)
     call testcheck
+  case(600)
+    call gwsefm
+  case(610)
+    call gwspecf
+  case(620)
+    call gwbandstr
+  case(630)
+    call gwscrho
+  case(640)
+    call gwdmat
+  case(700,701)
+    call gndstulr
   case default
     write(*,*)
     write(*,'("Error(elk): task not defined : ",I8)') task
     write(*,*)
     stop
   end select
+! reset the OpenMP thread variables
+  call omp_reset
+! close all opened files
+  call closefiles
 end do
 if (mp_mpi) then
   open(50,file='RUNNING')
@@ -209,7 +255,7 @@ stop
 end program
 
 !BOI
-! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 4.0.15}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
+! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 5.3.27}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
 ! !AUTHORS: {\sc J. K. Dewhurst, S. Sharma} \\ {\sc L. Nordstr\"{o}m, F. Cricchio, O. Gr\aa n\"{a}s} \\ {\sc E. K. U. Gross}
 ! !AFFILIATION:
 ! !INTRODUCTION: Introduction
@@ -242,12 +288,13 @@ end program
 !   Floyd, Arkardy Davydov, Florian Eich, Aldo Romero Castro, Koichi Kitahara,
 !   James Glasbrenner, Konrad Bussmann, Igor Mazin, Matthieu Verstraete, David
 !   Ernsting, Stephen Dugdale, Peter Elliott, Marcin Dulak, Jos\'{e} A. Flores
-!   Livas, Stefaan Cottenier, Yasushi Shinohara and Michael Fechner. Special
-!   mention of David Singh's very useful book on the LAPW method\footnote{D. J.
-!   Singh, {\it Planewaves, Pseudopotentials and the LAPW Method} (Kluwer
-!   Academic Publishers, Boston, 1994).} must also be made. Finally we would
-!   like to acknowledge the generous support of Karl-Franzens-Universit\"{a}t
-!   Graz, as well as the EU Marie-Curie Research Training Networks initiative.
+!   Livas, Stefaan Cottenier, Yasushi Shinohara, Michael Fechner, Yaroslav
+!   Kvashnin and Tristan M\"uller. Special mention of David Singh's very useful
+!   book on the LAPW method\footnote{D. J. Singh, {\it Planewaves,
+!   Pseudopotentials and the LAPW Method} (Kluwer Academic Publishers, Boston,
+!   1994).} must also be made. Finally we would like to acknowledge the generous
+!   support of Karl-Franzens-Universit\"{a}t Graz, the EU Marie-Curie Research
+!   Training Networks initiative and the Max Planck Society.
 !
 !   \vspace{24pt}
 !   Kay Dewhurst\newline
@@ -258,7 +305,7 @@ end program
 !   Hardy Gross
 !
 !   \vspace{12pt}
-!   Halle and Uppsala, July 2016
+!   Berlin, Halle and Uppsala, May 2018
 !   \newpage
 !
 !   \section{Units}
@@ -301,25 +348,14 @@ end program
 !   \item
 !    OpenMP works for symmetric multiprocessors, i.e. computers that have many
 !    cores with the same unified memory accessible to each. It is enabled by
-!    setting the appropriate command-line options (e.g. {\tt -openmp} for the
+!    setting the appropriate command-line options (e.g. {\tt -qopenmp} for the
 !    Intel compiler) before compiling, and also at runtime by the environment
 !    variable
 !    \begin{verbatim}
 !     export OMP_NUM_THREADS=x
 !    \end{verbatim}
-!    where x is the number of cores available on a particular node. Elk also
-!    makes use of nested OpenMP parallelism, meaning that there are nested
-!    parallel loops in parts of the code, the iterative diagonaliser being one
-!    such example. These nested loops can be run in parallel by setting
-!    \begin{verbatim}
-!     export OMP_NESTED=true
-!    \end{verbatim}
-!    Be aware that using this option can actually degrade performance if too
-!    many threads are created. To avoid such oversubscription, you may need to
-!    adjust related OpenMP variables including {\tt OMP\_THREAD\_LIMIT},
-!    {\tt OMP\_MAX\_ACTIVE\_LEVELS} and {\tt OMP\_DYNAMIC} (there may also be
-!    additional compiler-specific environment variables that can be set).
-!    Finally, some vendor-supplied BLAS/LAPACK libraries use OpenMP internally,
+!    where x is the number of cores available on a particular node. In addition,
+!    some vendor-supplied BLAS/LAPACK libraries use OpenMP internally,
 !    for example MKL from Intel and ACML from AMD; refer to their documentation
 !    for usage.
 !    \item
@@ -362,11 +398,11 @@ end program
 !   Libxc is the ETSF library of exchange-correlation functionals. Elk can use
 !   the complete set of LDA and GGA functionals available in Libxc as well as
 !   the potential-only metaGGA's. In order to enable this, first download and
-!   compile Libxc version 2.2.$x$. This should have produced the files
-!   {\tt libxc.a} and {\tt libxcf90.a}. Copy these files to the {\tt elk/src}
-!   directory and then uncomment the lines indicated for Libxc in the file
-!   {\tt elk/make.inc}. Once this is done, run {\tt make clean} followed by
-!   {\tt make}. To select a particular functional of Libxc, use the block
+!   compile Libxc version 4. This should have produced the files {\tt libxc.a}
+!   and {\tt libxcf90.a}. Copy these files to the {\tt elk/src} directory and
+!   then uncomment the lines indicated for Libxc in the file {\tt elk/make.inc}.
+!   Once this is done, run {\tt make clean} followed by {\tt make}. To select a
+!   particular functional of Libxc, use the block
 !   \begin{verbatim}
 !     xctype
 !      100 nx nc
@@ -632,7 +668,7 @@ end program
 !
 !   \block{deltast}{
 !   {\tt deltast} & size of the change in lattice vectors used for calculating
-!    the stress tensor & real & $0.005$}
+!    the stress tensor & real & $0.001$}
 !   The stress tensor is computed by changing the lattice vector matrix $A$ by
 !   $$ A\rightarrow (1+\delta t\,e_i)A, $$
 !   where $dt$ is an infinitesimal equal in practice to {\tt deltast} and $e_i$
@@ -681,12 +717,17 @@ end program
 !   are set to the Fermi energy plus {\tt dlefe}.
 !
 !   \block{dncgga}{
-!   {\tt dncgga} & small constant added to the up-density to stabilise
-!    non-collinear GGA & real & $1\times 10^{-4}$}
-!   This small constant is required in order to remove the infinite gradients
-!   obtained when using `Kubler's trick' in conjunction with GGA and
-!   non-collinear magnetism. It should be taken as the smallest value for which
-!   the self-consistent loop still converges.
+!   {\tt dncgga} & small constant used to stabilise non-collinear GGA &
+!    real & $1\times 10^{-8}$}
+!   This small constant, $d$, is required in order to remove the infinite
+!   gradients obtained when using `Kubler's trick' in conjunction with GGA and
+!   non-collinear magnetism. It is applied by calculating the up and down
+!   densities as
+!   $$ \rho^{\uparrow}({\bf r})=\rho({\bf r})+\widetilde{m}({\bf r})
+!    \qquad \rho^{\downarrow}({\bf r})=\rho({\bf r})-\widetilde{m}({\bf r}), $$
+!   where $\widetilde{m}({\bf r})=\sqrt{{\bf m}^2({\bf r})+d}$,
+!   and should be taken as the smallest value for which the exchange-correlation
+!   magnetic field ${\bf B}_{\rm xc}$ is smooth.
 !
 !   \block{dosmsum}{
 !   {\tt dosmsum} & {\tt .true.} if the partial DOS is to be summed over $m$ &
@@ -726,20 +767,6 @@ end program
 !    $1\times 10^{-4}$}
 !   See {\tt epspot}.
 !
-!   \block{epseph}{
-!   {\tt epseph} & energy tolerance for the Fermi surface average of the
-!    electron-phonon coupling & real & $0.02$}
-!   This is the energy tolerance used for approximating the $\delta$-functions
-!   in the integral
-!   $$ \gamma_n({\bf q})=2\pi\omega_n({\bf q})
-!    |g_{i{\bf k}+{\bf q},j{\bf k}}^n|^2
-!    \delta(\varepsilon_{i{\bf k}+{\bf q}}-\varepsilon_F)
-!    \delta(\varepsilon_{j{\bf k}}-\varepsilon_F), $$
-!   where $g$ is the electron-phonon coupling matrix and $n$ labels a phonon
-!   branch. The Eliashberg function $\alpha^2F(\omega)$ is then determined from
-!   $\gamma$. Numerically, $\delta(x)=1/\epsilon_{\rm eph}$ for
-!   $|x|<\epsilon_{\rm eph}/2$ and zero otherwise.
-!
 !   \block{epsforce}{
 !   {\tt epsforce} & convergence tolerance for the forces during a geometry
 !    optimisation run & real & $2\times 10^{-3}$}
@@ -800,7 +827,10 @@ end program
 !   \block{fracinr}{
 !   {\tt fracinr} & fraction of the muffin-tin radius up to which {\tt lmaxi}
 !    is used as the angular momentum cut-off & real & $0.01$}
-!   See {\tt lmaxi}.
+!   If {\tt fracinr} is negative then the fraction is determined from
+!   $f=\sqrt{({\tt lmaxi}+1)^2/({\tt lmaxo}+1)^2}$ in order to
+!   maintain a minimum density of points throughout the muffin-tin. See
+!   {\tt lmaxi} and {\tt lmaxo}.
 !
 !   \block{fsmtype}{
 !   {\tt fsmtype} & 0 for no fixed spin moment (FSM), 1 for total FSM, 2 for
@@ -824,9 +854,9 @@ end program
 !   $$ f_{xc}({\bf G},{\bf G}',{\bf q},\omega)=-\frac{\alpha+\beta\omega^2}{q^2}
 !    \delta_{{\bf G},{\bf G}'}\delta_{{\bf G},{\bf 0}}. $$
 !
-!   \block{fxtype}{
+!   \block{fxctype}{
 !   {\tt fxctype} & integer defining the type of exchange-correlation kernel
-!    $f_{\rm xc}$ & integer & -1}
+!    $f_{\rm xc}$ & integer & $-1$}
 !   The acceptable values are:
 !   \vskip 6pt
 !   \begin{tabularx}{\textwidth}[h]{lX}
@@ -836,9 +866,7 @@ end program
 !    {\it Phys. Rev. B} {\bf 72}, 125203 (2005); see {\tt fxclrc} \\
 !   210 & `Bootstrap' kernel, S. Sharma, J. K. Dewhurst, A. Sanna and
 !    E. K. U. Gross, {\it Phys. Rev. Lett.} {\bf 107}, 186401 (2011) \\
-!   211 & Single iteration bootstrap \\
-!   212 & Revised bootstrap, S. Rigamonti, S. Botti, V. Veniard, C. Draxl,
-!    L. Reining, F. Sottile, {\it Phys. Rev. Lett.} {\bf 114}, 146402 (2015)
+!   211 & Single iteration bootstrap
 !   \end{tabularx}
 !
 !   \block{gmaxrf}{
@@ -851,7 +879,7 @@ end program
 !   This variable has a lower bound which is enforced by the code as follows:
 !   $$ {\rm gmaxvr}\rightarrow\max\,({\rm gmaxvr},2\times{\rm gkmax}
 !    +{\rm epslat}) $$
-!   See {\tt rgkmax} and {\tt trimvg}.
+!   See {\tt rgkmax}.
 !
 !   \block{hdbse}{
 !   {\tt hdbse} & {\tt .true.} if the direct term is to be included in the BSE
@@ -890,11 +918,17 @@ end program
 !   \block{isgkmax}{
 !   {\tt isgkmax} & species for which the muffin-tin radius will be used for
 !    calculating {\tt gkmax} & integer & $-1$}
-!   By default ($-1$) the average muffin-tin radius is used for determining
-!   {\tt gkmax} from {\tt rgkmax}. This can be changed by setting {\tt isgkmax}
-!   either to the desired species number; or to $-2$ if
-!   ${\tt gkmax}={\tt rgkmax}/2$; or to $-3$ in which case the smallest
-!   radius is used.
+!   The APW cut-off is determined from ${\tt gkmax}={\tt rgkmax}/R$. The
+!   variable {\tt isgkmax} determines which muffin-tin radius is to be used for
+!   $R$. These are the options:
+!   \vskip 6pt
+!   \begin{tabularx}{\textwidth}[h]{lX}
+!   -4 & Use the largest radius \\
+!   -3 & Use the smallest radius \\
+!   -2 & Use the fixed value $R=2.0$ \\
+!   -1 & Use the average of the muffin-tin radii \\
+!   $n\ge 1$ & Use the radius of species $n$
+!   \end{tabularx}
 !
 !   \block{kstlist}{
 !   {\tt kstlist(i)} & $i$th $k$-point and state pair & integer(2) & $(1,1)$}
@@ -906,12 +940,15 @@ end program
 !   \block{latvopt}{
 !   {\tt latvopt} & type of lattice vector optimisation to be performed during
 !    structural relaxation & integer & 0}
-!   Unconstrained optimisation of the lattice vectors will be performed with
-!   ${\tt task}=2,3$ when ${\tt latvopt}=1$. When ${\tt latvopt}=2$ the lattice
-!   vectors will be optimised while keeping the unit cell volume fixed. In
-!   either case, the crystal symmetry is retained during optimisation. By
-!   default (${\tt latvopt}=0$) no lattice vector optimisation is performed
-!   during structural relaxation. See also {\tt tau0latv}.
+!   Optimisation of the lattice vectors will be performed with ${\tt task}=2,3$
+!   when ${\tt latvopt}\ne 0$. When ${\tt latvopt}=1$ the lattice vector
+!   optimisation will be constrained only by symmetry. Optimisation over all
+!   symmetry-preserving strains except isotropic scaling is performed when
+!   ${\tt latvopt}=2$. If ${\tt latvopt}<0$ then the optimisation will be over
+!   strain number $|{\tt latvopt}|$. The list of symmetric strain tensors can be
+!   produced with ${\tt task}=430$. By default (${\tt latvopt}=0$) no lattice
+!   vector optimisation is performed during structural relaxation. See also
+!   {\tt tau0latv} and {\tt atpopt}.
 !
 !   \block{lmaxapw}{
 !   {\tt lmaxapw} & angular momentum cut-off for the APW functions & integer &
@@ -928,13 +965,9 @@ end program
 !   therefore the spherical harmonic expansion can be truncated a low angular
 !   momentum. See also {\tt fracinr}.
 !
-!   \block{lmaxmat}{
-!   {\tt lmaxmat} & angular momentum cut-off for the outer-most loop in the
-!    hamiltonian and overlap matrix set up & integer & 7}
-!
 !   \block{lmaxo}{
 !   {\tt lmaxo} & angular momentum cut-off for the muffin-tin density and
-!    potential & integer & 7}
+!    potential & integer & 6}
 !
 !   \block{lmirep}{
 !   {\tt lmirep} & {\tt .true.} if the $Y_{lm}$ basis is to be transformed
@@ -1017,8 +1050,19 @@ end program
 !   specified (even for collinear calculations). See {\tt fsmtype}, {\tt taufsm}
 !   and {\tt spinpol}.
 !
+!   \block{msmooth}{
+!   {\tt msmooth} & amount of smoothing to be applied to the
+!    exchange-correlation potentials and magnetic field & integer & 0}
+!   Smoothing operations can be applied to the exchange-correlation potentials
+!   $v_{xc}$, $w_{xc}$ and the magnetic field ${\bf B}_{xc}$ in order to improve
+!   convergence. In the muffin-tin, this smoothing takes the form of $m$
+!   successive three-point running averages applied to the radial component. In
+!   the interstitial region, the potential is first Fourier transformed to
+!   $G$-space, then a low-pass filter of the form $\exp[-2m(G/G_{\rm max})^8]$
+!   is applied and the function is transformed back to real-space.
+!
 !   \block{mstar}{
-!   {\tt mstar} & Value of the effective mass parameter used for adaptive
+!   {\tt mstar} & value of the effective mass parameter used for adaptive
 !    determination of {\tt swidth} & real & $10.0$}
 !   See {\tt autoswidth}.
 !
@@ -1065,8 +1109,8 @@ end program
 !
 !   \block{ngridq}{
 !   {\tt ngridq } & the phonon $q$-point mesh sizes & integer(3) & $(1,1,1)$}
-!   Same as {\tt ngridk}, except that this mesh is for the phonon $q$-points.
-!   See also {\tt reduceq}.
+!   Same as {\tt ngridk}, except that this mesh is for the phonon $q$-points
+!   and other tasks. See also {\tt reduceq}.
 !
 !   \block{nosource}{
 !   {\tt nosource} & when set to {\tt .true.}, source fields are projected out
@@ -1362,12 +1406,12 @@ end program
 !   3 & Fermi-Dirac
 !   \end{tabularx}
 !   \vskip 6pt
-!   See also {\tt autoswidth} and {\tt swidth}.
+!   See also {\tt autoswidth}, {\tt swidth} and {\tt tempk}.
 !
 !   \block{swidth}{
 !   {\tt swidth} & width of the smooth approximation to the Dirac delta
 !    function & real & $0.001$}
-!   See {\tt stype} for details.
+!   See {\tt stype} for details and the variable {\tt tempk}.
 !
 !   \newpage
 !   \block{tasks}{
@@ -1471,7 +1515,7 @@ end program
 !    energy contributions. \\
 !   450 & Generates a laser pulse in the form of a time-dependent vector
 !    potential ${\bf A}(t)$ and writes it to AFIELDT.OUT. \\
-!   460 & Time-evolution run using TDDFT under the influence of ${\bf A}(t)$.
+!   460 & Time evolution run using TDDFT under the influence of ${\bf A}(t)$.
 !   \end{tabularx}
 !
 !   \block{tau0atp}{
@@ -1493,13 +1537,10 @@ end program
 !   {\tt latvopt}.
 !
 !   \block{tauoep}{
-!   {\tt tauoep} & step length initial value and scaling factors for the OEP
-!    iterative solver & real(3) & $(1.0, 0.2, 1.5)$}
-!   The optimised effective potential is determined using an interative method.
-!   [Phys. Rev. Lett. 98, 196405 (2007)]. At the first iteration the step length
-!   is set to {\tt tauoep(1)}. During subsequent iterations, the step length is
-!   scaled by {\tt tauoep(2)} or {\tt tauoep(3)}, when the residual is
-!   increasing or decreasing, respectively. See also {\tt maxitoep}.
+!   {\tt tauoep} & step length for the OEP iterative solver & real & $0.01$}
+!   The optimised effective potential is determined using an interative method
+!   [Phys. Rev. Lett. 98, 196405 (2007)]. This variable sets the step length
+!   descibed in the article. See also {\tt maxitoep}.
 !
 !   \block{taufsm}{
 !   {\tt taufsm} & the step size to be used when finding the effective magnetic
@@ -1513,6 +1554,11 @@ end program
 !   where $\lambda$ is proportional to {\tt taufsm}. See also {\tt fsmtype},
 !   {\tt momfix} and {\tt spinpol}.
 !
+!   \block{tempk}{
+!   {\tt tempk} & temperature $T$ of the electronic system in kelvin & real & -}
+!   Assigning a value to this variable sets {\tt stype} to 3 (Fermi-Dirac) and
+!   the smearing width to $k_{\rm B}T$.
+!
 !   \block{tforce}{
 !   {\tt tforce} & set to {\tt .true.} if the force should be calculated at the
 !    end of the self-consistent cycle & logical & {\tt .false.}}
@@ -1529,13 +1575,6 @@ end program
 !   from a given density matrix and set of Slater parameters at the end of the
 !   self-consistent cycle.
 !
-!   \block{trimvg}{
-!   {\tt trimvg} & set to {\tt .true.} if the Fourier components of the
-!    Kohn-Sham potential for $|G|>{\tt gmaxvr}/2$ are to be set to zero &
-!    logical & {\tt .false.}}
-!   This fixes stability problems which can occur for large {\tt rgkmax}. Should
-!   be used only in conjunction with large {\tt gmaxvr}.
-!
 !   \block{tefvit}{
 !   {\tt tefvit} & set to {\tt .true.} if the first-variational eigenvalue
 !    equation should be solved iteratively & logical & {\tt .false.}}
@@ -1625,6 +1664,15 @@ end program
 !    m_y({\bf r})\sin({\bf q \cdot r}),m_z({\bf r})), $$
 !   where $m_x$, $m_y$ and $m_z$ are lattice periodic. See also {\tt spinsprl}.
 !
+!   \block{wmaxgw}{
+!   {\tt wmaxgw} & maximum Matsubara frequency for $GW$ calculations & real &
+!    $-5.0$}
+!   This defines the cut-off of the Matsubara frequencies on the imaginary
+!   axis for calculating the $GW$ self-energy and solving the Dyson equation.
+!   If this number is negative then the cut-off is taken to be
+!   $|{\tt wmaxgw}|\times\Delta\epsilon$, where $\Delta\epsilon$ is the
+!   difference between the largest and smallest Kohn-Sham valence eigenvalues.
+!
 !   \block{wplot}{
 !   {\tt nwplot} & number of frequency/energy points in the DOS or optics plot &
 !    integer & $500$ \\
@@ -1692,9 +1740,9 @@ end program
 !   original mathematics. We would also appreciate the following conventions
 !   being adhered to:
 !   \begin{itemize}
-!   \item Strict Fortran 90/95 should be used. Features which are marked as
-!    obsolescent in F90/95 should be avoided. These include assigned format
-!    specifiers, labeled do-loops, computed goto statements and statement
+!   \item Strict Fortran 2003 should be used. Features which are marked as
+!    obsolescent in Fortran 2003 should be avoided. These include assigned
+!    format specifiers, labeled do-loops, computed goto statements and statement
 !    functions.
 !   \item Modules should be used in place of common blocks for declaring
 !    global variables. Use the existing modules to declare new global variables.
