@@ -6,18 +6,19 @@
 subroutine emdplot2d(emds)
 use modmain
 use modpw
+use modomp
 implicit none
 ! arguments
 real(4), intent(in) :: emds(nhkmax,nkpt)
 ! local variables
-integer nh(3),np,ip,n,i
+integer nh(3),np,ip,n,i,nthd
 real(8) vpnl(3),v1(3),t1
 ! allocatable arrays
 real(8), allocatable :: vpl(:,:),vppc(:,:)
-real(8), allocatable :: x(:),f(:),g(:)
+real(8), allocatable :: x(:),f(:)
 ! external functions
-real(8) rfhkintp
-external rfhkintp
+real(8) rfhkintp,fintgt
+external rfhkintp,fintgt
 ! allocate local arrays
 np=np2d(1)*np2d(2)
 allocate(vpl(3,np),vppc(2,np))
@@ -31,26 +32,30 @@ do i=1,n
   t1=2.d0*dble(i-1)/dble(n-1)-1.d0
   x(i)=t1*hkmax
 end do
-open(50,file='EMD2D.OUT',action='WRITE',form='FORMATTED')
+open(50,file='EMD2D.OUT',form='FORMATTED')
 write(50,'(2I6," : grid size")') np2d(:)
 ! loop over plotting points in the 2D plane
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(f,g,i,v1)
+call omp_hold(np,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(f,i,v1,t1) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO ORDERED
 do ip=1,np
-  allocate(f(n),g(n))
+  allocate(f(n))
 ! integrate along normal to plane
   do i=1,n
     v1(:)=vpl(:,ip)+x(i)*vpnl(:)
     f(i)=rfhkintp(v1,emds)
   end do
-  call fderiv(-2,n,x,f,g)
+  t1=fintgt(-2,n,x,f)
 !$OMP ORDERED
-  write(50,'(3G18.10)') vppc(1,ip),vppc(2,ip),g(n)
+  write(50,'(3G18.10)') vppc(1,ip),vppc(2,ip),t1
 !$OMP END ORDERED
-  deallocate(f,g)
+  deallocate(f)
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 close(50)
 deallocate(vpl,vppc,x)
 return
