@@ -31,22 +31,22 @@ do ias=1,natmtot
 ! spin-polarised core
     i=1
     do ir=1,nri
-      rfmt(i)=(rhocr(ir,ias,1)+rhocr(ir,ias,2))/y00
+      rfmt(i)=rhocr(ir,ias,1)+rhocr(ir,ias,2)
       i=i+lmmaxi
     end do
     do ir=nri+1,nr
-      rfmt(i)=(rhocr(ir,ias,1)+rhocr(ir,ias,2))/y00
+      rfmt(i)=rhocr(ir,ias,1)+rhocr(ir,ias,2)
       i=i+lmmaxo
     end do
   else
 ! spin-unpolarised core
     i=1
     do ir=1,nri
-      rfmt(i)=rhocr(ir,ias,1)/y00
+      rfmt(i)=rhocr(ir,ias,1)
       i=i+lmmaxi
     end do
     do ir=nri+1,nr
-      rfmt(i)=rhocr(ir,ias,1)/y00
+      rfmt(i)=rhocr(ir,ias,1)
       i=i+lmmaxo
     end do
   end if
