@@ -7,48 +7,39 @@ subroutine energynn
 use modmain
 implicit none
 ! local variables
-integer is,ia,ias
-integer nr,nri,ir,np,i
+integer is,ias,i
+integer nr,nri,ir
 real(8) t1
-complex(8) zrho0
-! automatic arrays
-real(8) vn(nrmtmax),vn0(nspecies)
 ! allocatable arrays
 complex(8), allocatable :: zvclmt(:,:),zvclir(:),zrhoir(:)
-allocate(zvclmt(npmtmax,natmtot),zvclir(ngtot))
+allocate(zvclmt(npmtmax,natmtot))
 ! generate the nuclear monopole potentials
-t1=1.d0/y00
-do is=1,nspecies
+do ias=1,natmtot
+  is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
-  np=npmt(is)
-  call potnucl(ptnucl,nr,rsp(:,is),spzn(is),vn)
-  vn0(is)=vn(1)
-  do ia=1,natoms(is)
-    ias=idxas(ia,is)
-    zvclmt(1:np,ias)=0.d0
-    i=1
-    do ir=1,nri
-      zvclmt(i,ias)=t1*vn(ir)
-      i=i+lmmaxi
-    end do
-    do ir=nri+1,nr
-      zvclmt(i,ias)=t1*vn(ir)
-      i=i+lmmaxo
-    end do
+  zvclmt(1:npmt(is),ias)=0.d0
+  i=1
+  do ir=1,nri
+    zvclmt(i,ias)=vcln(ir,is)
+    i=i+lmmaxi
+  end do
+  do ir=nri+1,nr
+    zvclmt(i,ias)=vcln(ir,is)
+    i=i+lmmaxo
   end do
 end do
+allocate(zrhoir(ngtot),zvclir(ngtot))
 ! set the interstitial density to zero
-allocate(zrhoir(ngtot))
 zrhoir(:)=0.d0
 ! solve the complex Poisson's equation
-call zpotcoul(nrmt,nrmti,npmt,npmti,nrspmax,rsp,1,gc,jlgr,ylmg,sfacg,zrhoir, &
- npmtmax,zvclmt,zvclir,zrho0)
+call zpotcoul(nrmt,nrmti,npmt,npmti,nrspmax,rsp,ngridg,igfft,ngvec,gc,gclg, &
+ ngvec,jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
 ! compute the nuclear-nuclear energy
 engynn=0.d0
 do ias=1,natmtot
   is=idxis(ias)
-  t1=dble(zvclmt(1,ias))*y00-vn0(is)
+  t1=(dble(zvclmt(1,ias))-vcln(1,is))*y00
   engynn=engynn+spzn(is)*t1
 end do
 engynn=0.5d0*engynn
