@@ -7,38 +7,32 @@ subroutine ephcouple
 use modmain
 use modphonon
 use modmpi
+use modomp
 use modstore
 implicit none
 ! local variables
 integer iq,ik,jk,jkq
-integer iv(3),isym,ip
-integer ist,jst,i,n
+integer ist,jst,isym,ip
 integer is,ia,ias,js,jas
-integer nr,nri,np
-real(8) vl(3),de,t1,t2
+integer nr,nri,np,i,n,nthd
+real(8) vl(3),de,x
+real(8) t1,t2,t3,t4
 ! allocatable arrays
 real(8), allocatable :: wq(:,:),gq(:,:)
 complex(8), allocatable :: dynq(:,:,:),ev(:,:),a(:,:)
 complex(8), allocatable :: dvmt(:,:,:),dvir(:,:)
 complex(8), allocatable :: zfmt(:),gzfmt(:,:,:)
 complex(8), allocatable :: ephmat(:,:,:)
+! external functions
+real(8) sdelta
+external sdelta
 ! increase the angular momentum cut-off on the inner part of the muffin-tin
-lmaxi0=lmaxi
+lmaxi_=lmaxi
 lmaxi=max(lmaxi,4)
 ! initialise universal variables
 call init0
 call init1
 call init2
-! check k-point grid is commensurate with q-point grid
-iv(:)=mod(ngridk(:),ngridq(:))
-if ((iv(1).ne.0).or.(iv(2).ne.0).or.(iv(3).ne.0)) then
-  write(*,*)
-  write(*,'("Error(ephcouple): k-point grid incommensurate with q-point grid")')
-  write(*,'(" ngridk : ",3I6)') ngridk
-  write(*,'(" ngridq : ",3I6)') ngridq
-  write(*,*)
-  stop
-end if
 ! allocate global arrays
 if (allocated(dvsmt)) deallocate(dvsmt)
 allocate(dvsmt(npmtmax,natmtot))
@@ -51,6 +45,8 @@ allocate(dvmt(npcmtmax,natmtot,nbph),dvir(ngtot,nbph))
 allocate(zfmt(npmtmax),gzfmt(npmtmax,3,natmtot))
 ! read in the density and potentials from file
 call readstate
+! Fourier transform Kohn-Sham potential to G-space
+call genvsig
 ! read Fermi energy from file
 call readfermi
 ! set the speed of light >> 1 (non-relativistic approximation)
@@ -59,19 +55,16 @@ solsc=sol*100.d0
 filext='_EPH.OUT'
 ! generate the first- and second-variational eigenvectors and eigenvalues
 call linengy
-call genapwfr
-call genlofr
-call olprad
-call hmlrad
+call genapwlofr
 call gensocfr
 call genevfsv
-! restore the speed of light
-solsc=sol
-! determine Fermi energy precisely using small smearing width
+! precise determine of the Fermi energy
 t1=swidth
 swidth=1.d-5
 call occupy
 swidth=t1
+! restore the speed of light
+solsc=sol
 ! read in the dynamical matrices
 call readdyn(dynq)
 ! apply the acoustic sum rule
@@ -108,19 +101,21 @@ do iq=1,nqpt
           js=idxis(jas)
           call zfmtftoc(nrmt(js),nrmti(js),dvsmt(:,jas),dvmt(:,jas,i))
         end do
-        call zcopy(ngtot,dvsir,1,dvir(:,i),1)
+! multiply the interstitial potential with the characteristic function
+        dvir(:,i)=dvsir(:)*cfunir(:)
       end do
     end do
   end do
 ! energy window for calculating the electron-phonon matrix elements averaged
 ! over the Fermi surface
-  de=4.d0*epseph
+  de=4.d0*swidth
 ! zero the phonon linewidths array
   gq(:,iq)=0.d0
-! begin parallel loop over non-reduced k-points
+  call omp_hold(nkptnr/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(ephmat,jk,vl,isym,jkq) &
-!$OMP PRIVATE(t1,t2,ist,jst,i)
+!$OMP PRIVATE(t1,t2,t3,t4,ist,jst,x,i) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
   do ik=1,nkptnr
 ! distribute among MPI processes
@@ -134,20 +129,20 @@ do iq=1,nqpt
     vl(:)=vkl(:,ik)+vql(:,iq)
 ! index to k+q-vector
     call findkpt(vl,isym,jkq)
-    t1=twopi*wkptnr*occmax/(2.d0*epseph**2)
+    t1=pi*wkptnr*occmax
 ! loop over second-variational states
     do ist=1,nstsv
-      t2=2.d0*abs(evalsv(ist,jkq)-efermi)
-      if (t2.gt.epseph) cycle
+      x=(evalsv(ist,jkq)-efermi)/swidth
+      t2=t1*sdelta(stype,x)/swidth
       do jst=1,nstsv
-        t2=2.d0*abs(evalsv(jst,jk)-efermi)
-        if (t2.gt.epseph) cycle
 ! loop over phonon branches
         do i=1,nbph
-          t2=dble(ephmat(ist,jst,i))**2+aimag(ephmat(ist,jst,i))**2
-!$OMP CRITICAL
-          gq(i,iq)=gq(i,iq)+wq(i,iq)*t1*t2
-!$OMP END CRITICAL
+          x=(evalsv(ist,jkq)-evalsv(jst,jk)-wq(i,iq))/swidth
+          t3=t2*sdelta(stype,x)/swidth
+          t4=dble(ephmat(ist,jst,i))**2+aimag(ephmat(ist,jst,i))**2
+!$OMP CRITICAL(ephcouple_)
+          gq(i,iq)=gq(i,iq)+wq(i,iq)*t3*t4
+!$OMP END CRITICAL(ephcouple_)
         end do
       end do
     end do
@@ -156,13 +151,14 @@ do iq=1,nqpt
   end do
 !$OMP END DO
 !$OMP END PARALLEL
+  call omp_free(nthd)
 ! end loop over phonon q-points
 end do
-! add gq from each process and redistribute
+! add gq from each process
 if (np_mpi.gt.1) then
   n=nbph*nqpt
-  call mpi_allreduce(mpi_in_place,gq,n,mpi_double_precision,mpi_sum, &
-   mpi_comm_kpt,ierror)
+  call mpi_allreduce(mpi_in_place,gq,n,mpi_double_precision,mpi_sum,mpicom, &
+   ierror)
 end if
 ! restore the default file extension
 filext='.OUT'
@@ -175,7 +171,7 @@ end if
 deallocate(wq,gq,dynq,ev,a)
 deallocate(dvmt,dvir,zfmt,gzfmt)
 ! restore original input parameters
-lmaxi=lmaxi0
+lmaxi=lmaxi_
 return
 end subroutine
 
