@@ -9,6 +9,7 @@
 subroutine eveqnfv(nmatp,ngp,igpig,vpc,vgpc,apwalm,evalfv,evecfv)
 ! !USES:
 use modmain
+use modomp
 ! !INPUT/OUTPUT PARAMETERS:
 !   nmatp  : order of overlap and Hamiltonian matrices (in,integer)
 !   ngp    : number of G+p-vectors (in,integer)
@@ -36,7 +37,7 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer ias,i
+integer nthd
 real(8) ts0,ts1
 ! allocatable arrays
 complex(8), allocatable :: h(:,:),o(:,:)
@@ -45,34 +46,21 @@ complex(8), allocatable :: h(:,:),o(:,:)
 !-----------------------------------------------!
 call timesec(ts0)
 allocate(h(nmatp,nmatp),o(nmatp,nmatp))
-!$OMP PARALLEL SECTIONS DEFAULT(SHARED) PRIVATE(i,ias)
+call omp_hold(2,nthd)
+!$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
+!$OMP NUM_THREADS(nthd)
 !$OMP SECTION
 ! Hamiltonian
-do i=1,nmatp
-  h(1:i,i)=0.d0
-end do
-do ias=1,natmtot
-  call hmlaa(ias,ngp,apwalm(:,:,:,ias),nmatp,h)
-  call hmlalo(ias,ngp,apwalm(:,:,:,ias),nmatp,h)
-  call hmllolo(ias,ngp,nmatp,h)
-end do
-call hmlistl(ngp,igpig,vgpc,nmatp,h)
+call hmlfv(nmatp,ngp,igpig,vgpc,apwalm,h)
 !$OMP SECTION
 ! overlap
-do i=1,nmatp
-  o(1:i,i)=0.d0
-end do
-do ias=1,natmtot
-  call olpaa(ias,ngp,apwalm(:,:,:,ias),nmatp,o)
-  call olpalo(ias,ngp,apwalm(:,:,:,ias),nmatp,o)
-  call olplolo(ias,ngp,nmatp,o)
-end do
-call olpistl(ngp,igpig,nmatp,o)
+call olpfv(nmatp,ngp,igpig,apwalm,o)
 !$OMP END PARALLEL SECTIONS
+call omp_free(nthd)
 call timesec(ts1)
-!$OMP CRITICAL
+!$OMP CRITICAL(eveqnfv_)
 timemat=timemat+ts1-ts0
-!$OMP END CRITICAL
+!$OMP END CRITICAL(eveqnfv_)
 !---------------------------------------!
 !     solve the eigenvalue equation     !
 !---------------------------------------!
