@@ -9,6 +9,7 @@
 subroutine eveqnfvr(nmatp,ngp,vpc,h,o,evalfv,evecfv)
 ! !USES:
 use modmain
+use modomp
 ! !INPUT/OUTPUT PARAMETERS:
 !   nmatp  : order of overlap and Hamiltonian matrices (in,integer)
 !   ngp    : number of G+p-vectors (in,integer)
@@ -43,7 +44,7 @@ integer ilo,i,j,k,l,m
 integer i1,i2,j1,j2
 integer k1,k2,k3,k4
 integer l1,l2,m1,m2
-integer lwork,info
+integer lwork,info,nthd
 real(8) v(3),vl,vu
 real(8) t1,t2,t3,t4
 real(8) ts0,ts1
@@ -235,8 +236,13 @@ allocate(iwork(5*nmatp),ifail(nmatp))
 allocate(w(nmatp),rv(nmatp,nstfv))
 lwork=8*nmatp
 allocate(work(lwork))
+! enable MKL parallelism
+call omp_hold(maxthd,nthd)
+call mkl_set_num_threads(nthd)
 call dsygvx(1,'V','I','U',nmatp,rh,nmatp,ro,nmatp,vl,vu,1,nstfv,evaltol,m,w, &
  rv,nmatp,work,lwork,iwork,ifail,info)
+call omp_free(nthd)
+call mkl_set_num_threads(1)
 if (info.ne.0) then
   write(*,*)
   write(*,'("Error(eveqnfvr): diagonalisation failed")')
@@ -277,9 +283,9 @@ end do
 deallocate(iwork,ifail,w,rv,work)
 deallocate(tr,tp,idx,s,map,rh,ro,zp)
 call timesec(ts1)
-!$OMP CRITICAL
+!$OMP CRITICAL(eveqnfvr_)
 timefv=timefv+ts1-ts0
-!$OMP END CRITICAL
+!$OMP END CRITICAL(eveqnfvr_)
 return
 end subroutine
 !EOC
