@@ -5,6 +5,7 @@
 
 subroutine eveqnfvz(nmatp,h,o,evalfv,evecfv)
 use modmain
+use modomp
 implicit none
 ! arguments
 integer, intent(in) :: nmatp
@@ -12,7 +13,8 @@ complex(8), intent(in) :: h(*),o(*)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer i,m,lwork,info
+integer i,m,nthd
+integer lwork,info
 real(8) vl,vu
 real(8) ts0,ts1
 ! allocatable arrays
@@ -24,8 +26,14 @@ allocate(iwork(5*nmatp),ifail(nmatp))
 allocate(w(nmatp),rwork(7*nmatp))
 lwork=2*nmatp
 allocate(work(lwork))
+! enable MKL parallelism
+call omp_hold(maxthd,nthd)
+call mkl_set_num_threads(nthd)
+! diagonalise the matrix
 call zhegvx(1,'V','I','U',nmatp,h,nmatp,o,nmatp,vl,vu,1,nstfv,evaltol,m,w, &
  evecfv,nmatmax,work,lwork,rwork,iwork,ifail,info)
+call omp_free(nthd)
+call mkl_set_num_threads(1)
 if (info.ne.0) then
   write(*,*)
   write(*,'("Error(eveqnfvz): diagonalisation failed")')
@@ -42,9 +50,9 @@ end if
 evalfv(1:nstfv)=w(1:nstfv)
 deallocate(iwork,ifail,w,rwork,work)
 call timesec(ts1)
-!$OMP CRITICAL
+!$OMP CRITICAL(eveqnfvz_)
 timefv=timefv+ts1-ts0
-!$OMP END CRITICAL
+!$OMP END CRITICAL(eveqnfvz_)
 return
 end subroutine
 
