@@ -5,6 +5,7 @@
 
 subroutine eveqnhf(ikp,vmt,vir,bmt,bir,evecsvp)
 use modmain
+use modomp
 implicit none
 ! arguments
 integer, intent(in) :: ikp
@@ -12,20 +13,16 @@ real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtot)
 real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
 complex(8), intent(inout) :: evecsvp(nstsv,nstsv)
 ! local variables
-integer ik,jk,ist1,ist2,ist3,ispn
-integer iv(3),igk,ifg,ig,iq,igq0
-integer lwork,info
-real(8) cfq,v(3),t1
-complex(8) zrho01,zrho02,z1,z2
+integer ik,jk,ist1,ist2,ist3
+integer iv(3),iq,ig,i,nthd
+real(8) vc(3),tp(2),t1
+complex(8) z1
 ! automatic arrays
 integer idx(nstsv)
-complex(8) sfacgq0(natmtot)
 ! allocatable arrays
-real(8), allocatable :: vgqc(:,:),gqc(:),tpgqc(:,:)
-real(8), allocatable :: jlgqr(:,:,:),jlgq0r(:,:,:)
-real(8), allocatable :: rwork(:)
+real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqrmt(:,:,:)
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
-complex(8), allocatable :: h(:,:),c(:,:),kmat(:,:),z(:),work(:)
+complex(8), allocatable :: h(:,:),v(:,:),kmat(:,:)
 complex(8), allocatable :: ylmgq(:,:),sfacgq(:,:)
 complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
 complex(8), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
@@ -34,21 +31,19 @@ complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 ! external functions
 complex(8) zfinp
 external zfinp
-!$OMP CRITICAL
+!$OMP CRITICAL(eveqnhf_)
 write(*,'("Info(eveqnhf): ",I6," of ",I6," k-points")') ikp,nkpt
-!$OMP END CRITICAL
+!$OMP END CRITICAL(eveqnhf_)
 ! allocate local arrays
-allocate(vgqc(3,ngvec),gqc(ngvec),tpgqc(2,ngvec))
-allocate(jlgqr(0:lnpsd,ngvec,nspecies),jlgq0r(0:lmaxo,nrcmtmax,nspecies))
+allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
+allocate(jlgqrmt(0:lnpsd,ngvc,nspecies))
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
-allocate(h(nstsv,nstsv),c(nstsv,nstsv))
-allocate(ylmgq(lmmaxo,ngvec),sfacgq(ngvec,natmtot))
-allocate(wfmt1(npcmtmax,natmtot,nspinor,nstsv),wfir1(ngtot,nspinor,nstsv))
-allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv),wfir2(ngtot,nspinor,nstsv))
-allocate(zrhomt(npcmtmax,natmtot,nstsv),zrhoir(ngtot,nstsv))
-! coefficient of long-range term
-cfq=0.5d0*(omega/pi)**2
+allocate(h(nstsv,nstsv),v(nstsv,nstsv))
+allocate(ylmgq(lmmaxo,ngvc),sfacgq(ngvc,natmtot))
+allocate(wfmt1(npcmtmax,natmtot,nspinor,nstsv),wfir1(ngtc,nspinor,nstsv))
+allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv),wfir2(ngtc,nspinor,nstsv))
+allocate(zrhomt(npcmtmax,natmtot,nstsv),zrhoir(ngtc,nstsv))
 ! get the eigenvectors from file for input reduced k-point
 call getevecfv(filext,ikp,vkl(:,ikp),vgkl(:,:,:,ikp),evecfv)
 ! find the matching coefficients
@@ -58,146 +53,129 @@ do ist1=1,nstsv
   idx(ist1)=ist1
 end do
 ! calculate the wavefunctions for all states of the input k-point
-call genwfsv(.false.,.true.,nstsv,idx,ngk(1,ikp),igkig(:,1,ikp),apwalm, &
- evecfv,evecsvp,wfmt1,ngtot,wfir1)
+call genwfsv(.false.,.true.,nstsv,idx,ngdc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+ apwalm,evecfv,evecsvp,wfmt1,ngtc,wfir1)
 !-----------------------------------------!
 !     local potential matrix elements     !
 !-----------------------------------------!
 if (hybrid.and.spinpol) then
 ! magnetic field matrix elements in hybrid case
-  call genvbmatk(vmt,vir,bmt,bir,ngk(1,ikp),igkig(:,1,ikp),wfmt1,ngtot,wfir1,h)
+  call genvbmatk(vmt,vir,bmt,bir,ngk(1,ikp),igkig(:,1,ikp),wfmt1,ngtc,wfir1,h)
 else
-  call genvmatk(vmt,vir,ngk(1,ikp),igkig(:,1,ikp),wfmt1,ngtot,wfir1,h)
+  call genvmatk(vmt,vir,ngk(1,ikp),igkig(:,1,ikp),wfmt1,ngtc,wfir1,h)
 end if
 ! Fourier transform wavefunctions to real-space
-allocate(z(ngkmax))
-t1=1.d0/sqrt(omega)
-do ist1=1,nstsv
-  do ispn=1,nspinor
-    call zcopy(ngk(1,ikp),wfir1(:,ispn,ist1),1,z,1)
-    wfir1(:,ispn,ist1)=0.d0
-    do igk=1,ngk(1,ikp)
-      ifg=igfft(igkig(igk,1,ikp))
-      wfir1(ifg,ispn,ist1)=t1*z(igk)
-    end do
-    call zfftifc(3,ngridg,1,wfir1(:,ispn,ist1))
-  end do
-end do
-deallocate(z)
+call zftwfir(ngk(1,ikp),igkig(:,1,ikp),wfir1)
 !---------------------------------!
 !     kinetic matrix elements     !
 !---------------------------------!
 allocate(kmat(nstsv,nstsv))
 call getkmat(ikp,kmat)
-call zgemm('N','N',nstsv,nstsv,nstsv,zone,kmat,nstsv,evecsvp,nstsv,zzero,c, &
+call zgemm('N','N',nstsv,nstsv,nstsv,zone,kmat,nstsv,evecsvp,nstsv,zzero,v, &
  nstsv)
-call zgemm('C','N',nstsv,nstsv,nstsv,zone,evecsvp,nstsv,c,nstsv,zone,h,nstsv)
+call zgemm('C','N',nstsv,nstsv,nstsv,zone,evecsvp,nstsv,v,nstsv,zone,h,nstsv)
 deallocate(kmat)
-!---------------------------------------------------------!
-!     Coulomb valence-valence-valence matrix elements     !
-!---------------------------------------------------------!
-c(:,:)=0.d0
-! start loop over non-reduced k-point set
+!------------------------------!
+!     Fock matrix elements     !
+!------------------------------!
+v(:,:)=0.d0
+! loop over non-reduced k-point set
 do ik=1,nkptnr
 ! find the equivalent reduced k-point
   jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
-! determine q-vector
+! determine the q-vector
   iv(:)=ivk(:,ikp)-ivk(:,ik)
   iv(:)=modulo(iv(:),ngridk(:))
+! check if the q-point is in user-defined set
+  iv(:)=iv(:)*ngridq(:)
+  do i=1,3
+    if (modulo(iv(i),ngridk(i)).ne.0) goto 10
+  end do
+  iv(:)=iv(:)/ngridk(:)
   iq=iqmap(iv(1),iv(2),iv(3))
-  v(:)=vkc(:,ikp)-vkc(:,ik)
-  do ig=1,ngvec
-! determine G+q-vectors
-    vgqc(:,ig)=vgc(:,ig)+v(:)
+  vc(:)=vkc(:,ikp)-vkc(:,ik)
+  do ig=1,ngvc
+! determine the G+q-vectors
+    vgqc(:,ig)=vgc(:,ig)+vc(:)
 ! G+q-vector length and (theta, phi) coordinates
-    call sphcrd(vgqc(:,ig),gqc(ig),tpgqc(:,ig))
-! spherical harmonics for G+q-vector
-    call genylm(lmaxo,tpgqc(:,ig),ylmgq(:,ig))
+    call sphcrd(vgqc(:,ig),gqc(ig),tp)
+! spherical harmonics for G+q-vectors
+    call genylm(lmaxo,tp,ylmgq(:,ig))
   end do
 ! structure factors for G+q
-  call gensfacgp(ngvec,vgqc,ngvec,sfacgq)
-! find the shortest G+q-vector
-  call findigp0(ngvec,gqc,igq0)
-  sfacgq0(:)=sfacgq(igq0,:)
+  call gensfacgp(ngvc,vgqc,ngvc,sfacgq)
+! generate the regularised Coulomb Green's function in G+q-space
+  call gengclgq(.true.,iq,ngvc,gqc,gclgq)
 ! compute the required spherical Bessel functions
-  call genjlgpr(lnpsd,gqc,jlgqr)
-  call genjlgq0r(gqc(igq0),jlgq0r)
+  call genjlgprmt(lnpsd,ngvc,gqc,ngvc,jlgqrmt)
 ! find the matching coefficients
   call match(ngk(1,ik),gkc(:,1,ik),tpgkc(:,:,1,ik),sfacgk(:,:,1,ik),apwalm)
 ! get the eigenvectors from file for non-reduced k-point
   call getevecfv(filext,0,vkl(:,ik),vgkl(:,:,1,ik),evecfv)
   call getevecsv(filext,0,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states
-  call genwfsv(.false.,.false.,nstsv,idx,ngk(1,ik),igkig(:,1,ik),apwalm, &
-   evecfv,evecsv,wfmt2,ngtot,wfir2)
+  call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ik),igkig(:,1,ik), &
+   apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
   do ist3=1,nstsv
     if (abs(occsv(ist3,jk)).lt.epsocc) cycle
 ! calculate the complex overlap densities for all states (T. McQueen)
-!$OMP PARALLEL DEFAULT(SHARED)
+    call omp_hold(nstsv,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
     do ist1=1,nstsv
-      call genzrho(.true.,.true.,wfmt2(:,:,:,ist3),wfir2(:,:,ist3), &
+      call genzrho(.true.,.true.,ngtc,wfmt2(:,:,:,ist3),wfir2(:,:,ist3), &
        wfmt1(:,:,:,ist1),wfir1(:,:,ist1),zrhomt(:,:,ist1),zrhoir(:,ist1))
     end do
 !$OMP END DO
 !$OMP END PARALLEL
+    call omp_free(nthd)
+    call omp_hold(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(zvclmt,zvclir,zrho01,zrho02) &
-!$OMP PRIVATE(ist1,z1,z2,t1)
+!$OMP PRIVATE(zvclmt,zvclir) &
+!$OMP PRIVATE(ist1,z1,t1) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
     do ist2=1,nstsv
-      allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtot))
+      allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtc))
 ! calculate the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rcmt,npcmtmax,zrhomt(:,:,ist2), &
        zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rcmt,igq0,gqc,jlgqr, &
-       ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt,zvclir,zrho02)
+      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rcmt,ngdc,igfc,ngvc, &
+       gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt, &
+       zvclir)
       do ist1=1,ist2
         z1=zfinp(zrhomt(:,:,ist1),zrhoir(:,ist1),zvclmt,zvclir)
-! compute the density coefficient of the smallest G+q-vector
-        call zrhogp(jlgq0r,ylmgq(:,igq0),sfacgq0,zrhomt(:,:,ist1), &
-         zrhoir(:,ist1),zrho01)
-        z2=cfq*wiq2(iq)*conjg(zrho01)*zrho02
-        t1=occsv(ist3,jk)/occmax
-        c(ist1,ist2)=c(ist1,ist2)-t1*(wkptnr*z1+z2)
+        t1=wqptnr*occsv(ist3,jk)/occmax
+        v(ist1,ist2)=v(ist1,ist2)-t1*z1
       end do
       deallocate(zvclmt,zvclir)
     end do
 !$OMP END DO
 !$OMP END PARALLEL
+    call omp_free(nthd)
   end do
+10 continue
 ! end loop over non-reduced k-point set
 end do
-deallocate(vgqc,tpgqc,gqc,jlgqr,jlgq0r)
+deallocate(vgqc,gqc,gclgq,jlgqrmt)
 deallocate(ylmgq,sfacgq,apwalm,evecfv)
 deallocate(wfmt1,wfmt2,wfir1,wfir2)
 deallocate(zrhomt,zrhoir)
 ! scale the Coulomb matrix elements in the case of a hybrid functional
-if (hybrid) c(:,:)=hybridc*c(:,:)
+if (hybrid) v(:,:)=hybridc*v(:,:)
 ! add the Coulomb matrix elements to Hamiltonian
-h(:,:)=h(:,:)+c(:,:)
+h(:,:)=h(:,:)+v(:,:)
 !----------------------------------------------!
 !     diagonalise Hartree-Fock Hamiltonian     !
 !----------------------------------------------!
-allocate(rwork(3*nstsv))
-lwork=2*nstsv
-allocate(work(lwork))
-call zheev('V','U',nstsv,h,nstsv,evalsv(:,ikp),work,lwork,rwork,info)
-deallocate(rwork,work)
-if (info.ne.0) then
-  write(*,*)
-  write(*,'("Error(eveqnhf): diagonalisation of the Hartree-Fock Hamiltonian &
-   &failed")')
-  write(*,'(" for k-point ",I8)') ikp
-  write(*,'(" ZHEEV returned INFO = ",I8)') info
-  write(*,*)
-  stop
-end if
-! apply unitary transformation to second-variational states
+call eveqnz(nstsv,nstsv,h,evalsv(:,ikp))
+! apply unitary transformation to the third-variational states so that they
+! refer to the first-variational basis
 evecsv(:,:)=evecsvp(:,:)
 call zgemm('N','N',nstsv,nstsv,nstsv,zone,evecsv,nstsv,h,nstsv,zzero,evecsvp, &
  nstsv)
-deallocate(evecsv,h,c)
+deallocate(evecsv,h,v)
 return
 end subroutine
 
