@@ -9,19 +9,18 @@ implicit none
 ! arguments
 integer, intent(in) :: ikp
 ! local variables
-integer jkp,ik,jk
+integer iq,ik,jk,i,m
 integer nst1,nst2,ist,jst
 integer is,ia,ias
-integer nrc,nrci,m,npc
-integer iv(3),ig,iq,igq0
-real(8) ex,cfq,v(3),t1
-complex(8) zrho0,z1
+integer nrc,nrci,npc
+integer iv(3),ig
+real(8) ex,vc(3),tp(2)
+complex(8) z1
 ! automatic arrays
 integer idx(nstsv)
 ! allocatable arrays
-real(8), allocatable :: vgqc(:,:),gqc(:),tpgqc(:,:),jlgqr(:,:,:)
-complex(8), allocatable :: apwalm(:,:,:,:)
-complex(8), allocatable :: evecfv(:,:),evecsv(:,:)
+real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqrmt(:,:,:)
+complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(8), allocatable :: ylmgq(:,:),sfacgq(:,:)
 complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
 complex(8), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
@@ -32,62 +31,63 @@ complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 complex(8) zfinp,zfmtinp
 external zfinp,zfmtinp
 ! allocate local arrays
-allocate(vgqc(3,ngvec),gqc(ngvec),tpgqc(2,ngvec))
-allocate(jlgqr(0:lnpsd,ngvec,nspecies))
+allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
+allocate(jlgqrmt(0:lnpsd,ngvc,nspecies))
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
-allocate(ylmgq(lmmaxo,ngvec),sfacgq(ngvec,natmtot))
+allocate(ylmgq(lmmaxo,ngvc),sfacgq(ngvc,natmtot))
 allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv))
-allocate(wfir2(ngtot,nspinor,nstsv))
-allocate(zrhomt(npcmtmax,natmtot),zrhoir(ngtot))
-allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtot))
-! coefficient for long-range term
-cfq=0.5d0*(omega/pi)**2
+allocate(wfir2(ngtc,nspinor,nstsv))
+allocate(zrhomt(npcmtmax,natmtot),zrhoir(ngtc))
+allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtc))
 ! get the eigenvectors from file for input reduced k-point
 call getevecfv(filext,ikp,vkl(:,ikp),vgkl(:,:,:,ikp),evecfv)
 call getevecsv(filext,ikp,vkl(:,ikp),evecsv)
 ! find the matching coefficients
 call match(ngk(1,ikp),gkc(:,1,ikp),tpgkc(:,:,1,ikp),sfacgk(:,:,1,ikp),apwalm)
-! equivalent reduced input k-point
-jkp=ivkik(ivk(1,ikp),ivk(2,ikp),ivk(3,ikp))
 ! count and index the occupied states
 nst1=0
 do ist=1,nstsv
-  if (evalsv(ist,jkp).lt.efermi) then
+  if (evalsv(ist,ikp).lt.efermi) then
     nst1=nst1+1
     idx(nst1)=ist
   end if
 end do
 ! calculate the wavefunctions for occupied states of the input k-point
-allocate(wfmt1(npcmtmax,natmtot,nspinor,nst1))
-allocate(wfir1(ngtot,nspinor,nst1))
-call genwfsv(.false.,.false.,nst1,idx,ngk(1,ikp),igkig(:,1,ikp),apwalm,evecfv, &
- evecsv,wfmt1,ngtot,wfir1)
+allocate(wfmt1(npcmtmax,natmtot,nspinor,nst1),wfir1(ngtc,nspinor,nst1))
+call genwfsv(.false.,.false.,nst1,idx,ngdc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+ apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 ! zero the local exchange energy variable
 ex=0.d0
 ! start loop over non-reduced k-point set
 do ik=1,nkptnr
 ! equivalent reduced k-point
   jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
-! determine q-vector
+! determine the q-vector
   iv(:)=ivk(:,ikp)-ivk(:,ik)
   iv(:)=modulo(iv(:),ngridk(:))
+! check if the q-point is in user-defined set
+  iv(:)=iv(:)*ngridq(:)
+  do i=1,3
+    if (modulo(iv(i),ngridk(i)).ne.0) goto 10
+  end do
+  iv(:)=iv(:)/ngridk(:)
   iq=iqmap(iv(1),iv(2),iv(3))
-  v(:)=vkc(:,ikp)-vkc(:,ik)
-  do ig=1,ngvec
+  vc(:)=vkc(:,ikp)-vkc(:,ik)
+  do ig=1,ngvc
 ! determine the G+q-vectors
-    vgqc(:,ig)=vgc(:,ig)+v(:)
+    vgqc(:,ig)=vgc(:,ig)+vc(:)
 ! G+q-vector length and (theta, phi) coordinates
-    call sphcrd(vgqc(:,ig),gqc(ig),tpgqc(:,ig))
+    call sphcrd(vgqc(:,ig),gqc(ig),tp)
 ! spherical harmonics for G+q-vectors
-    call genylm(lmaxo,tpgqc(:,ig),ylmgq(:,ig))
+    call genylm(lmaxo,tp,ylmgq(:,ig))
   end do
 ! structure factors for G+q
-  call gensfacgp(ngvec,vgqc,ngvec,sfacgq)
-! find the shortest G+q-vector
-  call findigp0(ngvec,gqc,igq0)
+  call gensfacgp(ngvc,vgqc,ngvc,sfacgq)
+! generate the regularised Coulomb Green's function in G+q-space
+  call gengclgq(.true.,iq,ngvc,gqc,gclgq)
 ! compute the required spherical Bessel functions
-  call genjlgpr(lnpsd,gqc,jlgqr)
+  call genjlgprmt(lnpsd,ngvc,gqc,ngvc,jlgqrmt)
 ! find the matching coefficients
   call match(ngk(1,ik),gkc(:,1,ik),tpgkc(:,:,1,ik),sfacgk(:,:,1,ik),apwalm)
 ! get the eigenvectors from file for non-reduced k-points
@@ -102,28 +102,28 @@ do ik=1,nkptnr
     end if
   end do
 ! calculate the wavefunctions for occupied states
-  call genwfsv(.false.,.false.,nst2,idx,ngk(1,ik),igkig(:,1,ik),apwalm,evecfv, &
-   evecsv,wfmt2,ngtot,wfir2)
+  call genwfsv(.false.,.false.,nst2,idx,ngdc,igfc,ngk(1,ik),igkig(:,1,ik), &
+   apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
 !--------------------------------------------!
 !    valence-valence-valence contribution    !
 !--------------------------------------------!
   do jst=1,nst2
     do ist=1,nst1
 ! calculate the complex overlap density
-      call genzrho(.true.,.true.,wfmt2(:,:,:,jst),wfir2(:,:,jst), &
+      call genzrho(.true.,.true.,ngtc,wfmt2(:,:,:,jst),wfir2(:,:,jst), &
        wfmt1(:,:,:,ist),wfir1(:,:,ist),zrhomt,zrhoir)
 ! calculate the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rcmt,npcmtmax,zrhomt,zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rcmt,igq0,gqc,jlgqr, &
-       ylmgq,sfacgq,zrhoir,npcmtmax,zvclmt,zvclir,zrho0)
+      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rcmt,ngdc,igfc,ngvc, &
+       gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir,npcmtmax,zvclmt,zvclir)
       z1=zfinp(zrhomt,zrhoir,zvclmt,zvclir)
-      t1=cfq*wiq2(iq)*(dble(zrho0)**2+aimag(zrho0)**2)
-      ex=ex-0.5d0*occmax*wkpt(ikp)*(wkptnr*dble(z1)+t1)
+      ex=ex-0.5d0*occmax*wkpt(ikp)*wqptnr*dble(z1)
     end do
   end do
+10 continue
 ! end loop over non-reduced k-point set
 end do
-deallocate(vgqc,gqc,tpgqc,jlgqr)
+deallocate(vgqc,gqc,gclgq,jlgqrmt)
 deallocate(evecfv,evecsv)
 deallocate(apwalm,ylmgq,sfacgq)
 deallocate(wfmt2,wfir2)
@@ -167,9 +167,9 @@ do is=1,nspecies
   end do
 end do
 ! add to global exchange energy
-!$OMP CRITICAL
+!$OMP CRITICAL(exxengyk_)
 engyx=engyx+ex
-!$OMP END CRITICAL
+!$OMP END CRITICAL(exxengyk_)
 deallocate(wfmt1,wfir1,wfcr,zfmt)
 deallocate(zrhomt,zrhoir,zvclmt,zvclir)
 return
@@ -196,4 +196,3 @@ end subroutine
 
 end subroutine
 
-
