@@ -171,25 +171,28 @@ if (tsyminv.and.tshift) then
          +symlat(:,3,ilspl)*v1(3)
     vtlsymc(:,isym)=vtlsymc(:,isym)-v1(:)+v2(:)
     call r3frac(epslat,vtlsymc(:,isym))
+! translation vector in Cartesian coordinates
+    call r3mv(avec,vtlsymc(:,isym),vtcsymc(:,isym))
   end do
 end if
 ! set flag for zero translation vector
 do isym=1,nsymcrys
   t1=sum(abs(vtlsymc(:,isym)))
   if (t1.lt.epslat) then
-    tvzsymc(isym)=.true.
+    tv0symc(isym)=.true.
   else
-    tvzsymc(isym)=.false.
+    tv0symc(isym)=.false.
   end if
 end do
 ! check inversion does not include a translation
 if (tsyminv) then
-  if (.not.tvzsymc(2)) tsyminv=.false.
+  if (.not.tv0symc(2)) tsyminv=.false.
 end if
 if (natmtot.gt.0) then
   v1(:)=atposl(:,1,1)-v0(:)
   t1=abs(v1(1))+abs(v1(2))+abs(v1(3))
-  if ((t1.gt.epslat).and.mp_mpi) then
+  if (mp_mpi.and.(t1.gt.epslat)) then
+    write(*,*)
     write(*,'("Info(findsymcrys): atomic basis shift (lattice) :")')
     write(*,'(3G18.10)') v1(:)
     write(*,'("See GEOMETRY.OUT for new atomic positions")')
