@@ -37,8 +37,8 @@ real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax,apwordmax),p1(nrmtmax),p1s(apwordmax)
 real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,apwordmax)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
@@ -66,7 +66,7 @@ do is=1,nspecies
         ep0(1:nr,io)=e*p0(1:nr,io)
 ! normalise radial functions
         fr(1:nr)=p0(1:nr,io)**2
-        t1=fintgt(-1,nr,rsp(:,is),fr)
+        t1=splint(nr,rsp(:,is),fr)
         t1=1.d0/sqrt(abs(t1))
         call dscal(nr,t1,p0(:,io),1)
         p1s(io)=t1*p1(nr)
@@ -74,14 +74,14 @@ do is=1,nspecies
 ! subtract linear combination of previous vectors
         do jo=1,io-1
           fr(1:nr)=p0(1:nr,io)*p0(1:nr,jo)
-          t1=-fintgt(-1,nr,rsp(:,is),fr)
+          t1=-splint(nr,rsp(:,is),fr)
           call daxpy(nr,t1,p0(:,jo),1,p0(:,io),1)
           p1s(io)=p1s(io)+t1*p1s(jo)
           call daxpy(nr,t1,ep0(:,jo),1,ep0(:,io),1)
         end do
 ! normalise radial functions again
         fr(1:nr)=p0(1:nr,io)**2
-        t1=fintgt(-1,nr,rsp(:,is),fr)
+        t1=splint(nr,rsp(:,is),fr)
         t1=abs(t1)
         if (t1.lt.1.d-25) then
           write(*,*)
@@ -128,3 +128,4 @@ end do
 return
 end subroutine
 !EOC
+
