@@ -31,7 +31,7 @@ use modmain
 implicit none
 ! local variables
 integer is,ia,ig
-real(8) t1
+real(8) v(3),t1
 complex(8) z1
 ! allocatable arrays
 complex(8), allocatable :: zfft(:)
@@ -46,19 +46,18 @@ cfunig(1)=1.d0
 do is=1,nspecies
 ! loop over atoms
   do ia=1,natoms(is)
+    v(:)=atposc(:,ia,is)
     do ig=1,ngtot
 ! structure factor
-      t1=-dot_product(vgc(:,ig),atposc(:,ia,is))
-      z1=cmplx(cos(t1),sin(t1),8)
+      t1=vgc(1,ig)*v(1)+vgc(2,ig)*v(2)+vgc(3,ig)*v(3)
+      z1=cmplx(cos(t1),-sin(t1),8)
 ! add to characteristic function in G-space
       cfunig(ig)=cfunig(ig)-ffacg(ig,is)*z1
     end do
   end do
 end do
 allocate(zfft(ngtot))
-do ig=1,ngtot
-  zfft(igfft(ig))=cfunig(ig)
-end do
+zfft(igfft(:))=cfunig(:)
 ! Fourier transform to real-space
 call zfftifc(3,ngridg,1,zfft)
 cfunir(:)=dble(zfft(:))
