@@ -55,7 +55,7 @@ irco=nrci+1
 npc=npcmt(is)
 npci=npcmti(is)
 ! de-phasing factor for spin-spirals
-if (spinsprl.and.ssdph) then
+if (ssdph) then
   t1=-0.5d0*dot_product(vqcss(:),atposc(:,ia,is))
   zq(1)=cmplx(cos(t1),sin(t1),8)
   zq(2)=conjg(zq(1))
@@ -74,10 +74,10 @@ do j=1,nstsv
       do ist=1,nstfv
         i=i+1
         z1=evecsv(i,j)
-        if (spinsprl.and.ssdph) z1=z1*zq(ispn)
+        if (ssdph) z1=z1*zq(ispn)
         if (abs(dble(z1))+abs(aimag(z1)).gt.epsocc) then
           if (.not.done(ist,jspn)) then
-            call wavefmt(lradstp,ias,ngp(jspn),apwalm(:,:,:,:,jspn), &
+            call wavefmt(lradstp,ias,ngp(jspn),apwalm(:,:,:,ias,jspn), &
              evecfv(:,ist,jspn),wfmt1(:,ist,jspn))
             done(ist,jspn)=.true.
           end if
@@ -88,7 +88,7 @@ do j=1,nstsv
     end do
   else
 ! spin-unpolarised wavefunction
-    call wavefmt(lradstp,ias,ngp,apwalm,evecfv(:,j,1),wfmt2)
+    call wavefmt(lradstp,ias,ngp,apwalm(:,:,:,ias,1),evecfv(:,j,1),wfmt2)
   end if
   do ispn=1,nspinor
     do jspn=1,nspinor
