@@ -28,8 +28,8 @@ real(8) t1
 real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax),p1(nrmtmax),q0(nrmtmax),q1(nrmtmax)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 do i=1,ndftu
   is=idftu(1,i)
   l=idftu(2,i)
@@ -43,7 +43,7 @@ do i=1,ndftu
     call rschrodint(solsc,l,fdue(l,ias),nr,rsp(:,is),vr,nn,p0,p1,q0,q1)
 ! normalise radial functions
     fr(1:nr)=p0(1:nr)**2
-    t1=fintgt(-1,nr,rsp(:,is),fr)
+    t1=splint(nr,rsp(:,is),fr)
     if (t1.lt.1.d-20) then
       write(*,*)
       write(*,'("Error(genfdufr): degenerate APW radial functions")')
