@@ -10,16 +10,15 @@ use modfxcifc
 implicit none
 ! arguments
 logical, intent(in) :: tsh
-real(8), intent(out) :: fxcmt(lmmaxvr,nrmtmax,natmtot)
-real(8), intent(out) :: fxcir(ngtot)
+real(8), intent(out) :: fxcmt(npmtmax,natmtot),fxcir(ngtot)
 ! local variables
-integer idm,is,ia,ias
-integer nr,nri,ir,i,n
+integer idm,is,ias
+integer nr,nri,ir,np,i,n
 real(8) t1
 real(8), allocatable :: rho(:),rhoup(:),rhodn(:),mag(:,:)
 real(8), allocatable :: fxc(:),fxcuu(:),fxcud(:),fxcdd(:)
 ! number of independent spin components
-n=lmmaxvr*nrmtmax
+n=npmtmax
 allocate(rho(n),fxc(n))
 if (spinpol) then
   allocate(mag(n,3))
@@ -30,58 +29,56 @@ end if
 !---------------------------!
 !     muffin-tin kernel     !
 !---------------------------!
-do is=1,nspecies
+do ias=1,natmtot
+  is=idxis(ias)
   nr=nrmt(is)
-  nri=nrmtinr(is)
-  n=lmmaxvr*nr
-  do ia=1,natoms(is)
-    ias=idxas(ia,is)
+  nri=nrmti(is)
+  np=npmt(is)
 ! compute the density in spherical coordinates
-    call rbsht(nr,nri,1,rhomt(:,:,ias),1,rho)
-    if (spinpol) then
+  call rbsht(nr,nri,rhomt(:,ias),rho)
+  if (spinpol) then
 !------------------------!
 !     spin-polarised     !
 !------------------------!
 ! magnetisation in spherical coordinates
-      do idm=1,ndmag
-        call rbsht(nr,nri,1,magmt(:,:,ias,idm),1,mag(:,idm))
-      end do
-      if (ncmag) then
+    do idm=1,ndmag
+      call rbsht(nr,nri,magmt(:,ias,idm),mag(:,idm))
+    end do
+    if (ncmag) then
 ! non-collinear (use Kubler's trick)
-        do i=1,n
+      do i=1,np
 ! compute rhoup=(rho+|m|)/2 and rhodn=(rho-|m|)/2
-          t1=sqrt(mag(i,1)**2+mag(i,2)**2+mag(i,3)**2)
-          rhoup(i)=0.5d0*(rho(i)+t1)
-          rhodn(i)=0.5d0*(rho(i)-t1)
-        end do
-      else
-! collinear
-        do i=1,n
-! compute rhoup=(rho+m_z)/2 and rhodn=(rho-m_z)/2
-          rhoup(i)=0.5d0*(rho(i)+mag(i,1))
-          rhodn(i)=0.5d0*(rho(i)-mag(i,1))
-        end do
-      end if
-! compute fxc
-      call fxcifc(fxctype,n=n,rhoup=rhoup,rhodn=rhodn,fxcuu=fxcuu,fxcud=fxcud, &
-       fxcdd=fxcdd)
-! form the scalar quantity dv/drho
-      do i=1,n
-        fxc(i)=0.25d0*(fxcuu(i)+2.d0*fxcud(i)+fxcdd(i))
+        t1=sqrt(mag(i,1)**2+mag(i,2)**2+mag(i,3)**2)
+        rhoup(i)=0.5d0*(rho(i)+t1)
+        rhodn(i)=0.5d0*(rho(i)-t1)
       end do
     else
+! collinear
+      do i=1,np
+! compute rhoup=(rho+m_z)/2 and rhodn=(rho-m_z)/2
+        rhoup(i)=0.5d0*(rho(i)+mag(i,1))
+        rhodn(i)=0.5d0*(rho(i)-mag(i,1))
+      end do
+    end if
+! compute fxc
+    call fxcifc(fxctype,n=np,rhoup=rhoup,rhodn=rhodn,fxcuu=fxcuu,fxcud=fxcud, &
+     fxcdd=fxcdd)
+! form the scalar quantity dv/drho
+    do i=1,np
+      fxc(i)=0.25d0*(fxcuu(i)+2.d0*fxcud(i)+fxcdd(i))
+    end do
+  else
 !--------------------------!
 !     spin-unpolarised     !
 !--------------------------!
-      call fxcifc(fxctype,n=n,rho=rho,fxc=fxc)
-    end if
-    if (tsh) then
+    call fxcifc(fxctype,n=np,rho=rho,fxc=fxc)
+  end if
+  if (tsh) then
 ! convert fxc to spherical harmonics if required
-      call rfsht(nr,nri,1,fxc,1,fxcmt(:,:,ias))
-    else
-      call dcopy(n,fxc,1,fxcmt(:,:,ias),1)
-    end if
-  end do
+    call rfsht(nr,nri,fxc,fxcmt(:,ias))
+  else
+    fxcmt(1:np,ias)=fxc(1:np)
+  end if
 end do
 !-----------------------------!
 !     interstitial kernel     !
