@@ -31,16 +31,13 @@ subroutine gengkvec(ngvec,ivg,vgc,vkl,vkc,gkmax,ngkmax,ngk,igkig,vgkl,vgkc)
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: ngvec
-integer, intent(in) :: ivg(3,ngvec)
+integer, intent(in) :: ngvec,ivg(3,ngvec)
 real(8), intent(in) :: vgc(3,ngvec)
 real(8), intent(in) :: vkl(3),vkc(3)
 real(8), intent(in) :: gkmax
 integer, intent(in) :: ngkmax
-integer, intent(out) :: ngk
-integer, intent(out) :: igkig(ngkmax)
-real(8), intent(out) :: vgkl(3,ngkmax)
-real(8), intent(out) :: vgkc(3,ngkmax)
+integer, intent(out) :: ngk,igkig(ngkmax)
+real(8), intent(out) :: vgkl(3,ngkmax),vgkc(3,ngkmax)
 ! local variables
 integer ig
 real(8) v(3),t0,t1
@@ -63,3 +60,4 @@ end do
 return
 end subroutine
 !EOC
+
