@@ -3,15 +3,14 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine gengqrf(vqpc,igq0,vgqc,gqc,ylmgq,sfacgq)
+subroutine gengqrf(vqpc,vgqc,gqc,jlgqr,ylmgq,sfacgq)
 use modmain
 implicit none
 ! arguments
 real(8), intent(in) :: vqpc(3)
-integer, intent(out) :: igq0
 real(8), intent(out) :: vgqc(3,ngrf),gqc(ngrf)
-complex(8), intent(out) :: ylmgq(lmmaxo,ngrf)
-complex(8), intent(out) :: sfacgq(ngrf,natmtot)
+real(8), intent(out) :: jlgqr(njcmax,nspecies,ngrf)
+complex(8), intent(out) :: ylmgq(lmmaxo,ngrf),sfacgq(ngrf,natmtot)
 ! local variables
 integer ig
 real(8) tp(2)
@@ -23,10 +22,10 @@ do ig=1,ngrf
 ! spherical harmonics for G+q-vectors
   call genylm(lmaxo,tp,ylmgq(:,ig))
 end do
-! structure factors for G+q
+! generate the spherical Bessel functions
+call genjlgpr(ngrf,gqc,jlgqr)
+! structure factors for G+q-vectors
 call gensfacgp(ngrf,vgqc,ngrf,sfacgq)
-! find the shortest G+q-vector
-call findigp0(ngrf,gqc,igq0)
 return
 end subroutine
 
