@@ -25,10 +25,26 @@ use modmain
 implicit none
 ! local variables
 integer ig,jg,i1,i2,i3,j1,j2,j3
-real(8) v1(3),v2(3),v3(3),t1
+real(8) v1(3),v2(3),v3(3)
 ! allocatable arrays
 integer, allocatable :: idx(:),ivg0(:,:)
 real(8), allocatable :: vgc0(:,:),gc0(:)
+! ensure |G| cut-off is at least twice |G+k| cut-off
+gmaxvr=max(gmaxvr,2.d0*gkmax+epslat)
+! find the G-vector grid sizes
+call gridsize(avec,gmaxvr,ngridg,ngtot,intgv)
+! allocate global G-vector arrays
+if (allocated(ivg)) deallocate(ivg)
+allocate(ivg(3,ngtot))
+if (allocated(ivgig)) deallocate(ivgig)
+allocate(ivgig(intgv(1,1):intgv(2,1),intgv(1,2):intgv(2,2), &
+ intgv(1,3):intgv(2,3)))
+if (allocated(igfft)) deallocate(igfft)
+allocate(igfft(ngtot))
+if (allocated(vgc)) deallocate(vgc)
+allocate(vgc(3,ngtot))
+if (allocated(gc)) deallocate(gc)
+allocate(gc(ngtot))
 ! allocate local arrays
 allocate(idx(ngtot),ivg0(3,ngtot))
 allocate(vgc0(3,ngtot),gc0(ngtot))
@@ -68,15 +84,6 @@ do ig=2,ngtot
     exit
   end if
 end do
-! find the number of vectors with G < gmaxvr/2
-t1=gmaxvr/2.d0
-ngv2=1
-do ig=2,ngvec
-  if (gc(ig).gt.t1) then
-    ngv2=ig-1
-    exit
-  end if
-end do
 ! generate index arrays
 do ig=1,ngtot
   i1=ivg(1,ig)
