@@ -19,7 +19,7 @@ real(8) ca,t1
 integer idx(nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
 complex(8), allocatable :: kmat(:,:),pmat(:,:,:)
 ! coupling constant of the external A-field (1/c)
 ca=1.d0/solsc
@@ -36,19 +36,19 @@ do ist=1,nstsv
 end do
 ! calculate the wavefunctions for all states of the input k-point
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv))
-allocate(wfir(ngkmax,nspinor,nstsv))
-call genwfsv(.false.,.true.,nstsv,idx,ngk(:,ik),igkig(:,:,ik),apwalm,evecfv, &
- evecsv,wfmt,ngkmax,wfir)
+allocate(wfgk(ngkmax,nspinor,nstsv))
+call genwfsv(.false.,.true.,nstsv,idx,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
+ apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
 deallocate(apwalm,evecfv,evecsv)
 ! Kohn-Sham potential and magnetic field matrix elements
 if (spinpol) then
-  call genvbmatk(vmt,vir,bsmt,bsir,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfir,h)
+  call genvbmatk(vmt,vir,bsmt,bsir,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,h)
 else
-  call genvmatk(vmt,vir,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfir,h)
+  call genvmatk(vmt,vir,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,h)
 end if
 ! add the DFT+U matrix elements if required
 call genvmmtsv(wfmt,h)
-deallocate(wfmt,wfir)
+deallocate(wfmt,wfgk)
 ! add the kinetic matrix elements in the second-variational basis
 allocate(kmat(nstsv,nstsv))
 call getkmat(ik,kmat)
