@@ -29,26 +29,20 @@ implicit none
 integer is,ia,ja,ias,jas
 integer nr,nri,ir,i
 integer ilo,jlo,io,jo
-integer nn,np,l,info
+integer nn,l,info
 real(8) e,t1
 ! automatic arrays
 logical done(natmmax)
+integer ipiv(nplorb)
 real(8) vr(nrmtmax),fr(nrmtmax)
-real(8) p0(nrmtmax,maxlorbord),p1(nrmtmax)
-real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,maxlorbord)
+real(8) p0(nrmtmax,lorbordmax),p1(nrmtmax)
+real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,lorbordmax)
 real(8) p0s(nrmtmax,nlomax),ep0s(nrmtmax,nlomax)
-! allocatable arrays
-integer, allocatable :: ipiv(:)
-real(8), allocatable :: xa(:),ya(:)
-real(8), allocatable :: a(:,:),b(:),c(:)
+real(8) xa(nplorb),ya(nplorb)
+real(8) a(nplorb,nplorb),b(nplorb),c(nplorb)
 ! external functions
-real(8) fintgt,polynom
-external fintgt,polynom
-! polynomial order
-np=max(maxlorbord+1,4)
-allocate(ipiv(np))
-allocate(xa(np),ya(np),c(np))
-allocate(a(np,np),b(np))
+real(8) splint,polynom
+external splint,polynom
 do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
@@ -76,24 +70,24 @@ do is=1,nspecies
         ep0(1:nr,jo)=e*p0(1:nr,jo)
 ! normalise radial functions
         fr(1:nr)=p0(1:nr,jo)**2
-        t1=fintgt(-1,nr,rsp(:,is),fr)
+        t1=splint(nr,rsp(:,is),fr)
         t1=1.d0/sqrt(abs(t1))
         call dscal(nr,t1,p0(:,jo),1)
         call dscal(nr,t1,ep0(:,jo),1)
 ! set up the matrix of radial derivatives
-        do i=1,np
-          ir=nr-np+i
+        do i=1,nplorb
+          ir=nr-nplorb+i
           xa(i)=rsp(ir,is)
           ya(i)=p0(ir,jo)/rsp(ir,is)
         end do
         do io=1,lorbord(ilo,is)
-          a(io,jo)=polynom(io-1,np,xa,ya,c,rmt(is))
+          a(io,jo)=polynom(io-1,nplorb,xa,ya,c,rmt(is))
         end do
       end do
 ! set up the target vector
       b(:)=0.d0
       b(lorbord(ilo,is))=1.d0
-      call dgesv(lorbord(ilo,is),1,a,np,ipiv,b,np,info)
+      call dgesv(lorbord(ilo,is),1,a,nplorb,ipiv,b,nplorb,info)
       if (info.ne.0) goto 10
 ! generate linear superposition of radial functions
       p0s(:,ilo)=0.d0
@@ -105,7 +99,7 @@ do is=1,nspecies
       end do
 ! normalise radial functions
       fr(1:nr)=p0s(1:nr,ilo)**2
-      t1=fintgt(-1,nr,rsp(:,is),fr)
+      t1=splint(nr,rsp(:,is),fr)
       t1=1.d0/sqrt(abs(t1))
       call dscal(nr,t1,p0s(:,ilo),1)
       call dscal(nr,t1,ep0s(:,ilo),1)
@@ -113,14 +107,14 @@ do is=1,nspecies
       do jlo=1,ilo-1
         if (lorbl(jlo,is).eq.l) then
           fr(1:nr)=p0s(1:nr,ilo)*p0s(1:nr,jlo)
-          t1=-fintgt(-1,nr,rsp(:,is),fr)
+          t1=-splint(nr,rsp(:,is),fr)
           call daxpy(nr,t1,p0s(:,jlo),1,p0s(:,ilo),1)
           call daxpy(nr,t1,ep0s(:,jlo),1,ep0s(:,ilo),1)
         end if
       end do
 ! normalise radial functions again
       fr(1:nr)=p0s(1:nr,ilo)**2
-      t1=fintgt(-1,nr,rsp(:,is),fr)
+      t1=splint(nr,rsp(:,is),fr)
       t1=abs(t1)
       if (t1.lt.1.d-25) goto 10
       t1=1.d0/sqrt(t1)
@@ -148,7 +142,6 @@ do is=1,nspecies
 ! end loop over atoms and species
   end do
 end do
-deallocate(ipiv,xa,ya,a,b,c)
 return
 10 continue
 write(*,*)
@@ -160,3 +153,4 @@ write(*,*)
 stop
 end subroutine
 !EOC
+
