@@ -6,26 +6,32 @@
 subroutine genpmat(tfv,tsv)
 use modmain
 use modmpi
+use modomp
 implicit none
 ! arguments
 logical, intent(in) :: tfv,tsv
 ! local variables
-integer ik
+integer ik,nthd
 if (mp_mpi) write(*,*)
-!$OMP PARALLEL DEFAULT(SHARED)
+! synchronise MPI processes
+call mpi_barrier(mpicom,ierror)
+call omp_hold(nkpt/np_mpi,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
-!$OMP CRITICAL
+!$OMP CRITICAL(genpmat_)
   write(*,'("Info(genpmat): ",I6," of ",I6," k-points")') ik,nkpt
-!$OMP END CRITICAL
+!$OMP END CRITICAL(genpmat_)
   call putpmat(tfv,tsv,ik)
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 ! synchronise MPI processes
-call mpi_barrier(mpi_comm_kpt,ierror)
+call mpi_barrier(mpicom,ierror)
 return
 end subroutine
 
