@@ -46,6 +46,8 @@ do is=1,nspecies
     r2sp(ir,is)=rsp(ir,is)**2
   end do
 end do
+! determine the fraction of the muffin-tin radius which defines the inner part
+if (fracinr.lt.0.d0) fracinr=sqrt(dble(lmmaxi)/dble(lmmaxo))
 ! set up the coarse radial meshes and find the inner part of the muffin-tin
 ! where rho is calculated with lmaxi
 if (allocated(rcmt)) deallocate(rcmt)
@@ -80,3 +82,4 @@ end do
 return
 end subroutine
 !EOC
+
