@@ -10,11 +10,10 @@ use modfxcifc
 implicit none
 ! arguments
 logical, intent(in) :: tsh
-real(8), intent(out) :: fxcmt(lmmaxvr,nrmtmax,natmtot,4,4)
-real(8), intent(out) :: fxcir(ngtot,4,4)
+real(8), intent(out) :: fxcmt(npmtmax,natmtot,4,4),fxcir(ngtot,4,4)
 ! local variables
-integer idm,is,ia,ias
-integer nr,nri,ir,ld,i,j,n
+integer idm,is,ias
+integer nr,nri,ir,np,i,j,n
 real(8) t1
 ! allocatable arrays
 real(8), allocatable :: rho(:),rhoup(:),rhodn(:)
@@ -29,7 +28,7 @@ if (.not.spinpol) then
   stop
 end if
 ! allocate local arrays
-n=lmmaxvr*nrmtmax
+n=npmtmax
 allocate(rho(n),mag(n,ndmag))
 allocate(bxc(n,ndmag),fxc(n,4,4))
 n=max(n,ngtot)
@@ -39,71 +38,68 @@ allocate(fxcuu(n),fxcud(n),fxcdd(n))
 !---------------------------!
 !     muffin-tin kernel     !
 !---------------------------!
-ld=lmmaxvr*nrmtmax
-do is=1,nspecies
+do ias=1,natmtot
+  is=idxis(ias)
   nr=nrmt(is)
-  nri=nrmtinr(is)
-  n=lmmaxvr*nr
-  do ia=1,natoms(is)
-    ias=idxas(ia,is)
+  nri=nrmti(is)
+  np=npmt(is)
 ! compute the density in spherical coordinates
-    call rbsht(nr,nri,1,rhomt(:,:,ias),1,rho)
-    do idm=1,ndmag
+  call rbsht(nr,nri,rhomt(:,ias),rho)
+  do idm=1,ndmag
 ! magnetisation in spherical coordinates
-      call rbsht(nr,nri,1,magmt(:,:,ias,idm),1,mag(:,idm))
+    call rbsht(nr,nri,magmt(:,ias,idm),mag(:,idm))
 ! B_xc in spherical coordinates
-      call rbsht(nr,nri,1,bxcmt(:,:,ias,idm),1,bxc(:,idm))
-    end do
-    if (ncmag) then
+    call rbsht(nr,nri,bxcmt(:,ias,idm),bxc(:,idm))
+  end do
+  if (ncmag) then
 ! non-collinear (use Kubler's trick)
-      do i=1,n
+    do i=1,np
 ! compute |m|
-        magm(i)=sqrt(mag(i,1)**2+mag(i,2)**2+mag(i,3)**2)
+      magm(i)=sqrt(mag(i,1)**2+mag(i,2)**2+mag(i,3)**2)
 ! compute rhoup=(rho+|m|)/2 and rhodn=(rho-|m|)/2
-        rhoup(i)=0.5d0*(rho(i)+magm(i))
-        rhodn(i)=0.5d0*(rho(i)-magm(i))
+      rhoup(i)=0.5d0*(rho(i)+magm(i))
+      rhodn(i)=0.5d0*(rho(i)-magm(i))
 ! unit vector m/|m|
-        t1=1.d0/(magm(i)+1.d-8)
-        magu(1,i)=t1*mag(i,1)
-        magu(2,i)=t1*mag(i,2)
-        magu(3,i)=t1*mag(i,3)
+      t1=1.d0/(magm(i)+1.d-8)
+      magu(1,i)=t1*mag(i,1)
+      magu(2,i)=t1*mag(i,2)
+      magu(3,i)=t1*mag(i,3)
 ! compute B_xc.(m/|m|)
-        bxcp(i)=bxc(i,1)*magu(1,i)+bxc(i,2)*magu(2,i)+bxc(i,3)*magu(3,i)
-      end do
-    else
+      bxcp(i)=bxc(i,1)*magu(1,i)+bxc(i,2)*magu(2,i)+bxc(i,3)*magu(3,i)
+    end do
+  else
 ! collinear
-      do i=1,n
+    do i=1,np
 ! compute |m| = |m_z|
-        magm(i)=abs(mag(i,1))
+      magm(i)=abs(mag(i,1))
 ! compute rhoup=(rho+|m|)/2 and rhodn=(rho-|m|)/2
-        rhoup(i)=0.5d0*(rho(i)+magm(i))
-        rhodn(i)=0.5d0*(rho(i)-magm(i))
+      rhoup(i)=0.5d0*(rho(i)+magm(i))
+      rhodn(i)=0.5d0*(rho(i)-magm(i))
 ! unit vector m/|m|
-        magu(1,i)=0.d0
-        magu(2,i)=0.d0
-        if (mag(i,1).gt.0.d0) then
-          magu(3,i)=1.d0
-        else
-          magu(3,i)=-1.d0
-        end if
+      magu(1,i)=0.d0
+      magu(2,i)=0.d0
+      if (mag(i,1).gt.0.d0) then
+        magu(3,i)=1.d0
+      else
+        magu(3,i)=-1.d0
+      end if
 ! compute B_xc.(m/|m|)
-        bxcp(i)=bxc(i,1)*magu(3,i)
-      end do
-    end if
+      bxcp(i)=bxc(i,1)*magu(3,i)
+    end do
+  end if
 ! compute f_xc in U(2) x U(2) basis
-    call fxcifc(fxctype,n=n,rhoup=rhoup,rhodn=rhodn,fxcuu=fxcuu,fxcud=fxcud, &
-     fxcdd=fxcdd)
+  call fxcifc(fxctype,n=np,rhoup=rhoup,rhodn=rhodn,fxcuu=fxcuu,fxcud=fxcud, &
+   fxcdd=fxcdd)
 ! transform f_xc to O(1) x O(3) basis (upper triangular part)
-    call tfm2213(n,fxcuu,fxcud,fxcdd,magu,magm,bxcp,ld,fxc)
-    do i=1,4
-      do j=i,4
-        if (tsh) then
+  call tfm2213(np,fxcuu,fxcud,fxcdd,magu,magm,bxcp,npmtmax,fxc)
+  do i=1,4
+    do j=i,4
+      if (tsh) then
 ! convert to spherical harmonics if required
-          call rfsht(nr,nri,1,fxc(:,i,j),1,fxcmt(:,:,ias,i,j))
-        else
-          call dcopy(n,fxc(:,i,j),1,fxcmt(:,:,ias,i,j),1)
-        end if
-      end do
+        call rfsht(nr,nri,fxc(:,i,j),fxcmt(:,ias,i,j))
+      else
+        call dcopy(np,fxc(:,i,j),fxcmt(:,ias,i,j),1)
+      end if
     end do
   end do
 end do
