@@ -3,16 +3,14 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine gentau(taumt,tauir)
+subroutine gentau
 use modmain
 use modmpi
+use modomp
 implicit none
-! arguments
-real(8), intent(out) :: taumt(npmtmax,natmtot,nspinor)
-real(8), intent(out) :: tauir(ngtot,nspinor)
 ! local variables
 integer ik,ispn,is,ias
-integer ir,npc,i,n
+integer np,npc,n,nthd
 ! allocatable arrays
 real(8), allocatable :: rfmt(:,:),rfir(:)
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
@@ -20,24 +18,26 @@ real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 taumt(:,:,:)=0.d0
 tauir(:,:)=0.d0
 ! if wavefunctions do not exist tau cannot be computed
-if (iscl.le.1) return
-!$OMP PARALLEL DEFAULT(SHARED)
+if (iscl.le.0) return
+call omp_hold(nkpt/np_mpi,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
-  call gentauk(ik,taumt,tauir)
+  call gentauk(ik)
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 allocate(rfmt(npmtmax,natmtot))
 ! convert taumt to spherical harmonics
-do ias=1,natmtot
-  is=idxis(ias)
-  npc=npcmt(is)
-  do ispn=1,nspinor
-    rfmt(1:npc,ias)=taumt(1:npc,ias,ispn)
-    call rfsht(nrcmt(is),nrcmti(is),rfmt(:,ias),taumt(:,ias,ispn))
+do ispn=1,nspinor
+  do ias=1,natmtot
+    is=idxis(ias)
+    call dcopy(npcmt(is),taumt(:,ias,ispn),1,rfmt,1)
+    call rfsht(nrcmt(is),nrcmti(is),rfmt,taumt(:,ias,ispn))
   end do
 end do
 ! symmetrise tau
@@ -57,7 +57,7 @@ if (spinpol) then
   rvfir(:,1:ndmag-1)=0.d0
   rvfir(:,ndmag)=tauir(:,1)-tauir(:,2)
   call symrf(nrcmt,nrcmti,npcmt,npmtmax,rfmt,rfir)
-  call symrvf(nrcmt,nrcmti,npcmt,npmtmax,rvfmt,rvfir)
+  call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,npmtmax,rvfmt,rvfir)
   do ias=1,natmtot
     is=idxis(ias)
     npc=npcmt(is)
@@ -71,15 +71,6 @@ else
 ! spin-unpolarised case
   call symrf(nrcmt,nrcmti,npcmt,npmtmax,taumt,tauir)
 end if
-! convert taumt to spherical coordinates
-do ias=1,natmtot
-  is=idxis(ias)
-  npc=npcmt(is)
-  do ispn=1,nspinor
-    rfmt(1:npc,ias)=taumt(1:npc,ias,ispn)
-    call rbsht(nrcmt(is),nrcmti(is),rfmt(:,ias),taumt(:,ias,ispn))
-  end do
-end do
 ! convert taumt from a coarse to a fine radial mesh
 do ispn=1,nspinor
   call rfmtctof(taumt(:,:,ispn))
@@ -87,24 +78,22 @@ end do
 ! add tau from each process and redistribute
 if (np_mpi.gt.1) then
   n=npmtmax*natmtot*nspinor
-  call mpi_allreduce(mpi_in_place,taumt,n,mpi_double_precision,mpi_sum, &
-   mpi_comm_kpt,ierror)
+  call mpi_allreduce(mpi_in_place,taumt,n,mpi_double_precision,mpi_sum,mpicom, &
+   ierror)
   n=ngtot*nspinor
-  call mpi_allreduce(mpi_in_place,tauir,n,mpi_double_precision,mpi_sum, &
-   mpi_comm_kpt,ierror)
+  call mpi_allreduce(mpi_in_place,tauir,n,mpi_double_precision,mpi_sum,mpicom, &
+   ierror)
 end if
-! add the core contribution
-call gentaucr(taumt)
-! make sure tau is positive everywhere
+! generate the core kinetic energy density
+call gentaucr
 do ispn=1,nspinor
   do ias=1,natmtot
     is=idxis(ias)
-    do i=1,npmt(is)
-      if (taumt(i,ias,ispn).lt.0.d0) taumt(i,ias,ispn)=0.d0
-    end do
-  end do
-  do ir=1,ngtot
-    if (tauir(ir,ispn).lt.0.d0) tauir(ir,ispn)=0.d0
+    np=npmt(is)
+! add the core contribution
+    taumt(1:np,ias,ispn)=taumt(1:np,ias,ispn)+taucr(1:np,ias,ispn)
+! zero tau on the inner part of the muffin-tin
+    taumt(1:npmti(is),ias,ispn)=0.d0
   end do
 end do
 deallocate(rfmt)
