@@ -24,19 +24,15 @@ implicit none
 integer, intent(in) :: ikp
 complex(8), intent(out) :: vclijjk(nstsv,nstsv,nstsv,nkpt)
 ! local variables
-integer ik,iv(3)
-integer ig,iq,igq0
-integer ist1,ist2,ist3
-real(8) cfq,v(3),t1
-complex(8) zrho01,zrho02,z1,z2
-complex(8) sfacgq0(natmtot)
+integer ik,ist1,ist2,ist3
+integer iv(3),iq,ig,i
+real(8) vc(3),tp(2)
+complex(8) z1
 ! automatic arrays
 integer idx(nstsv)
 ! allocatable arrays
-real(8), allocatable :: vgqc(:,:),tpgqc(:,:),gqc(:)
-real(8), allocatable :: jlgqr(:,:,:),jlgq0r(:,:,:)
-complex(8), allocatable :: apwalm(:,:,:,:)
-complex(8), allocatable :: evecfv(:,:),evecsv(:,:)
+real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqrmt(:,:,:)
+complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(8), allocatable :: ylmgq(:,:),sfacgq(:,:)
 complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
 complex(8), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
@@ -46,17 +42,15 @@ complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 complex(8) zfinp
 external zfinp
 ! allocate local arrays
-allocate(vgqc(3,ngvec),tpgqc(2,ngvec),gqc(ngvec))
-allocate(jlgqr(0:lnpsd,ngvec,nspecies),jlgq0r(0:lmaxo,nrcmtmax,nspecies))
+allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
+allocate(jlgqrmt(0:lnpsd,ngvc,nspecies))
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
-allocate(ylmgq(lmmaxo,ngvec),sfacgq(ngvec,natmtot))
-allocate(wfmt1(npcmtmax,natmtot,nspinor,nstsv),wfir1(ngtot,nspinor,nstsv))
-allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv),wfir2(ngtot,nspinor,nstsv))
-allocate(zrhomt(npcmtmax,natmtot,nstsv),zrhoir(ngtot,nstsv))
-allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtot))
-! factor for long-range term
-cfq=0.5d0*(omega/pi)**2
+allocate(ylmgq(lmmaxo,ngvc),sfacgq(ngvc,natmtot))
+allocate(wfmt1(npcmtmax,natmtot,nspinor,nstsv),wfir1(ngtc,nspinor,nstsv))
+allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv),wfir2(ngtc,nspinor,nstsv))
+allocate(zrhomt(npcmtmax,natmtot,nstsv),zrhoir(ngtc,nstsv))
+allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtc))
 ! get the eigenvectors from file for non-reduced k-point ikp
 call getevecfv(filext,0,vkl(:,ikp),vgkl(:,:,1,ikp),evecfv)
 call getevecsv(filext,0,vkl(:,ikp),evecsv)
@@ -67,64 +61,64 @@ do ist1=1,nstsv
   idx(ist1)=ist1
 end do
 ! calculate the wavefunctions for all states of passed non-reduced k-point ikp
-call genwfsv(.false.,.false.,nstsv,idx,ngk(1,ikp),igkig(:,1,ikp),apwalm, &
- evecfv,evecsv,wfmt2,ngtot,wfir2)
+call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+ apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
 ! start loop over reduced k-point set
 do ik=1,nkpt
+! determine the q-vector
+  iv(:)=ivk(:,ik)-ivk(:,ikp)
+  iv(:)=modulo(iv(:),ngridk(:))
+! check if the q-point is in user-defined set
+  iv(:)=iv(:)*ngridq(:)
+  do i=1,3
+    if (modulo(iv(i),ngridk(i)).ne.0) goto 10
+  end do
+  iv(:)=iv(:)/ngridk(:)
+  iq=iqmap(iv(1),iv(2),iv(3))
+  vc(:)=vkc(:,ik)-vkc(:,ikp)
+  do ig=1,ngvc
+! determine the G+q-vectors
+    vgqc(:,ig)=vgc(:,ig)+vc(:)
+! G+q-vector length and (theta, phi) coordinates
+    call sphcrd(vgqc(:,ig),gqc(ig),tp)
+! spherical harmonics for G+q-vectors
+    call genylm(lmaxo,tp,ylmgq(:,ig))
+  end do
+! structure factors for G+q
+  call gensfacgp(ngvc,vgqc,ngvc,sfacgq)
+! generate the regularised Coulomb Green's function in G+q-space
+  call gengclgq(.true.,iq,ngvc,gqc,gclgq)
+! compute the required spherical Bessel functions
+  call genjlgprmt(lnpsd,ngvc,gqc,ngvc,jlgqrmt)
+! find the matching coefficients
+  call match(ngk(1,ik),gkc(:,1,ik),tpgkc(:,:,1,ik),sfacgk(:,:,1,ik),apwalm)
 ! get the eigenvectors from file
   call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
-! find the matching coefficients
-  call match(ngk(1,ik),gkc(:,1,ik),tpgkc(:,:,1,ik),sfacgk(:,:,1,ik),apwalm)
 ! calculate the wavefunctions for all states of the reduced k-point
-  call genwfsv(.false.,.false.,nstsv,idx,ngk(1,ik),igkig(:,1,ik),apwalm, &
-   evecfv,evecsv,wfmt1,ngtot,wfir1)
-! determine q-vector
-  iv(:)=ivk(:,ik)-ivk(:,ikp)
-  iv(:)=modulo(iv(:),ngridk(:))
-  iq=iqmap(iv(1),iv(2),iv(3))
-  v(:)=vkc(:,ik)-vkc(:,ikp)
-  do ig=1,ngvec
-! determine G+q-vectors
-    vgqc(:,ig)=vgc(:,ig)+v(:)
-! G+q-vector length and (theta, phi) coordinates
-    call sphcrd(vgqc(:,ig),gqc(ig),tpgqc(:,ig))
-! spherical harmonics for G+q-vectors
-    call genylm(lmaxo,tpgqc(:,ig),ylmgq(:,ig))
-  end do
-! structure factors for G+q
-  call gensfacgp(ngvec,vgqc,ngvec,sfacgq)
-! find the shortest G+q-vector
-  call findigp0(ngvec,gqc,igq0)
-  sfacgq0(:)=sfacgq(igq0,:)
-! compute the required spherical Bessel functions
-  call genjlgpr(lnpsd,gqc,jlgqr)
-  call genjlgq0r(gqc(igq0),jlgq0r)
+  call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ik),igkig(:,1,ik), &
+   apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 !----------------------------------------------!
 !     valence-valence-valence contribution     !
 !----------------------------------------------!
   do ist2=1,nstsv
     do ist1=1,nstsv
 ! calculate the complex overlap density for all states
-      call genzrho(.true.,.true.,wfmt2(:,:,:,ist2),wfir2(:,:,ist2), &
+      call genzrho(.true.,.true.,ngtc,wfmt2(:,:,:,ist2),wfir2(:,:,ist2), &
        wfmt1(:,:,:,ist1),wfir1(:,:,ist1),zrhomt(:,:,ist1),zrhoir(:,ist1))
     end do
     do ist1=1,nstsv
 ! compute the potential and G=0 coefficient of the density
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rcmt,npcmtmax,zrhomt(:,:,ist1), &
        zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rcmt,igq0,gqc,jlgqr, &
-       ylmgq,sfacgq,zrhoir(:,ist1),npcmtmax,zvclmt,zvclir,zrho02)
+      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rcmt,ngdc,igfc,ngvc, &
+       gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist1),npcmtmax,zvclmt, &
+       zvclir)
       z1=zfinp(zrhomt(:,:,ist1),zrhoir(:,ist1),zvclmt,zvclir)
-      t1=cfq*wiq2(iq)*(dble(zrho02)**2+aimag(zrho02)**2)
-      vclijjk(ist1,ist1,ist2,ik)=wkptnr*dble(z1)+t1
+      vclijjk(ist1,ist1,ist2,ik)=wqptnr*dble(z1)
       do ist3=ist1+1,nstsv
         z1=zfinp(zrhomt(:,:,ist3),zrhoir(:,ist3),zvclmt,zvclir)
-! compute the density coefficient of the smallest G+q-vector
-        call zrhogp(jlgq0r,ylmgq(:,igq0),sfacgq0,zrhomt(:,:,ist3), &
-         zrhoir(:,ist3),zrho01)
-        z2=cfq*wiq2(iq)*conjg(zrho01)*zrho02
-        vclijjk(ist3,ist1,ist2,ik)=wkptnr*z1+z2
+        vclijjk(ist3,ist1,ist2,ik)=wqptnr*z1
       end do
     end do
   end do
@@ -134,9 +128,10 @@ do ik=1,nkpt
       vclijjk(ist3,ist1,:,ik)=conjg(vclijjk(ist1,ist3,:,ik))
     end do
   end do
+10 continue
 ! end loop over reduced k-point set
 end do
-deallocate(vgqc,tpgqc,gqc,jlgqr,jlgq0r)
+deallocate(vgqc,gqc,gclgq,jlgqrmt)
 deallocate(apwalm,evecfv,evecsv,ylmgq,sfacgq)
 deallocate(wfmt1,wfmt2,wfir1,wfir2)
 deallocate(zrhomt,zrhoir,zvclmt,zvclir)
