@@ -38,8 +38,8 @@ complex(8), allocatable :: apwalm(:,:,:,:,:)
 complex(8), allocatable :: evecfv(:,:,:),evecsv(:,:)
 complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv))
@@ -57,8 +57,8 @@ do ist=1,nstsv
   idx(ist)=ist
 end do
 ! calculate the second-variational wavefunctions for all states
-call genwfsv(.true.,.true.,nstsv,idx,ngp,igpig,apwalm,evecfv,evecsv,wfmt, &
- ngkmax,wfir)
+call genwfsv(.true.,.true.,nstsv,idx,ngridg,igfft,ngp,igpig,apwalm,evecfv, &
+ evecsv,wfmt,ngkmax,wfir)
 deallocate(apwalm,evecfv,evecsv)
 ! zero the plane wave coefficients
 wfpw(:,:,:)=0.d0
@@ -207,8 +207,8 @@ do jspn=1,nspnfv
               fr2(irc)=aimag(zsum1)
               if (irc.eq.nrci) lmax=lmaxo
             end do
-            t1=fintgt(-1,nrc,rcmt(:,is),fr1)
-            t2=fintgt(-1,nrc,rcmt(:,is),fr2)
+            t1=splint(nrc,rcmt(:,is),fr1)
+            t2=splint(nrc,rcmt(:,is),fr2)
 ! add to the H+p wavefunction
             wfpw(ihp,ispn,ist)=wfpw(ihp,ispn,ist)+z1*cmplx(t1,t2,8)
           end do
