@@ -6,6 +6,7 @@
 subroutine genzfrm(wfmt11,wfmt12,wfir11,wfir12,wfmt21,wfmt22,wfir21,wfir22, &
  zrhomt,zrhoir,zmagmt,zmagir)
 use modmain
+use modomp
 implicit none
 ! arguments
 complex(8), intent(in) ::  wfmt11(npcmtmax,natmtot),wfmt12(npcmtmax,natmtot)
@@ -15,12 +16,15 @@ complex(8), intent(in) ::  wfir21(ngtot),wfir22(ngtot)
 complex(8), intent(out) :: zrhomt(npcmtmax,natmtot),zrhoir(ngtot)
 complex(8), intent(out) :: zmagmt(npcmtmax,natmtot,ndmag),zmagir(ngtot,ndmag)
 ! local variables
-integer ld,is,ias
+integer ld,is,ias,nthd
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
 ld=npcmtmax*natmtot
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is)
+call omp_hold(natmtot,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(is) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
@@ -29,6 +33,7 @@ do ias=1,natmtot
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
