@@ -5,6 +5,7 @@
 
 subroutine genzvclmt(nr,nri,ld1,r,ld2,zrhomt,zvclmt)
 use modmain
+use modomp
 implicit none
 ! arguments
 integer, intent(in) :: nr(nspecies),nri(nspecies)
@@ -14,8 +15,11 @@ integer, intent(in) :: ld2
 complex(8), intent(in) :: zrhomt(ld2,natmtot)
 complex(8), intent(out) :: zvclmt(ld2,natmtot)
 ! local variables
-integer is,ias
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is)
+integer is,ias,nthd
+call omp_hold(natmtot,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(is) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
@@ -23,6 +27,7 @@ do ias=1,natmtot
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 return
 end subroutine
 
