@@ -20,12 +20,12 @@ call phfext(iq,is,ia,ip,fext)
 fname='DEVECSV'//trim(fext)
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,devecsv
-!$OMP CRITICAL
-open(70,file=trim(scrpath)//trim(fname),action='READ',form='UNFORMATTED', &
- access='DIRECT',recl=recl)
-read(70,rec=ik) vkl_,nstsv_,devecsv
-close(70)
-!$OMP END CRITICAL
+!$OMP CRITICAL(u226)
+open(226,file=trim(scrpath)//trim(fname),form='UNFORMATTED',access='DIRECT', &
+ recl=recl)
+read(226,rec=ik) vkl_,nstsv_,devecsv
+close(226)
+!$OMP END CRITICAL(u226)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
