@@ -41,6 +41,9 @@ integer recl,nmatmax_,nstfv_,nspnfv_
 real(8) vkl_(3),v(3)
 real(8) si(3,3),t1
 complex(8) z1
+character(256) fname
+! automatic arrays
+logical done(ngkmax)
 ! allocatable arrays
 complex(8), allocatable :: evecfv_(:,:)
 if (ikp.gt.0) then
@@ -51,12 +54,22 @@ else
 end if
 ! find the record length
 inquire(iolength=recl) vkl_,nmatmax_,nstfv_,nspnfv_,evecfv
-!$OMP CRITICAL
-open(70,file=trim(scrpath)//'EVECFV'//trim(fext),action='READ', &
- form='UNFORMATTED',access='DIRECT',recl=recl)
-read(70,rec=ik) vkl_,nmatmax_,nstfv_,nspnfv_,evecfv
-close(70)
-!$OMP END CRITICAL
+fname=trim(scrpath)//'EVECFV'//trim(fext)
+!$OMP CRITICAL(u122)
+do i=1,2
+  open(122,file=trim(fname),form='UNFORMATTED',access='DIRECT',recl=recl,err=10)
+  read(122,rec=ik,err=10) vkl_,nmatmax_,nstfv_,nspnfv_,evecfv
+  exit
+10 continue
+  if (i.eq.2) then
+    write(*,*)
+    write(*,'("Error(getevecfv): unable to read from ",A)') trim(fname)
+    write(*,*)
+    stop
+  end if
+  close(122)
+end do
+!$OMP END CRITICAL(u122)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
@@ -106,31 +119,40 @@ si(:,:)=dble(symlat(:,:,ilspl))
 !-----------------------------------------------!
 ! loop over the first-variational spins
 do jspn=1,nspnfv
-  if (tvzsymc(isym)) then
+  if (tv0symc(isym)) then
 ! translation vector is zero
     do igk=1,ngk(jspn,ik)
       evecfv_(igk,:)=evecfv(igk,:,jspn)
     end do
   else
 ! non-zero translation vector gives a phase factor
+    v(:)=vtcsymc(:,isym)
     do igk=1,ngk(jspn,ik)
       ig=igkig(igk,jspn,ik)
-      t1=-twopi*dot_product(dble(ivg(:,ig)),vtlsymc(:,isym))
+      t1=-(vgc(1,ig)*v(1)+vgc(2,ig)*v(2)+vgc(3,ig)*v(3))
       z1=cmplx(cos(t1),sin(t1),8)
       evecfv_(igk,:)=z1*evecfv(igk,:,jspn)
     end do
   end if
 ! apply spatial rotation operation (passive transformation)
+  done(1:ngk(jspn,ik))=.false.
   i=1
   do igk=1,ngk(jspn,ik)
     call r3mtv(si,vgkl(:,igk,jspn,ik),v)
     do igp=i,ngk(jspn,ik)
+      if (done(igp)) cycle
       t1=abs(v(1)-vgpl(1,igp,jspn)) &
         +abs(v(2)-vgpl(2,igp,jspn)) &
         +abs(v(3)-vgpl(3,igp,jspn))
       if (t1.lt.epslat) then
         evecfv(igp,:,jspn)=evecfv_(igk,:)
-        if (igp.eq.i) i=i+1
+        done(igp)=.true.
+        exit
+      end if
+    end do
+    do igp=i,ngk(jspn,ik)
+      if (.not.done(igp)) then
+        i=igp
         exit
       end if
     end do
@@ -165,8 +187,8 @@ if (nlotot.gt.0) then
           lm=idxlm(l,-l)
           i=ngk(jspn,ik)+idxlo(lm,ilo,ias)
           j=ngk(jspn,ik)+idxlo(lm,ilo,jas)
-          call rotzflm(symlatc(:,:,lspl),l,l,nstfv,nmatmax,evecfv_(j,1), &
-           evecfv(i,1,jspn))
+          call rotzflm(symlatc(:,:,lspl),l,l,lolmmax,nstfv,nmatmax, &
+           evecfv_(j,1),evecfv(i,1,jspn))
           evecfv(i:i+2*l,:,jspn)=z1*evecfv(i:i+2*l,:,jspn)
         end do
       end do
