@@ -42,7 +42,7 @@ do is=1,nspecies
   do ia=1,natoms(is)
     ias=idxas(ia,is)
 ! de-phasing factor for spin-spirals
-    if (spinsprl.and.ssdph) then
+    if (ssdph) then
       t1=-0.5d0*dot_product(vqcss(:),atposc(:,ia,is))
       zq(1)=cmplx(cos(t1),sin(t1),8)
       zq(2)=conjg(zq(1))
@@ -60,10 +60,10 @@ do is=1,nspecies
           do ist=1,nstfv
             i=i+1
             z1=evecsv(i,j)
-            if (spinsprl.and.ssdph) z1=z1*zq(ispn)
+            if (ssdph) z1=z1*zq(ispn)
             if (abs(dble(z1))+abs(aimag(z1)).gt.epsocc) then
               if (.not.done(ist,jspn)) then
-                call wavefmt(1,ias,ngk(jspn,ik),apwalm(:,:,:,:,jspn), &
+                call wavefmt(1,ias,ngk(jspn,ik),apwalm(:,:,:,ias,jspn), &
                  evecfv(:,ist,jspn),wfmt1(:,ist,jspn))
                 done(ist,jspn)=.true.
               end if
@@ -74,7 +74,7 @@ do is=1,nspecies
         end do
       else
 ! spin-unpolarised wavefunction
-        call wavefmt(1,ias,ngk(1,ik),apwalm,evecfv(:,j,1),wfmt2)
+        call wavefmt(1,ias,ngk(1,ik),apwalm(:,:,:,ias,1),evecfv(:,j,1),wfmt2)
       end if
 ! compute the gradient of the wavefunction
       do ispn=1,nspinor
@@ -142,3 +142,4 @@ end do
 deallocate(zfft1,zfft2)
 return
 end subroutine
+
