@@ -52,7 +52,7 @@ complex(8), intent(out) :: gzfmt(ld,3)
 ! local variables
 integer nro,iro,ir,i,j
 integer np,npi,i1,i2
-integer lmmax,l,m,lm1,lm2
+integer l,m,lm1,lm2
 ! real constant 1/sqrt(2)
 real(8), parameter :: c1=0.7071067811865475244d0
 real(8) t1,t2,t3
@@ -69,9 +69,7 @@ iro=nri+1
 npi=lmmaxi*nri
 np=npi+lmmaxo*nro
 ! store 1/r
-do ir=1,nr
-  ri(ir)=1.d0/r(ir)
-end do
+ri(:)=1.d0/r(:)
 !----------------------------------------!
 !     compute the radial derivatives     !
 !----------------------------------------!
@@ -125,7 +123,7 @@ lm1=0
 do l=0,lmaxi
   t1=sqrt(dble(l+1)/dble(2*l+3))
   if (l.gt.0) then
-    t2=sqrt(dble(l)/dble(2*l-1))
+    t2=-sqrt(dble(l)/dble(2*l-1))
   else
     t2=0.d0
   end if
@@ -151,7 +149,7 @@ do l=0,lmaxi
         t3=t2*clebgor(l,1,l-1,m,i,m+i)
         i1=lm1; i2=lm2
         do ir=1,nri
-          gzfmt(i2,j)=gzfmt(i2,j)-t3*(drmt(i1)+dble(l+1)*ri(ir)*zfmt(i1))
+          gzfmt(i2,j)=gzfmt(i2,j)+t3*(drmt(i1)+dble(l+1)*ri(ir)*zfmt(i1))
           i1=i1+lmmaxi; i2=i2+lmmaxi
         end do
       end if
@@ -163,7 +161,7 @@ lm1=0
 do l=0,lmaxo
   t1=sqrt(dble(l+1)/dble(2*l+3))
   if (l.gt.0) then
-    t2=sqrt(dble(l)/dble(2*l-1))
+    t2=-sqrt(dble(l)/dble(2*l-1))
   else
     t2=0.d0
   end if
@@ -187,7 +185,7 @@ do l=0,lmaxo
         t3=t2*clebgor(l,1,l-1,m,i,m+i)
         i1=npi+lm1; i2=npi+lm2
         do ir=iro,nr
-          gzfmt(i2,j)=gzfmt(i2,j)-t3*(drmt(i1)+dble(l+1)*ri(ir)*zfmt(i1))
+          gzfmt(i2,j)=gzfmt(i2,j)+t3*(drmt(i1)+dble(l+1)*ri(ir)*zfmt(i1))
           i1=i1+lmmaxo; i2=i2+lmmaxo
         end do
       end if
@@ -198,17 +196,24 @@ deallocate(drmt)
 !--------------------------------------------------------!
 !     convert from spherical components to Cartesian     !
 !--------------------------------------------------------!
-lmmax=lmmaxi
 i1=0
-do ir=1,nr
-  do lm1=1,lmmax
+do ir=1,nri
+  do lm1=1,lmmaxi
+    i1=i1+1
+    z1=gzfmt(i1,1)
+    gzfmt(i1,1)=c1*(z1-gzfmt(i1,2))
+    z1=c1*(z1+gzfmt(i1,2))
+    gzfmt(i1,2)=cmplx(-aimag(z1),dble(z1),8)
+  end do
+end do
+do ir=iro,nr
+  do lm1=1,lmmaxo
     i1=i1+1
     z1=gzfmt(i1,1)
     gzfmt(i1,1)=c1*(z1-gzfmt(i1,2))
     z1=c1*(z1+gzfmt(i1,2))
     gzfmt(i1,2)=cmplx(-aimag(z1),dble(z1),8)
   end do
-  if (ir.eq.nri) lmmax=lmmaxo
 end do
 return
 end subroutine
