@@ -16,19 +16,20 @@ complex(8), intent(inout) :: hq(*)
 integer is,io,jo
 integer l1,l2,l3,m1,m2,m3
 integer lm1,lm2,lm3
-real(8) t1
+real(8) t0
 complex(8) z1,zsum
 ! automatic arrays
 complex(8) x(ngpq),y(ngp)
 is=idxis(ias)
+t0=0.5d0*rmt(is)**2
 lm1=0
-do l1=0,lmaxmat
+do l1=0,lmaxapw
   do m1=-l1,l1
     lm1=lm1+1
     do io=1,apword(l1,is)
       y(:)=0.d0
       lm3=0
-      do l3=0,lmaxmat
+      do l3=0,lmaxapw
         do m3=-l3,l3
           lm3=lm3+1
           do jo=1,apword(l3,is)
@@ -47,23 +48,13 @@ do l1=0,lmaxmat
           end do
         end do
       end do
-      x(1:ngpq)=conjg(apwalmq(1:ngpq,io,lm1))
-      call zgerci(ngpq,ngp,zone,x,y,ld,hq)
-    end do
-  end do
-end do
 ! kinetic surface contribution
-t1=0.5d0*rmt(is)**2
-lm1=0
-do l1=0,lmaxmat
-  do m1=-l1,l1
-    lm1=lm1+1
-    do io=1,apword(l1,is)
-      x(1:ngpq)=conjg(apwalmq(1:ngpq,io,lm1))
       do jo=1,apword(l1,is)
-        z1=t1*apwfr(nrmt(is),1,io,l1,ias)*apwdfr(jo,l1,ias)
-        call zgerci(ngpq,ngp,z1,x,apwalm(:,jo,lm1),ld,hq)
+        z1=t0*apwfr(nrmt(is),1,io,l1,ias)*apwdfr(jo,l1,ias)
+        call zaxpy(ngp,z1,apwalm(:,jo,lm1),1,y,1)
       end do
+      x(1:ngpq)=conjg(apwalmq(1:ngpq,io,lm1))
+      call zgerci(ngpq,ngp,x,y,ld,hq)
     end do
   end do
 end do
