@@ -9,6 +9,7 @@
 subroutine hmlrad
 ! !USES:
 use modmain
+use modomp
 ! !DESCRIPTION:
 !   Calculates the radial Hamiltonian integrals of the APW and local-orbital
 !   basis functions. In other words, for atom $\alpha$, it computes integrals of
@@ -30,7 +31,7 @@ use modmain
 !BOC
 implicit none
 ! local variables
-integer is,ias
+integer is,ias,nthd
 integer nr,nri,nro
 integer iro,ir,npi,i
 integer l1,l2,l3,m2,lm2
@@ -39,13 +40,15 @@ real(8) t1
 ! allocatable arrays
 real(8), allocatable :: fr(:)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 ! begin loops over atoms and species
+call omp_hold(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(fr,is,nr,nri,nro,iro,npi) &
 !$OMP PRIVATE(l1,l2,l3,io,jo,ir,t1) &
-!$OMP PRIVATE(lm2,m2,i,ilo,jlo)
+!$OMP PRIVATE(lm2,m2,i,ilo,jlo) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   allocate(fr(nrmtmax))
@@ -58,15 +61,15 @@ do ias=1,natmtot
 !---------------------------!
 !     APW-APW integrals     !
 !---------------------------!
-  do l1=0,lmaxmat
+  do l1=0,lmaxapw
     do io=1,apword(l1,is)
-      do l3=0,lmaxmat
+      do l3=0,lmaxapw
         do jo=1,apword(l3,is)
           if (l1.eq.l3) then
             do ir=1,nr
               fr(ir)=apwfr(ir,1,io,l1,ias)*apwfr(ir,2,jo,l3,ias)*r2sp(ir,is)
             end do
-            t1=fintgt(-1,nr,rsp(:,is),fr)
+            t1=splint(nr,rsp(:,is),fr)
             haa(1,jo,l3,io,l1,ias)=t1/y00
           else
             haa(1,jo,l3,io,l1,ias)=0.d0
@@ -87,7 +90,7 @@ do ias=1,natmtot
                   fr(ir)=t1*vsmt(i,ias)
                   i=i+lmmaxo
                 end do
-                t1=fintgt(-1,nr,rsp(:,is),fr)
+                t1=splint(nr,rsp(:,is),fr)
                 haa(lm2,jo,l3,io,l1,ias)=t1
                 haa(lm2,io,l1,jo,l3,ias)=t1
               end do
@@ -101,7 +104,7 @@ do ias=1,natmtot
                   fr(ir)=t1*vsmt(i,ias)
                   i=i+lmmaxo
                 end do
-                t1=fintgt(-1,nro,rsp(iro,is),fr(iro))
+                t1=splint(nro,rsp(iro,is),fr(iro))
                 haa(lm2,jo,l3,io,l1,ias)=t1
                 haa(lm2,io,l1,jo,l3,ias)=t1
               end do
@@ -116,13 +119,13 @@ do ias=1,natmtot
 !-------------------------------------!
   do ilo=1,nlorb(is)
     l1=lorbl(ilo,is)
-    do l3=0,lmaxmat
+    do l3=0,lmaxapw
       do io=1,apword(l3,is)
         if (l1.eq.l3) then
           do ir=1,nr
             fr(ir)=lofr(ir,1,ilo,ias)*apwfr(ir,2,io,l3,ias)*r2sp(ir,is)
           end do
-          t1=fintgt(-1,nr,rsp(:,is),fr)
+          t1=splint(nr,rsp(:,is),fr)
           hloa(1,io,l3,ilo,ias)=t1/y00
         else
           hloa(1,io,l3,ilo,ias)=0.d0
@@ -142,7 +145,7 @@ do ias=1,natmtot
               fr(ir)=t1*vsmt(i,ias)
               i=i+lmmaxo
             end do
-            t1=fintgt(-1,nr,rsp(:,is),fr)
+            t1=splint(nr,rsp(:,is),fr)
             hloa(lm2,io,l3,ilo,ias)=t1
           end do
         end do
@@ -155,7 +158,7 @@ do ias=1,natmtot
               fr(ir)=t1*vsmt(i,ias)
               i=i+lmmaxo
             end do
-            t1=fintgt(-1,nro,rsp(iro,is),fr(iro))
+            t1=splint(nro,rsp(iro,is),fr(iro))
             hloa(lm2,io,l3,ilo,ias)=t1
           end do
         end do
@@ -173,7 +176,7 @@ do ias=1,natmtot
         do ir=1,nr
           fr(ir)=lofr(ir,1,ilo,ias)*lofr(ir,2,jlo,ias)*r2sp(ir,is)
         end do
-        t1=fintgt(-1,nr,rsp(:,is),fr)
+        t1=splint(nr,rsp(:,is),fr)
         hlolo(1,jlo,ilo,ias)=t1/y00
       else
         hlolo(1,jlo,ilo,ias)=0.d0
@@ -193,7 +196,7 @@ do ias=1,natmtot
             fr(ir)=t1*vsmt(i,ias)
             i=i+lmmaxo
           end do
-          t1=fintgt(-1,nr,rsp(:,is),fr)
+          t1=splint(nr,rsp(:,is),fr)
           hlolo(lm2,jlo,ilo,ias)=t1
         end do
       end do
@@ -206,7 +209,7 @@ do ias=1,natmtot
             fr(ir)=t1*vsmt(i,ias)
             i=i+lmmaxo
           end do
-          t1=fintgt(-1,nro,rsp(iro,is),fr(iro))
+          t1=splint(nro,rsp(iro,is),fr(iro))
           hlolo(lm2,jlo,ilo,ias)=t1
         end do
       end do
@@ -217,6 +220,7 @@ do ias=1,natmtot
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 return
 end subroutine
 !EOC
