@@ -10,8 +10,7 @@ use modvars
 implicit none
 ! local variables
 logical lsym(48)
-integer isym,is,ia
-integer ist,ic,m
+integer isym,iv(3)
 real(8) ts0,ts1
 real(8) boxl(3,0:3),t1
 
@@ -23,7 +22,7 @@ call timesec(ts0)
 ! check if the system is an isolated molecule
 if (molecule) ngridq(:)=1
 ! store the point group symmetries for reducing the q-point set
-if ((reduceq.eq.0).or.ultracell) then
+if (reduceq.eq.0) then
   nsymqpt=1
   symqpt(:,:,1)=symlat(:,:,1)
 else
@@ -39,17 +38,32 @@ else
     end if
   end do
 end if
-! OEP, Hartree-Fock, RPA epsilon, TDDFT, BSE or RDMFT
-if ((xctype(1).lt.0).or.(task.eq.5).or.(task.eq.105).or.(task.eq.180).or. &
- (task.eq.185).or.(task.eq.188).or.(task.eq.300).or.(task.eq.320).or. &
- (task.eq.330).or.(task.eq.331)) then
+if ((task.eq.105).or.(task.eq.180).or.(task.eq.185).or. &
+ (task.eq.320).or.(task.eq.330).or.(task.eq.331)) then
+! equal k- and q-point grids for nesting function, BSE and linear-reposnse TDDFT
   ngridq(:)=ngridk(:)
+else if ((xctype(1).lt.0).or.(task.eq.5).or.(task.eq.300).or.(task.eq.600).or. &
+ (task.eq.620).or.(task.eq.630)) then
+! allow the q-point grid to be smaller than the k-point grid for OEP,
+! Hartree-Fock, RDMFT and GW
+  if ((ngridq(1).le.0).or.(ngridq(2).le.0).or.(ngridq(3).le.0)) then
+    ngridq(:)=ngridk(:)
+  end if
+else
+  ngridq(:)=abs(ngridq(:))
 end if
-if (ultracell) then
-  ngridq(:)=2*(ngridkpa(:)-1)+1
-  call nfftifc(ngridq(1))
-  call nfftifc(ngridq(2))
-  call nfftifc(ngridq(3))
+! check that the q-point and k-point grids are commensurate for some tasks
+if ((xctype(1).lt.0).or.(task.eq.5).or.(task.eq.205).or.(task.eq.240).or. &
+ (task.eq.300).or.(task.eq.600).or.(task.eq.620).or.(task.eq.630)) then
+  iv(:)=mod(ngridk(:),ngridq(:))
+  if ((iv(1).ne.0).or.(iv(2).ne.0).or.(iv(3).ne.0)) then
+    write(*,*)
+    write(*,'("Error(init2): k-point grid incommensurate with q-point grid")')
+    write(*,'(" ngridk : ",3I6)') ngridk
+    write(*,'(" ngridq : ",3I6)') ngridq
+    write(*,*)
+    stop
+  end if
 end if
 ! allocate the q-point arrays
 if (allocated(iqmap)) deallocate(iqmap)
@@ -66,13 +80,8 @@ allocate(vqc(3,nqptnr))
 if (allocated(wqpt)) deallocate(wqpt)
 allocate(wqpt(nqptnr))
 ! set up the q-point box (offset should always be zero)
-if (ultracell) then
-  boxl(:,0)=0.d0
-  call r3mm(binv,bvecu,boxl(:,1))
-else
-  boxl(:,:)=0.d0
-  boxl(1,1)=1.d0; boxl(2,2)=1.d0; boxl(3,3)=1.d0
-end if
+boxl(:,:)=0.d0
+boxl(1,1)=1.d0; boxl(2,2)=1.d0; boxl(3,3)=1.d0
 ! generate the q-point set
 ! (note that the vectors vql and vqc are in the first Brillouin zone)
 call genppts(.true.,nsymqpt,symqpt,ngridq,nqptnr,epslat,bvec,boxl,nqpt,iqmap, &
@@ -89,6 +98,8 @@ write(*,'("Error(init2): q = 0 not in q-point set")')
 write(*,*)
 stop
 10 continue
+! find the maximum size of the spherical Bessel function array over all species
+call findnjcmax
 ! write to VARIABLES.OUT
 call writevars('nsymqpt',iv=nsymqpt)
 call writevars('symqpt',nv=9*nsymqpt,iva=symqpt)
@@ -99,49 +110,17 @@ call writevars('ivq',nv=3*nqptnr,iva=ivq)
 call writevars('vql',nv=3*nqptnr,rva=vql)
 call writevars('wqpt',nv=nqpt,rva=wqpt)
 
-!----------------------------------------------------!
-!     OEP, Hartree-Fock, RDMFT and BSE variables     !
-!----------------------------------------------------!
-if ((xctype(1).lt.0).or.(task.eq.5).or.(task.eq.185).or.(task.eq.300).or. &
- (task.eq.330).or.(task.eq.331)) then
-! determine the 1/q^2 integral weights if required
-  call genwiq2
-! output the 1/q^2 integrals to WIQ2.OUT
-  call writewiq2
-end if
-if (xctype(1).lt.0) then
-! initialise OEP residual magnitude
-  resoep=1.d0
-! find maximum core states over all species
-  ncrmax=0
-  do is=1,nspecies
-    do ia=1,natoms(is)
-      ic=0
-      do ist=1,nstsp(is)
-        if (spcore(ist,is)) then
-          do m=-ksp(ist,is),ksp(ist,is)-1
-            ic=ic+1
-          end do
-        end if
-      end do
-      ncrmax=max(ncrmax,ic)
-    end do
-  end do
-! allocate and zero the exchange potential and magnetic field
-  if (allocated(vxmt)) deallocate(vxmt)
-  allocate(vxmt(npcmtmax,natmtot))
-  vxmt(:,:)=0.d0
-  if (allocated(vxir)) deallocate(vxir)
-  allocate(vxir(ngtot))
-  vxir(:)=0.d0
-  if (spinpol) then
-    if (allocated(bxmt)) deallocate(bxmt)
-    allocate(bxmt(npcmtmax,natmtot,ndmag))
-    bxmt(:,:,:)=0.d0
-    if (allocated(bxir)) deallocate(bxir)
-    allocate(bxir(ngtot,ndmag))
-    bxir(:,:)=0.d0
-  end if
+!--------------------------------------------------------!
+!     OEP, Hartree-Fock, RDMFT, BSE and GW variables     !
+!--------------------------------------------------------!
+if ((xctype(1).lt.0).or.(task.eq.5).or.(task.eq.180).or.(task.eq.185).or. &
+ (task.eq.188).or.(task.eq.205).or.(task.eq.300).or.(task.eq.320).or. &
+ (task.eq.330).or.(task.eq.331).or.(task.eq.600).or.(task.eq.620).or. &
+ (task.eq.630)) then
+! determine the regularised Coulomb Green's function for small q
+  call gengclq
+! output the Coulomb Green's function to GCLQ.OUT
+  call writegclq
 end if
 if (task.eq.300) then
   if (allocated(vclmat)) deallocate(vclmat)
@@ -150,6 +129,14 @@ if (task.eq.300) then
   allocate(dkdc(nstsv,nstsv,nkpt))
 end if
 
+!----------------------------------------------------------!
+!     G-vector variables for coarse grid (G < 2*gkmax)     !
+!----------------------------------------------------------!
+! generate the G-vectors
+call gengvc
+! generate the characteristic function
+call gencfrc
+
 call timesec(ts1)
 timeinit=timeinit+ts1-ts0
 
