@@ -1,33 +1,49 @@
-# 1 "./libxc_master.F90"
-# 1 "<command-line>"
-# 1 "./libxc_master.F90"
-!! Copyright (C) 2003-2006 M. Marques, A. Castro, A. Rubio, G. Bertsch
+!! Copyright (C) 2003-2015 Miguel Marques
+!! All rights reserved.
 !!
-!! This program is free software; you can redistribute it and/or modify
-!! it under the terms of the GNU Lesser General Public License as published by
-!! the Free Software Foundation; either version 2, or (at your option)
-!! any later version.
+!! This file is dual-licensed under a GPL and a BSD license
 !!
-!! This program is distributed in the hope that it will be useful,
-!! but WITHOUT ANY WARRANTY; without even the implied warranty of
-!! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-!! GNU Lesser General Public License for more details.
+!! MPL License:
 !!
-!! You should have received a copy of the GNU Lesser General Public License
-!! along with this program; if not, write to the Free Software
-!! Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-!! 02110-1301, USA.
+!! This Source Code Form is subject to the terms of the Mozilla Public
+!! License, v. 2.0. If a copy of the MPL was not distributed with this
+!! file, You can obtain one at mozilla.org/MPL/2.0/.
 !!
-!! $Id: libxc.f90 3550 2007-11-19 14:32:49Z marques $
-# 27 "./libxc_master.F90"
+!! BSD License:
+!!
+!! Redistribution and use in source and binary forms, with or without
+!! modification, are permitted provided that the following conditions
+!! are met:
+!!
+!! 1. Redistributions of source code must retain the above copyright
+!! notice, this list of conditions and the following disclaimer.
+!!
+!! 2. Redistributions in binary form must reproduce the above
+!! copyright notice, this list of conditions and the following
+!! disclaimer in the documentation and/or other materials provided
+!! with the distribution.
+!!
+!! 3. Neither the name of the copyright holder nor the names of its
+!! contributors may be used to endorse or promote products derived
+!! from this software without specific prior written permission.
+!!
+!! THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+!! "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+!! LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+!! FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+!! COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
+!! INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+!! (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+!! SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+!! HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+!! STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+!! ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
+!! OF THE POSSIBILITY OF SUCH DAMAGE.
 !-------------------------------------------------------------------
 module xc_f90_types_m
-
-
-
+  implicit none
   integer, public, parameter :: xc_f90_kind = selected_real_kind(14)
 
-
   type xc_f90_pointer_t
     private
     integer, pointer :: buffer
@@ -46,18 +62,6 @@ module xc_f90_lib_m
 
   public
 
-  ! Families of xc functionals
-  integer, parameter :: &
-    XC_FAMILY_UNKNOWN = -1, &
-    XC_FAMILY_NONE = 0, &
-    XC_FAMILY_LDA = 1, &
-    XC_FAMILY_GGA = 2, &
-    XC_FAMILY_MGGA = 4, &
-    XC_FAMILY_LCA = 8, &
-    XC_FAMILY_OEP = 16, &
-    XC_FAMILY_HYB_GGA = 32, &
-    XC_FAMILY_HYB_MGGA = 64
-
   integer, parameter :: &
     XC_UNPOLARIZED = 1, & ! Spin unpolarized
     XC_POLARIZED = 2 ! Spin polarized
@@ -73,6 +77,18 @@ module xc_f90_lib_m
     XC_EXCHANGE_CORRELATION = 2, &
     XC_KINETIC = 3
 
+  ! Families of xc functionals
+  integer, parameter :: &
+    XC_FAMILY_UNKNOWN = -1, &
+    XC_FAMILY_NONE = 0, &
+    XC_FAMILY_LDA = 1, &
+    XC_FAMILY_GGA = 2, &
+    XC_FAMILY_MGGA = 4, &
+    XC_FAMILY_LCA = 8, &
+    XC_FAMILY_OEP = 16, &
+    XC_FAMILY_HYB_GGA = 32, &
+    XC_FAMILY_HYB_MGGA = 64
+
   integer, parameter :: &
     XC_FLAGS_HAVE_EXC = 1, &
     XC_FLAGS_HAVE_VXC = 2, &
@@ -82,19 +98,42 @@ module xc_f90_lib_m
     XC_FLAGS_1D = 32, &
     XC_FLAGS_2D = 64, &
     XC_FLAGS_3D = 128, &
-    XC_FLAGS_STABLE = 512, &
-    XC_FLAGS_DEVELOPMENT = 1024
+    XC_FLAGS_HYB_CAM = 256, &
+    XC_FLAGS_HYB_CAMY = 512, &
+    XC_FLAGS_HYB_VV10 = 1024, &
+    XC_FLAGS_HYB_LC = 2048, &
+    XC_FLAGS_HYB_LCY = 4096, &
+    XC_FLAGS_STABLE = 8192, &
+    XC_FLAGS_DEVELOPMENT = 16384, &
+    XC_FLAGS_NEEDS_LAPLACIAN = 32768
+
+  integer, parameter, public :: &
+    XC_TAU_EXPLICIT = 0, &
+    XC_TAU_EXPANSION = 1
+
+  integer, parameter, public :: &
+    XC_MAX_REFERENCES = 5
+
+  ! These are old names kept for compatibility
+  integer, parameter :: &
+    XC_GGA_X_BGCP = 38, &
+    XC_GGA_C_BGCP = 39, &
+    XC_GGA_C_VPBE = 83, &
+    XC_GGA_XC_LB = 160, &
+    XC_MGGA_C_CC06 = 229, &
+    XC_GGA_K_ABSR1 = 506, &
+    XC_GGA_K_ABSR2 = 507
 
-  ! These are old names keep for compatibility, and that should disappear soon
-  integer, parameter :: XC_GGA_XC_LB = 160
-  integer, parameter :: XC_GGA_K_ABSR1 = 506
-  integer, parameter :: XC_GGA_K_ABSR2 = 507
 
   !----------------------------------------------------------------
   interface
-    subroutine xc_f90_version(major, minor)
-      integer, intent(out) :: major, minor
+    subroutine xc_f90_version(major, minor, micro)
+      integer, intent(out) :: major, minor, micro
     end subroutine xc_f90_version
+
+    subroutine xc_f90_version_string(version)
+      character(len=10), intent(out) :: version
+    end subroutine xc_f90_version_string
   end interface
 
   !----------------------------------------------------------------
@@ -125,11 +164,10 @@ module xc_f90_lib_m
       type(xc_f90_pointer_t), intent(in) :: info
     end function xc_f90_info_flags
 
-    subroutine xc_f90_info_refs(info, number, str, s)
+    subroutine xc_f90_info_refs(info, number, s)
       use xc_f90_types_m
       type(xc_f90_pointer_t), intent(in) :: info
       integer, intent(inout) :: number ! number of the reference. Must be 0 in the first call
-      type(xc_f90_pointer_t), intent(inout) :: str ! this will hold a (char **) pointer
       character(len=*), intent(out) :: s ! the string that is output
     end subroutine xc_f90_info_refs
 
@@ -146,6 +184,20 @@ module xc_f90_lib_m
       use xc_f90_types_m
       integer, intent(in) :: id
     end function xc_f90_family_from_id
+
+    integer function xc_f90_number_of_functionals()
+      use xc_f90_types_m
+    end function xc_f90_number_of_functionals
+
+    integer function xc_f90_maximum_name_length()
+      use xc_f90_types_m
+    end function xc_f90_maximum_name_length
+
+    subroutine xc_f90_available_functional_numbers(list)
+      use xc_f90_types_m
+      integer, intent(out) :: list
+    end subroutine xc_f90_available_functional_numbers
+
   end interface
 
 
@@ -163,6 +215,18 @@ module xc_f90_lib_m
       use xc_f90_types_m
       type(xc_f90_pointer_t), intent(inout) :: p
     end subroutine xc_f90_func_end
+
+    subroutine xc_f90_func_set_dens_threshold(p, dens_threshold)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(inout) :: p
+      real(xc_f90_kind), intent(in) :: dens_threshold
+    end subroutine xc_f90_func_set_dens_threshold
+
+    subroutine xc_f90_func_set_ext_params(p, ext_params)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(inout) :: p
+      real(xc_f90_kind), intent(in) :: ext_params
+    end subroutine xc_f90_func_set_ext_params
   end interface
 
 
@@ -205,6 +269,15 @@ module xc_f90_lib_m
       real(xc_f90_kind), intent(out) :: v ! v(nspin) the potential
     end subroutine xc_f90_lda_vxc
 
+    subroutine xc_f90_lda_vxc_fxc(p, np, rho, v, fxc)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(in) :: p
+      integer, intent(in) :: np
+      real(xc_f90_kind), intent(in) :: rho ! rho(nspin) the density
+      real(xc_f90_kind), intent(out) :: v ! v(nspin) the potential
+      real(xc_f90_kind), intent(out) :: fxc ! v(nspin,nspin) the xc kernel
+    end subroutine xc_f90_lda_vxc_fxc
+
     subroutine xc_f90_lda_fxc(p, np, rho, fxc)
       use xc_f90_types_m
       type(xc_f90_pointer_t), intent(in) :: p
@@ -222,43 +295,6 @@ module xc_f90_lib_m
     end subroutine xc_f90_lda_kxc
   end interface
 
-
-  interface
-    subroutine xc_f90_lda_x_1d_set_par(p, interaction, bb)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(inout) :: p
-      integer, intent(in) :: interaction
-      real(xc_f90_kind), intent(in) :: bb
-    end subroutine xc_f90_lda_x_1d_set_par
-
-    subroutine xc_f90_lda_c_xalpha_set_par(p, alpha)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(inout) :: p
-      real(xc_f90_kind), intent(in) :: alpha
-    end subroutine xc_f90_lda_c_xalpha_set_par
-
-    subroutine xc_f90_lda_x_set_par(p, alpha, relativistic, omega)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(inout) :: p
-      real(xc_f90_kind), intent(in) :: alpha ! of Xalpha, set to 4/3 to obtain standard LDA
-      integer, intent(in) :: relativistic
-      real(xc_f90_kind), intent(in) :: omega
-    end subroutine xc_f90_lda_x_set_par
-
-    subroutine xc_f90_lda_c_1d_csc_set_par(p, interaction, bb)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(inout) :: p
-      integer, intent(in) :: interaction
-      real(xc_f90_kind), intent(in) :: bb
-    end subroutine xc_f90_lda_c_1d_csc_set_par
-
-    subroutine xc_f90_lda_c_2d_prm_set_par(p, N)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(inout) :: p
-      real(xc_f90_kind), intent(in) :: N
-    end subroutine xc_f90_lda_c_2d_prm_set_par
-  end interface
-
   ! GGAs
   !----------------------------------------------------------------
   interface
@@ -311,6 +347,19 @@ module xc_f90_lib_m
       real(xc_f90_kind), intent(out) :: vsigma
     end subroutine xc_f90_gga_vxc
 
+    subroutine xc_f90_gga_vxc_fxc(p, np, rho, sigma, vrho, vsigma, v2rho2, v2rhosigma, v2sigma2)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(in) :: p
+      integer, intent(in) :: np
+      real(xc_f90_kind), intent(in) :: rho
+      real(xc_f90_kind), intent(in) :: sigma
+      real(xc_f90_kind), intent(out) :: vrho
+      real(xc_f90_kind), intent(out) :: vsigma
+      real(xc_f90_kind), intent(out) :: v2rho2
+      real(xc_f90_kind), intent(out) :: v2rhosigma
+      real(xc_f90_kind), intent(out) :: v2sigma2
+    end subroutine xc_f90_gga_vxc_fxc
+
     subroutine xc_f90_gga_fxc(p, np, rho, sigma, v2rho2, v2rhosigma, v2sigma2)
       use xc_f90_types_m
       type(xc_f90_pointer_t), intent(in) :: p
@@ -335,18 +384,6 @@ module xc_f90_lib_m
     end subroutine xc_f90_gga_kxc
   end interface
 
-  !----------------------------------------------------------------
-  interface
-    subroutine xc_f90_gga_lb_set_par(p, modified, threshold, ip, qtot)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(in) :: p
-      integer, intent(in) :: modified ! should we use the modified version
-      real(xc_f90_kind), intent(in) :: threshold ! if so, the threshold to use the asymtotic version
-      real(xc_f90_kind), intent(in) :: ip ! ionization potential
-      real(xc_f90_kind), intent(in) :: qtot ! total charge
-    end subroutine xc_f90_gga_lb_set_par
-  end interface
-
 
   !----------------------------------------------------------------
   interface
@@ -362,24 +399,6 @@ module xc_f90_lib_m
   end interface
 
 
-  !----------------------------------------------------------------
-  interface
-    subroutine xc_f90_gga_x_wpbeh_set_par(p, omega)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(in) :: p
-      real(xc_f90_kind), intent(in) :: omega ! range separation
-    end subroutine xc_f90_gga_x_wpbeh_set_par
-  end interface
-
-  !----------------------------------------------------------------
-  interface
-    subroutine xc_f90_gga_x_hjs_set_par(p, omega)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(in) :: p
-      real(xc_f90_kind), intent(in) :: omega ! range separation
-    end subroutine xc_f90_gga_x_hjs_set_par
-  end interface
-
   !----------------------------------------------------------------
   interface
     subroutine xc_f90_gga_ak13_get_asymptotic(homo, asymp)
@@ -402,23 +421,12 @@ module xc_f90_lib_m
       type(xc_f90_pointer_t), intent(in) :: p
       real(xc_f90_kind), intent(out) :: omega, alpha, beta
     end subroutine xc_f90_hyb_cam_coef
-  end interface
 
-
-  !----------------------------------------------------------------
-  interface
-    subroutine xc_f90_hyb_gga_xc_hse_set_par(p, beta, omega)
+    subroutine xc_f90_nlc_coef(p, nlc_b, nlc_c)
       use xc_f90_types_m
       type(xc_f90_pointer_t), intent(in) :: p
-      real(xc_f90_kind), intent(in) :: beta ! mixing
-      real(xc_f90_kind), intent(in) :: omega ! range separation
-    end subroutine xc_f90_hyb_gga_xc_hse_set_par
-
-    subroutine xc_f90_hyb_gga_xc_pbeh_set_par(p, alpha)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(in) :: p
-      real(xc_f90_kind), intent(in) :: alpha ! mixing
-    end subroutine xc_f90_hyb_gga_xc_pbeh_set_par
+      real(xc_f90_kind), intent(out) :: nlc_b, nlc_c
+    end subroutine xc_f90_nlc_coef
   end interface
 
 
@@ -493,6 +501,34 @@ module xc_f90_lib_m
       real(xc_f90_kind), intent(out) :: vtau
     end subroutine xc_f90_mgga_vxc
 
+    subroutine xc_f90_mgga_vxc_fxc(p, np, rho, sigma, lapl, tau, &
+      vrho, vsigma, vlapl, vtau, &
+      v2rho2, v2sigma2, v2lapl2, v2tau2, v2rhosigma, v2rholapl, v2rhotau, &
+      v2sigmalapl, v2sigmatau, v2lapltau)
+
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(in) :: p
+      integer, intent(in) :: np
+      real(xc_f90_kind), intent(in) :: rho
+      real(xc_f90_kind), intent(in) :: sigma
+      real(xc_f90_kind), intent(in) :: lapl
+      real(xc_f90_kind), intent(in) :: tau
+      real(xc_f90_kind), intent(out) :: vrho
+      real(xc_f90_kind), intent(out) :: vsigma
+      real(xc_f90_kind), intent(out) :: vlapl
+      real(xc_f90_kind), intent(out) :: vtau
+      real(xc_f90_kind), intent(out) :: v2rho2
+      real(xc_f90_kind), intent(out) :: v2sigma2
+      real(xc_f90_kind), intent(out) :: v2lapl2
+      real(xc_f90_kind), intent(out) :: v2tau2
+      real(xc_f90_kind), intent(out) :: v2rhosigma
+      real(xc_f90_kind), intent(out) :: v2rholapl
+      real(xc_f90_kind), intent(out) :: v2rhotau
+      real(xc_f90_kind), intent(out) :: v2sigmalapl
+      real(xc_f90_kind), intent(out) :: v2sigmatau
+      real(xc_f90_kind), intent(out) :: v2lapltau
+    end subroutine xc_f90_mgga_vxc_fxc
+
     subroutine xc_f90_mgga_fxc(p, np, rho, sigma, lapl, tau, &
       v2rho2, v2sigma2, v2lapl2, v2tau2, v2rhosigma, v2rholapl, v2rhotau, &
       v2sigmalapl, v2sigmatau, v2lapltau)
@@ -517,18 +553,10 @@ module xc_f90_lib_m
     end subroutine xc_f90_mgga_fxc
   end interface
 
-  interface
-    subroutine xc_f90_mgga_x_tb09_set_par(p, cc)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(inout) :: p
-      real(xc_f90_kind), intent(in) :: cc
-    end subroutine xc_f90_mgga_x_tb09_set_par
-  end interface
-
-
 end module xc_f90_lib_m
 
 !! Local Variables:
 !! mode: f90
 !! coding: utf-8
 !! End:
+
