@@ -75,11 +75,13 @@ logical ptnucl
 ! nuclear radius
 real(8) rnucl(maxspecies)
 ! nuclear volume
-real(8) vnucl(maxspecies)
+real(8) volnucl(maxspecies)
 ! number of radial mesh points to nuclear radius
 integer nrnucl(maxspecies)
 ! number of coarse radial mesh points to nuclear radius
 integer nrcnucl(maxspecies)
+! nuclear Coulomb potential
+real(8), allocatable :: vcln(:,:)
 ! species electronic charge
 real(8) spze(maxspecies)
 ! species mass
@@ -137,6 +139,8 @@ real(8) nrmtscf
 integer nrmt(maxspecies)
 ! maximum nrmt over all the species
 integer nrmtmax
+! optional default muffin-tin radius for all atoms
+real(8) rmtall
 ! minimum allowed distance between muffin-tin surfaces
 real(8) rmtdelta
 ! muffin-tin radii
@@ -159,10 +163,6 @@ integer, parameter :: maxlapw=50
 integer lmaxapw
 ! (lmaxapw+1)^2
 integer lmmaxapw
-! maximum angular momentum used when evaluating the Hamiltonian matrix elements
-integer lmaxmat
-! (lmaxmat+1)^2
-integer lmmaxmat
 ! maximum angular momentum on the outer part of the muffin-tin
 integer lmaxo
 ! (lmaxo+1)^2
@@ -257,16 +257,18 @@ real(8), allocatable :: tpmae(:,:)
 !---------------------------------------------!
 !     electric field and vector potential     !
 !---------------------------------------------!
-! efieldpol is .true. if a polarising constant electric field is applied
-logical efieldpol
+! tefield is .true. if a polarising constant electric field is applied
+logical tefield
 ! electric field vector in Cartesian coordinates
 real(8) efieldc(3)
 ! electric field vector in lattice coordinates
 real(8) efieldl(3)
-! afieldpol is .true. if a polarising constant vector potential is applied
-logical afieldpol
-! vector potential which couples to paramagnetic current
+! tafield is .true. if a constant vector potential is applied
+logical tafield
+! vector potential A-field which couples to paramagnetic current
 real(8) afieldc(3)
+! A-field in lattice coordinates
+real(8) afieldl(3)
 
 !----------------------------!
 !     symmetry variables     !
@@ -294,10 +296,11 @@ logical tsyminv
 integer, parameter :: maxsymcrys=192
 ! number of crystal symmetries
 integer nsymcrys
-! crystal symmetry translation vector in lattice coordinates
+! crystal symmetry translation vector in lattice and Cartesian coordinates
 real(8) vtlsymc(3,maxsymcrys)
-! tvzsymc is .true. if the translation vector is zero
-logical tvzsymc(maxsymcrys)
+real(8) vtcsymc(3,maxsymcrys)
+! tv0symc is .true. if the translation vector is zero
+logical tv0symc(maxsymcrys)
 ! spatial rotation element in lattice point group for each crystal symmetry
 integer lsplsymc(maxsymcrys)
 ! global spin rotation element in lattice point group for each crystal symmetry
@@ -320,26 +323,34 @@ integer, allocatable :: lspnsyms(:,:)
 real(8) gmaxvr
 ! G-vector grid sizes
 integer ngridg(3)
+! G-vector grid sizes for coarse grid (G < 2*gkmax)
+integer ngdc(3)
 ! total number of G-vectors
 integer ngtot
+! total number of G-vectors for coarse grid (G < 2*gkmax)
+integer ngtc
 ! integer grid intervals for each direction
 integer intgv(2,3)
 ! number of G-vectors with G < gmaxvr
 integer ngvec
-! number of G-vectors with G < gmaxvr/2
-integer ngv2
+! number of G-vectors for coarse grid (G < 2*gkmax)
+integer ngvc
 ! G-vector integer coordinates (i1,i2,i3)
 integer, allocatable :: ivg(:,:)
 ! map from (i1,i2,i3) to G-vector index
 integer, allocatable :: ivgig(:,:,:)
-! map from G-vector array to FFT array
+! map from G-vector index to FFT array
 integer, allocatable :: igfft(:)
+! map from G-vector index to FFT array for coarse grid (G < 2*gkmax)
+integer, allocatable :: igfc(:)
 ! G-vectors in Cartesian coordinates
 real(8), allocatable :: vgc(:,:)
 ! length of G-vectors
 real(8), allocatable :: gc(:)
+! Coulomb Green's function in G-space = 4 pi / G^2
+real(8), allocatable :: gclg(:)
 ! spherical Bessel functions j_l(|G|R_mt)
-real(8), allocatable :: jlgr(:,:,:)
+real(8), allocatable :: jlgrmt(:,:,:)
 ! spherical harmonics of the G-vectors
 complex(8), allocatable :: ylmg(:,:)
 ! structure factors for the G-vectors
@@ -350,6 +361,8 @@ real(8), allocatable :: ffacg(:,:)
 complex(8), allocatable :: cfunig(:)
 ! characteristic function in real-space: 0 inside the muffin-tins and 1 outside
 real(8), allocatable :: cfunir(:)
+! characteristic function in real-space for coarse grid (G < 2*gkmax)
+real(8), allocatable :: cfrc(:)
 
 !---------------------------!
 !     k-point variables     !
@@ -430,6 +443,8 @@ complex(8), allocatable :: sfacgk(:,:,:,:)
 !---------------------------!
 ! q-point grid sizes
 integer ngridq(3)
+! integer grid intervals for the q-points
+integer intq(2,3)
 ! type of reduction to perform on q-point set (see reducek)
 integer reduceq
 ! number of point group symmetries used for q-point reduction
@@ -446,40 +461,24 @@ integer, allocatable :: iqmap(:,:,:)
 integer, allocatable :: iqmapnr(:,:,:)
 ! locations of q-points on integer grid
 integer, allocatable :: ivq(:,:)
+! map from (i1,i2,i3) to q-vector index
+integer, allocatable :: ivqiq(:,:,:)
+! map from q-vector index to FFT array
+integer, allocatable :: iqfft(:)
 ! q-points in lattice coordinates
 real(8), allocatable :: vql(:,:)
 ! q-points in Cartesian coordinates
 real(8), allocatable :: vqc(:,:)
+! length of q-vectors
+real(8), allocatable :: qc(:)
 ! q-point weights
 real(8), allocatable :: wqpt(:)
-! weight for each non-reduced q-opint
+! weight for each non-reduced q-point
 real(8) wqptnr
-! index to q = 0 point
+! index of q = 0 point
 integer iq0
-! weights associated with the integral of 1/q^2
-real(8), allocatable :: wiq2(:)
-
-!-----------------------------!
-!     ultracell variables     !
-!-----------------------------!
-! ultracell is .true. if an ultracell is to be used
-logical ultracell
-! kappa-point grid sizes
-integer ngridkpa(3)
-! ultracell lattice vectors stored column-wise
-real(8) avecu(3,3)
-! ultracell reciprocal lattice vectors
-real(8) bvecu(3,3)
-! ultracell volume and Brillouin zone volume
-real(8) omegau,omegabzu
-! number of kappa-points
-integer nkpa
-! kappa-points in ultracell lattice coordinates
-real(8), allocatable :: vkpalu(:,:)
-! kappa-points in unit cell lattice coordinates
-real(8), allocatable :: vkpal(:,:)
-! kappa-points in Cartesian coordinates
-real(8), allocatable :: vkpac(:,:)
+! regularised Coulomb Green's function in q-space
+real(8), allocatable :: gclq(:)
 
 !-----------------------------------------------------!
 !     spherical harmonic transform (SHT) matrices     !
@@ -517,73 +516,75 @@ character(512) xcdescr
 integer xcspin
 ! exchange-correlation functional density gradient requirement
 integer xcgrad
-! small constant added to the up-density to stabilise non-collinear GGA
+! small constant used to stabilise non-collinear GGA
 real(8) dncgga
-! Tran-Blaha '09 constant c [Phys. Rev. Lett. 102, 226401 (2009)]
-real(8) c_tb09
-! tc_tb09 is .true. if the Tran-Blaha constant has been read in
-logical tc_tb09
-! muffin-tin charge density
-real(8), allocatable :: rhomt(:,:)
-! interstitial real-space charge density
-real(8), allocatable :: rhoir(:)
+! muffin-tin and interstitial charge density
+real(8), allocatable :: rhomt(:,:),rhoir(:)
 ! trhonorm is .true. if the density is to be normalised after every iteration
 logical trhonorm
-! muffin-tin magnetisation vector field
-real(8), allocatable :: magmt(:,:,:)
-! interstitial magnetisation vector field
-real(8), allocatable :: magir(:,:)
-! amount of smoothing to be applied to the density; this is the number of
-! 3-point running averages performed on the radial functions in the muffin-tins
+! muffin-tin and interstitial magnetisation vector field
+real(8), allocatable :: magmt(:,:,:),magir(:,:)
+! tcden is .true. if the current density is to be calculated
+logical tcden
+! muffin-tin and interstitial current density vector field
+real(8), allocatable :: cdmt(:,:,:),cdir(:,:)
+! amount of smoothing to be applied to the exchange-correlation potentials and
+! magnetic field
 integer msmooth
-! muffin-tin Coulomb potential
-real(8), allocatable :: vclmt(:,:)
-! interstitial real-space Coulomb potential
-real(8), allocatable :: vclir(:)
+! muffin-tin and interstitial Coulomb potential
+real(8), allocatable :: vclmt(:,:),vclir(:)
 ! Poisson solver pseudocharge density constant
 integer npsd
 ! lmaxo+npsd+1
 integer lnpsd
-! muffin-tin exchange energy density
-real(8), allocatable :: exmt(:,:)
-! interstitial real-space exchange energy density
-real(8), allocatable :: exir(:)
-! muffin-tin correlation energy density
-real(8), allocatable :: ecmt(:,:)
-! interstitial real-space correlation energy density
-real(8), allocatable :: ecir(:)
-! muffin-tin exchange-correlation potential
-real(8), allocatable :: vxcmt(:,:)
-! interstitial real-space exchange-correlation potential
-real(8), allocatable :: vxcir(:)
-! muffin-tin Kohn-Sham effective potential
-real(8), allocatable :: vsmt(:,:)
-! interstitial Kohn-Sham effective potential
-real(8), allocatable :: vsir(:)
+! muffin-tin and interstitial exchange energy density
+real(8), allocatable :: exmt(:,:),exir(:)
+! muffin-tin and interstitial correlation energy density
+real(8), allocatable :: ecmt(:,:),ecir(:)
+! muffin-tin and interstitial exchange-correlation potential
+real(8), allocatable :: vxcmt(:,:),vxcir(:)
+! constant part of exchange-correlation potential
+real(8) vxc0
+! muffin-tin and interstitial Kohn-Sham effective potential
+real(8), allocatable :: vsmt(:,:),vsir(:)
 ! G-space interstitial Kohn-Sham effective potential
 complex(8), allocatable :: vsig(:)
-! trimvg is .true. if vsig should be trimmed for |G| > gmaxvr/2
-logical trimvg
-! muffin-tin exchange-correlation magnetic field
-real(8), allocatable :: bxcmt(:,:,:)
-! interstitial exchange-correlation magnetic field
-real(8), allocatable :: bxcir(:,:)
+! muffin-tin and interstitial exchange-correlation magnetic field
+real(8), allocatable :: bxcmt(:,:,:),bxcir(:,:)
 ! muffin-tin Kohn-Sham effective magnetic field in spherical coordinates
 real(8), allocatable :: bsmt(:,:,:)
 ! interstitial Kohn-Sham effective magnetic field
 real(8), allocatable :: bsir(:,:)
-! spin-orbit coupling radial function
-real(8), allocatable :: socfr(:,:)
 ! nosource is .true. if the field is to be made source-free
 logical nosource
-! trst is .true. if reduced Stoner theory (RST) is to be used
-logical trst
-! RST scale factor
-real(8) rstsf
+! tssxc is .true. if scaled spin exchange-correlation (SSXC) is to be used
+logical tssxc
+! SSXC scaling factor
+real(8) ssxc
+! spin-orbit coupling radial function
+real(8), allocatable :: socfr(:,:)
+! kinetic energy density
+real(8), allocatable :: taumt(:,:,:),tauir(:,:)
+! core kinetic energy density
+real(8), allocatable :: taucr(:,:,:)
+! taudft is .true. if meta-GGA is to be treated as a tau-DFT functional
+logical taudft
+! tau-DFT exchange-correlation potential
+real(8), allocatable :: wxcmt(:,:),wxcir(:)
+! tau-DFT Kohn-Sham potential
+real(8), allocatable :: wsmt(:,:),wsir(:)
+! Tran-Blaha '09 constant c [Phys. Rev. Lett. 102, 226401 (2009)]
+real(8) c_tb09
+! tc_tb09 is .true. if the Tran-Blaha constant has been read in
+logical tc_tb09
 ! if trdstate is .true. the density and potential can be read from STATE.OUT
 logical trdstate
-! temperature in degrees kelvin
+! temperature in degrees Kelvin
 real(8) tempk
+! maximum number of iterations used for inverting the Kohn-Sham equations
+integer maxitksi
+! step size used for inverting the Kohn-Sham equations
+real(8) tauksi
 
 !--------------------------!
 !     mixing variables     !
@@ -592,9 +593,8 @@ real(8) tempk
 integer mixtype
 ! mixing type description
 character(256) mixdescr
-! adaptive mixing parameter
-real(8) beta0
-real(8) betamax
+! adaptive mixing parameters (formerly beta0 and betamax)
+real(8) amixpm(2)
 ! subspace dimension for Broyden mixing
 integer mixsdb
 ! Broyden mixing parameters alpha and w0
@@ -641,6 +641,8 @@ real(8), allocatable :: mommt(:,:)
 real(8) mommttot(3)
 ! total current
 real(8) curtot(3)
+! total current magnitude
+real(8) curtotm
 
 !-----------------------------------------!
 !     APW and local-orbital variables     !
@@ -653,6 +655,8 @@ integer, parameter :: maxapword=4
 integer apword(0:maxlapw,maxspecies)
 ! maximum of apword over all angular momenta and species
 integer apwordmax
+! polynomial order used for APW radial derivatives
+integer npapw
 ! APW initial linearisation energies
 real(8) apwe0(maxapword,0:maxlapw,maxspecies)
 ! APW linearisation energies
@@ -668,7 +672,7 @@ real(8), allocatable :: apwdfr(:,:,:)
 ! maximum number of local-orbitals
 integer, parameter :: maxlorb=200
 ! maximum allowable local-orbital order
-integer, parameter :: maxlorbord=4
+integer, parameter :: maxlorbord=5
 ! number of local-orbitals
 integer nlorb(maxspecies)
 ! maximum nlorb over all species
@@ -677,6 +681,10 @@ integer nlomax
 integer nlotot
 ! local-orbital order
 integer lorbord(maxlorb,maxspecies)
+! maximum lorbord over all species
+integer lorbordmax
+! polynomial order used for local-orbital radial derivatives
+integer nplorb
 ! local-orbital angular momentum
 integer lorbl(maxlorb,maxspecies)
 ! maximum lorbl over all species
@@ -747,6 +755,8 @@ integer minitefv,maxitefv
 real(8) befvit
 ! iterative solver convergence tolerance
 real(8) epsefvit
+! type of eigenvalue solver to be used
+integer evtype
 
 !--------------------------------------------!
 !     eigenvalue and occupancy variables     !
@@ -773,7 +783,7 @@ real(8) mstar
 real(8) occmax
 ! convergence tolerance for occupancies
 real(8) epsocc
-! second-variational occupation number array
+! second-variational occupation numbers
 real(8), allocatable :: occsv(:,:)
 ! Fermi energy for second-variational states
 real(8) efermi
@@ -867,6 +877,15 @@ real(8), allocatable :: forcetot(:,:)
 real(8), allocatable :: forcetotp(:,:)
 ! maximum force magnitude over all atoms
 real(8) forcemax
+! tfav0 is .true. if the average force should be zero in order to prevent
+! translation of the atomic basis
+logical tfav0
+! average force
+real(8) forceav(3)
+! atomic position optimisation type
+!  0 : no optimisation
+!  1 : unconstrained optimisation
+integer atpopt
 ! maximum number of atomic position optimisation steps
 integer maxatpstp
 ! default step size parameter for atomic position optimisation
@@ -875,6 +894,9 @@ real(8) tau0atp
 real(8), allocatable :: tauatp(:)
 ! number of strain tensors
 integer nstrain
+! current strain tensor
+integer istrain
+data istrain / 0 /
 ! strain tensors
 real(8) strain(3,3,9)
 ! infinitesimal displacement parameter multiplied by the strain tensor for
@@ -984,8 +1006,8 @@ integer np3d(3)
 integer ncrmax
 ! maximum number of OEP iterations
 integer maxitoep
-! initial value and scaling factors for OEP step size
-real(8) tauoep(3)
+! OEP step size
+real(8) tauoep
 ! magnitude of the OEP residual
 real(8) resoep
 ! exchange potential and magnetic field
@@ -1009,6 +1031,9 @@ integer ngrf
 integer nwrf
 ! complex response function frequencies
 complex(8), allocatable :: wrf(:)
+! maximum number of spherical Bessel functions on the coarse radial mesh over
+! all species
+integer njcmax
 
 !-------------------------------------------------!
 !     Bethe-Salpeter equation (BSE) variables     !
@@ -1125,7 +1150,7 @@ real(8), parameter :: amu=amu_si/em_si
 !---------------------------------!
 ! code version
 integer version(3)
-data version / 4,0,15 /
+data version / 5,4,24 /
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
