@@ -23,8 +23,6 @@ real(8), allocatable :: vqlwrt(:,:)
 real(8) mustar
 ! number of temperatures for the Eliashberg equations and thermal properties
 integer ntemp
-! energy tolerance for the Fermi surface average of the electron-phonon coupling
-real(8) epseph
 
 !-----------------------------!
 !     supercell variables     !
@@ -51,8 +49,10 @@ real(8), allocatable :: vkqc(:,:)
 real(8), allocatable :: vgqc(:,:)
 ! G+q-vector lengths
 real(8), allocatable :: gqc(:)
+! regularised Coulomb Green's function in G+q-space
+real(8), allocatable :: gclgq(:)
 ! spherical Bessel functions j_l(|G+q|R_mt)
-real(8), allocatable :: jlgqr(:,:,:)
+real(8), allocatable :: jlgqrmt(:,:,:)
 ! spherical harmonics for G+q-vectors
 complex(8), allocatable :: ylmgq(:,:)
 ! structure factors for G+q-vectors
