@@ -40,7 +40,7 @@ call init0
 call readstate
 ! allocate local arrays
 allocate(fr(nrmtmax,3))
-open(50,file='MOSSBAUER.OUT',action='WRITE',form='FORMATTED')
+open(50,file='MOSSBAUER.OUT',form='FORMATTED')
 ! loop over species
 do is=1,nspecies
   nr=nrmt(is)
@@ -68,7 +68,7 @@ do is=1,nspecies
     rhon=fr(nrn,1)*y00
     fr(1:nrn,1)=fr(1:nrn,1)*r2sp(1:nrn,is)
     t1=fintgt(-1,nrn,rsp(:,is),fr)
-    rhoa=fourpi*y00*t1/vnucl(is)
+    rhoa=fourpi*y00*t1/volnucl(is)
     write(50,*)
     write(50,*)
     write(50,'("Species : ",I4," (",A,"), atom : ",I4)') is,trim(spsymb(is)),ia
