@@ -15,7 +15,7 @@ do is=1,nspecies
 ! approximate nuclear radius
   rnucl(is)=radnucl(spzn(is))
 ! nuclear volume
-  vnucl(is)=(4.d0/3.d0)*pi*rnucl(is)**3
+  volnucl(is)=(4.d0/3.d0)*pi*rnucl(is)**3
 ! number of radial mesh points to nuclear radius
   nrnucl(is)=1
   do ir=1,nrmt(is)
