@@ -6,12 +6,13 @@
 subroutine oepmain
 use modmain
 use modmpi
+use modomp
 implicit none
 ! local variables
 integer ik,idm,is,ias
 integer nrc,nrci,np,npc
-integer it,n
-real(8) tau,resp,t1
+integer n,nthd,it
+real(8) t1
 ! allocatable arrays
 real(8), allocatable :: dvxmt(:,:),dvxir(:)
 real(8), allocatable :: dbxmt(:,:,:),dbxir(:,:)
@@ -21,7 +22,11 @@ complex(8), allocatable :: vclcv(:,:,:,:),vclvv(:,:,:)
 ! external functions
 real(8) rfinpc
 external rfinpc
-if (iscl.lt.1) return
+! initialise the OEP exchange potential
+if (iscl.le.0) then
+  call initoep
+  return
+end if
 ! calculate Coulomb matrix elements
 allocate(vclcv(ncrmax,natmtot,nstsv,nkpt),vclvv(nstsv,nstsv,nkpt))
 call oepvcl(vclcv,vclvv)
@@ -32,21 +37,11 @@ if (spinpol) then
   allocate(dbxmt(npcmtmax,natmtot,ndmag),dbxir(ngtot,ndmag))
   allocate(rvfmt(npmtmax,natmtot,ndmag),rvfir(ngtot,ndmag))
 end if
-! set the exchange potential and magnetic field to zero
-vxmt(:,:)=0.d0
-vxir(:)=0.d0
-if (spinpol) then
-  bxmt(:,:,:)=0.d0
-  bxir(:,:)=0.d0
-end if
-resp=0.d0
-! initial step size
-tau=tauoep(1)
 !------------------------------!
 !     start iteration loop     !
 !------------------------------!
 do it=1,maxitoep
-  if ((mod(it,10).eq.0).and.mp_mpi) then
+  if (mp_mpi.and.(mod(it,10).eq.0)) then
     write(*,'("Info(oepmain): done ",I4," iterations of ",I4)') it,maxitoep
   end if
 ! zero the residuals
@@ -57,7 +52,9 @@ do it=1,maxitoep
     dbxir(:,:)=0.d0
   end if
 ! calculate the k-dependent residuals
-!$OMP PARALLEL DEFAULT(SHARED)
+  call omp_hold(nkpt/np_mpi,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
   do ik=1,nkpt
 ! distribute among MPI processes
@@ -66,24 +63,28 @@ do it=1,maxitoep
   end do
 !$OMP END DO
 !$OMP END PARALLEL
+  call omp_free(nthd)
 ! add residuals from each process and redistribute
   if (np_mpi.gt.1) then
     n=npcmtmax*natmtot
     call mpi_allreduce(mpi_in_place,dvxmt,n,mpi_double_precision,mpi_sum, &
-     mpi_comm_kpt,ierror)
+     mpicom,ierror)
     call mpi_allreduce(mpi_in_place,dvxir,ngtot,mpi_double_precision, &
-     mpi_sum,mpi_comm_kpt,ierror)
+     mpi_sum,mpicom,ierror)
     if (spinpol) then
       n=n*ndmag
       call mpi_allreduce(mpi_in_place,dbxmt,n,mpi_double_precision,mpi_sum, &
-       mpi_comm_kpt,ierror)
+       mpicom,ierror)
       n=ngtot*ndmag
       call mpi_allreduce(mpi_in_place,dbxir,n,mpi_double_precision,mpi_sum, &
-       mpi_comm_kpt,ierror)
+       mpicom,ierror)
     end if
   end if
 ! convert muffin-tin residuals to spherical harmonics
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is,nrc,nrci,idm)
+  call omp_hold(natmtot,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(is,nrc,nrci,idm) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
   do ias=1,natmtot
     is=idxis(ias)
@@ -96,9 +97,10 @@ do it=1,maxitoep
   end do
 !$OMP END DO
 !$OMP END PARALLEL
+  call omp_free(nthd)
 ! symmetrise the residuals
   call symrf(nrcmt,nrcmti,npcmt,npmtmax,rfmt1,dvxir)
-  if (spinpol) call symrvf(nrcmt,nrcmti,npcmt,npmtmax,rvfmt,dbxir)
+  if (spinpol) call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,npmtmax,rvfmt,dbxir)
 ! magnitude of residuals
   resoep=sqrt(abs(rfinpc(npmtmax,rfmt1,dvxir,rfmt1,dvxir)))
   do idm=1,ndmag
@@ -106,18 +108,11 @@ do it=1,maxitoep
     resoep=resoep+sqrt(abs(t1))
   end do
   resoep=resoep/omega
-! adjust step size
-  if (it.gt.1) then
-    if (resoep.gt.resp) then
-      tau=tau*tauoep(2)
-    else
-      tau=tau*tauoep(3)
-    end if
-  end if
-  resp=resoep
 ! update exchange potential and magnetic field
+  call omp_hold(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt2,is,nrc,nrci,npc,idm)
+!$OMP PRIVATE(rfmt2,is,nrc,nrci,npc,idm) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
   do ias=1,natmtot
     allocate(rfmt2(npcmtmax))
@@ -128,25 +123,28 @@ do it=1,maxitoep
 ! convert residual to spherical coordinates
     call rbsht(nrc,nrci,rfmt1(:,ias),rfmt2)
 ! subtract from exchange potential
-    vxmt(1:npc,ias)=vxmt(1:npc,ias)-tau*rfmt2(1:npc)
+    vxmt(1:npc,ias)=vxmt(1:npc,ias)-tauoep*rfmt2(1:npc)
 ! repeat for exchange magnetic field
     do idm=1,ndmag
       call rbsht(nrc,nrci,rvfmt(:,ias,idm),rfmt2)
-      bxmt(1:npc,ias,idm)=bxmt(1:npc,ias,idm)-tau*rfmt2(1:npc)
+      bxmt(1:npc,ias,idm)=bxmt(1:npc,ias,idm)-tauoep*rfmt2(1:npc)
     end do
     deallocate(rfmt2)
   end do
 !$OMP END DO
 !$OMP END PARALLEL
-  vxir(:)=vxir(:)-tau*dvxir(:)
+  call omp_free(nthd)
+  vxir(:)=vxir(:)-tauoep*dvxir(:)
   do idm=1,ndmag
-    bxir(:,idm)=bxir(:,idm)-tau*dbxir(:,idm)
+    bxir(:,idm)=bxir(:,idm)-tauoep*dbxir(:,idm)
   end do
 ! end iteration loop
 end do
 ! convert the exchange potential and field to spherical harmonics
+call omp_hold(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(is,nrc,nrci,idm)
+!$OMP PRIVATE(is,nrc,nrci,idm) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
@@ -159,6 +157,7 @@ do ias=1,natmtot
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 ! convert potential and field from a coarse to a fine radial mesh
 call rfmtctof(rfmt1)
 do idm=1,ndmag
@@ -179,13 +178,15 @@ do idm=1,ndmag
 end do
 ! symmetrise the exchange potential and field
 call symrf(nrmt,nrmti,npmt,npmtmax,vxcmt,vxcir)
-if (spinpol) call symrvf(nrmt,nrmti,npmt,npmtmax,bxcmt,bxcir)
+if (spinpol) call symrvf(.true.,ncmag,nrmt,nrmti,npmt,npmtmax,bxcmt,bxcir)
 deallocate(rfmt1,rfir,vclcv,vclvv)
 deallocate(dvxmt,dvxir)
 if (spinpol) then
   deallocate(rvfmt,rvfir)
   deallocate(dbxmt,dbxir)
 end if
+! set the constant part of the exchange potential equal to that of LDA/GGA
+call rfint0(vxc0,vxcmt,vxcir)
 return
 end subroutine
 
