@@ -33,8 +33,8 @@ real(8) t1
 ! automatic arrays
 real(8) fr(nrmtmax)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
@@ -45,7 +45,7 @@ do ias=1,natmtot
     l=lorbl(ilo,is)
     do io=1,apword(l,is)
       fr(1:nr)=apwfr(1:nr,1,io,l,ias)*lofr(1:nr,1,ilo,ias)*r2sp(1:nr,is)
-      t1=fintgt(-1,nr,rsp(:,is),fr)
+      t1=splint(nr,rsp(:,is),fr)
       oalo(io,ilo,ias)=t1
     end do
   end do
@@ -57,7 +57,7 @@ do ias=1,natmtot
     do jlo=1,nlorb(is)
       if (lorbl(jlo,is).eq.l) then
         fr(1:nr)=lofr(1:nr,1,ilo,ias)*lofr(1:nr,1,jlo,ias)*r2sp(1:nr,is)
-        t1=fintgt(-1,nr,rsp(:,is),fr)
+        t1=splint(nr,rsp(:,is),fr)
         ololo(ilo,jlo,ias)=t1
       end if
     end do
