@@ -6,16 +6,18 @@
 subroutine phdelete
 use modphonon
 implicit none
+! local variables
+integer iostat
 character(256) fext
 ! construct the phonon file extension
 call phfext(iqph,isph,iaph,ipph,fext)
 ! delete the eigenvalue/vector files
-open(70,file='DEVALFV'//trim(fext))
-close(70,status='DELETE')
-open(70,file='DEVECFV'//trim(fext))
-close(70,status='DELETE')
-open(70,file='DEVECSV'//trim(fext))
-close(70,status='DELETE')
+open(220,file='DEVALFV'//trim(fext),iostat=iostat)
+close(220,status='DELETE')
+open(222,file=trim(scrpath)//'DEVECFV'//trim(fext),iostat=iostat)
+close(222,status='DELETE')
+open(226,file=trim(scrpath)//'DEVECSV'//trim(fext),iostat=iostat)
+close(226,status='DELETE')
 return
 end subroutine
 
