@@ -6,16 +6,18 @@
 subroutine phscdelete
 use modmain
 implicit none
+! local variables
+integer iostat
 ! delete the eigenvector files
 call delevec
 ! delete the eigenvalue files
-open(70,file='EVALFV'//trim(filext))
-close(70,status='DELETE')
-open(70,file='EVALSV'//trim(filext))
-close(70,status='DELETE')
+open(120,file='EVALFV'//trim(filext),iostat=iostat)
+close(120,status='DELETE')
+open(124,file='EVALSV'//trim(filext),iostat=iostat)
+close(124,status='DELETE')
 ! delete the occupancy file
-open(70,file='OCCSV'//trim(filext))
-close(70,status='DELETE')
+open(130,file='OCCSV'//trim(filext),iostat=iostat)
+close(130,status='DELETE')
 return
 end subroutine
 
