@@ -25,13 +25,13 @@ call readstate
 ! write the potential plots to file
 select case(task)
 case(41)
-  open(50,file='VCL1D.OUT',action='WRITE',form='FORMATTED')
-  open(51,file='VLINES.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='VCL1D.OUT',form='FORMATTED')
+  open(51,file='VLINES.OUT',form='FORMATTED')
   call plot1d(50,51,1,vclmt,vclir)
   close(50)
   close(51)
-  open(50,file='VXC1D.OUT',action='WRITE',form='FORMATTED')
-  open(51,file='VLINES.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='VXC1D.OUT',form='FORMATTED')
+  open(51,file='VLINES.OUT',form='FORMATTED')
   call plot1d(50,51,1,vxcmt,vxcir)
   close(50)
   close(51)
@@ -41,10 +41,10 @@ case(41)
   write(*,'(" 1D exchange-correlation potential plot written to VXC1D.OUT")')
   write(*,'(" vertex location lines written to VLINES.OUT")')
 case(42)
-  open(50,file='VCL2D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='VCL2D.OUT',form='FORMATTED')
   call plot2d(50,1,vclmt,vclir)
   close(50)
-  open(50,file='VXC2D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='VXC2D.OUT',form='FORMATTED')
   call plot2d(50,1,vxcmt,vxcir)
   close(50)
   write(*,*)
@@ -52,10 +52,10 @@ case(42)
   write(*,'(" 2D Coulomb potential plot written to VCL2D.OUT")')
   write(*,'(" 2D exchange-correlation potential plot written to VXC2D.OUT")')
 case(43)
-  open(50,file='VCL3D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='VCL3D.OUT',form='FORMATTED')
   call plot3d(50,1,vclmt,vclir)
   close(50)
-  open(50,file='VXC3D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='VXC3D.OUT',form='FORMATTED')
   call plot3d(50,1,vxcmt,vxcir)
   close(50)
   write(*,*)
