@@ -14,12 +14,11 @@ real(8), intent(in) :: evalfv(nstfv,nspnfv)
 integer recl
 ! find the record length
 inquire(iolength=recl) vkl(:,ik),nstfv,nspnfv,evalfv
-!$OMP CRITICAL
-open(70,file='EVALFV'//trim(fext),action='WRITE',form='UNFORMATTED', &
- access='DIRECT',recl=recl)
-write(70,rec=ik) vkl(:,ik),nstfv,nspnfv,evalfv
-close(70)
-!$OMP END CRITICAL
+!$OMP CRITICAL(u120)
+open(120,file='EVALFV'//trim(fext),form='UNFORMATTED',access='DIRECT',recl=recl)
+write(120,rec=ik) vkl(:,ik),nstfv,nspnfv,evalfv
+close(120)
+!$OMP END CRITICAL(u120)
 return
 end subroutine
 
