@@ -24,14 +24,19 @@ implicit none
 ! arguments
 real(8), intent(in) :: eps
 real(8), intent(inout) :: v(3)
-! local variables
-integer i
-do i=1,3
-  v(i)=v(i)-int(v(i))
-  if (v(i).lt.0.d0) v(i)=v(i)+1.d0
-  if ((1.d0-v(i)).lt.eps) v(i)=0.d0
-  if (v(i).lt.eps) v(i)=0.d0
-end do
+v(1)=v(1)-int(v(1))
+if (v(1).lt.0.d0) v(1)=v(1)+1.d0
+if ((1.d0-v(1)).lt.eps) v(1)=0.d0
+if (v(1).lt.eps) v(1)=0.d0
+v(2)=v(2)-int(v(2))
+if (v(2).lt.0.d0) v(2)=v(2)+1.d0
+if ((1.d0-v(2)).lt.eps) v(2)=0.d0
+if (v(2).lt.eps) v(2)=0.d0
+v(3)=v(3)-int(v(3))
+if (v(3).lt.0.d0) v(3)=v(3)+1.d0
+if ((1.d0-v(3)).lt.eps) v(3)=0.d0
+if (v(3).lt.eps) v(3)=0.d0
 return
 end subroutine
 !EOC
+
