@@ -10,6 +10,7 @@ subroutine rdmdkdc
 ! !USES:
 use modmain
 use modrdm
+use modomp
 ! !DESCRIPTION:
 !   Calculates the derivative of kinetic energy w.r.t. the second-variational
 !   coefficients {\tt evecsv}.
@@ -19,11 +20,14 @@ use modrdm
 !EOP
 !BOC
 implicit none
+! local variables
+integer ik,nthd
 ! allocatable arrays
 complex(8), allocatable :: evecsv(:,:),kmat(:,:)
-integer ik
+call omp_hold(nkpt,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(evecsv,kmat)
+!$OMP PRIVATE(evecsv,kmat) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ik=1,nkpt
   allocate(evecsv(nstsv,nstsv),kmat(nstsv,nstsv))
@@ -35,6 +39,8 @@ do ik=1,nkpt
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 return
 end subroutine
 !EOC
+
