@@ -22,9 +22,9 @@ use modtest
 !BOC
 implicit none
 ! local variables
-integer ik,ist,is,ia,ias
+integer ik,ist,is,ias
 integer nr,nri,ir,i
-real(8) vn,t1
+real(8) t1
 complex(8) z1
 ! allocatable arrays
 real(8), allocatable :: rfmt(:)
@@ -44,9 +44,9 @@ do ias=1,natmtot
   i=1
   do ir=1,nr
     if (spincore) then
-      rfmt(i)=(rhocr(ir,ias,1)+rhocr(ir,ias,2))/y00
+      rfmt(i)=rhocr(ir,ias,1)+rhocr(ir,ias,2)
     else
-      rfmt(i)=rhocr(ir,ias,1)/y00
+      rfmt(i)=rhocr(ir,ias,1)
     end if
     if (ir.le.nri) then
       i=i+lmmaxi
@@ -73,13 +73,9 @@ end do
 deallocate(evecsv)
 ! Madelung term
 engymad=0.d0
-do is=1,nspecies
-! compute the bare nucleus potential at the origin
-  call potnucl(ptnucl,1,rsp(:,is),spzn(is),vn)
-  do ia=1,natoms(is)
-    ias=idxas(ia,is)
-    engymad=engymad+0.5d0*spzn(is)*(vclmt(1,ias)*y00-vn)
-  end do
+do ias=1,natmtot
+  is=idxis(ias)
+  engymad=engymad+0.5d0*spzn(is)*(vclmt(1,ias)-vcln(1,is))*y00
 end do
 ! exchange-correlation energy
 call rdmengyxc
@@ -94,3 +90,4 @@ call writetest(300,'RDMFT total energy',tol=1.d-6,rv=engytot)
 return
 end subroutine
 !EOC
+
