@@ -13,7 +13,7 @@ real(8), intent(out) :: gq(nbph,nqpt)
 integer iq,i
 integer natmtot_,nqpt_,iq_,i_
 real(8) vql_(3),vqc_(3),t1
-open(50,file='GAMMAQ.OUT',action='READ',form='FORMATTED',status='OLD')
+open(50,file='GAMMAQ.OUT',form='FORMATTED',status='OLD')
 read(50,*)
 read(50,*) natmtot_
 if (natmtot.ne.natmtot_) then
