@@ -5,12 +5,13 @@
 
 real(8) function rfinpc(ld,rfmt1,rfir1,rfmt2,rfir2)
 use modmain
+use modomp
 implicit none
 integer, intent(in) :: ld
 real(8), intent(in) :: rfmt1(ld,natmtot),rfir1(ngtot)
 real(8), intent(in) :: rfmt2(ld,natmtot),rfir2(ngtot)
 ! local variables
-integer is,ias,ir
+integer is,ias,ir,nthd
 real(8) sum
 ! external functions
 real(8) rfmtinp
@@ -22,7 +23,10 @@ do ir=1,ngtot
 end do
 sum=sum*omega/dble(ngtot)
 ! muffin-tin contribution
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is) REDUCTION(+:sum)
+call omp_hold(natmtot,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(is) REDUCTION(+:sum) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
@@ -31,6 +35,7 @@ do ias=1,natmtot
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 rfinpc=sum
 return
 end function
