@@ -9,17 +9,17 @@ implicit none
 ! arguments
 real(8), intent(in) :: rfmt(npmtmax,natmtot),rfir(ngtot)
 ! local variables
-integer is,ias
-integer nr,nri,ir,i
-real(8) sum,t1
+integer is,ias,i
+integer nr,nri,ir
+real(8) t1
 ! automatic arrays
 real(8) fr(nrmtmax)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 ! interstitial contribution
-sum=dot_product(rfir(:),cfunir(:))
-sum=sum*omega/dble(ngtot)
+rfint=dot_product(rfir(:),cfunir(:))
+rfint=rfint*omega/dble(ngtot)
 ! muffin-tin contribution
 do ias=1,natmtot
   is=idxis(ias)
@@ -34,10 +34,9 @@ do ias=1,natmtot
     fr(ir)=rfmt(i,ias)*r2sp(ir,is)
     i=i+lmmaxo
   end do
-  t1=fintgt(-1,nr,rsp(:,is),fr)
-  sum=sum+fourpi*y00*t1
+  t1=splint(nr,rsp(:,is),fr)
+  rfint=rfint+fourpi*y00*t1
 end do
-rfint=sum
 return
 end function
 
