@@ -9,6 +9,7 @@
 subroutine rhoinit
 ! !USES:
 use modmain
+use modomp
 ! !DESCRIPTION:
 !   Initialises the crystal charge density. Inside the muffin-tins it is set to
 !   the spherical atomic density. In the interstitial region it is taken to be
@@ -22,31 +23,29 @@ use modmain
 implicit none
 ! local variables
 integer lmax,is,ia,ias
-integer nr,nri,nro,ir
+integer nr,nri,nro,ir,i
 integer nrc,nrci,irco,irc
-integer l,m,lm,ig,ifg,i
+integer l,m,lm,ig,ifg,nthd
 real(8) x,t1,t2
 complex(8) z1,z2,z3
 ! allocatable arrays
 real(8), allocatable :: jl(:,:),ffg(:),fr(:)
 complex(8), allocatable :: zfmt(:),zfft(:)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 lmax=min(lmaxi,1)
-! zero the charge density and magnetisation arrays
+! zero the charge density arrays
 rhomt(:,:)=0.d0
 rhoir(:)=0.d0
-if (spinpol) then
-  magmt(:,:,:)=0.d0
-  magir(:,:)=0.d0
-end if
 ! compute the superposition of all the atomic density tails
 allocate(zfft(ngtot))
 zfft(:)=0.d0
+call omp_hold(nspecies,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(ffg,fr,nr,nro,ig) &
-!$OMP PRIVATE(ir,x,t1,ia,ias,ifg)
+!$OMP PRIVATE(ffg,fr,nr,nro,ig,ir) &
+!$OMP PRIVATE(x,t1,ia,ias,ifg) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do is=1,nspecies
   allocate(ffg(ngvec),fr(nrspmax))
@@ -63,27 +62,32 @@ do is=1,nspecies
       end if
       fr(ir)=t1*rhosp(ir,is)*r2sp(ir,is)
     end do
-    t1=fintgt(-1,nro,rsp(nr,is),fr(nr))
+    t1=splint(nro,rsp(nr,is),fr(nr))
+! apply low-pass filter
+    t1=t1*exp(-4.d0*(gc(ig)/gmaxvr)**2)
     ffg(ig)=(fourpi/omega)*t1
   end do
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-!$OMP CRITICAL
+!$OMP CRITICAL(rhoinit_)
     do ig=1,ngvec
       ifg=igfft(ig)
       zfft(ifg)=zfft(ifg)+ffg(ig)*conjg(sfacg(ig,ias))
     end do
-!$OMP END CRITICAL
+!$OMP END CRITICAL(rhoinit_)
   end do
   deallocate(fr,ffg)
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 ! compute the tails in each muffin-tin
+call omp_hold(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(jl,zfmt,is,nrc,nrci) &
 !$OMP PRIVATE(irco,ig,ifg,irc,x) &
-!$OMP PRIVATE(z1,z2,z3,lm,l,m,i)
+!$OMP PRIVATE(z1,z2,z3,lm,l,m,i) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   allocate(jl(0:lmax,nrcmtmax),zfmt(npcmtmax))
@@ -122,6 +126,7 @@ do ias=1,natmtot
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+call omp_free(nthd)
 ! convert the density from a coarse to a fine radial mesh
 call rfmtctof(rhomt)
 ! add the atomic charge density and the excess charge in each muffin-tin
@@ -146,6 +151,8 @@ end do
 call zfftifc(3,ngridg,1,zfft)
 do ir=1,ngtot
   rhoir(ir)=dble(zfft(ir))+t1
+! make sure that the density is always positive
+  if (rhoir(ir).lt.1.d-10) rhoir(ir)=1.d-10
 end do
 deallocate(zfft)
 return
