@@ -9,6 +9,7 @@
 subroutine rhomagsh
 ! !USES:
 use modmain
+use modomp
 ! !DESCRIPTION:
 !   Converts the muffin-tin density and magnetisation from spherical coordinates
 !   to a spherical harmonic expansion. See {\tt rhomagk}.
@@ -21,29 +22,35 @@ implicit none
 ! local variables
 integer idm,is,ias
 integer nrc,nrci,npc
+integer nthd,ithd
 ! allocatable arrays
-real(8), allocatable :: rfmt(:)
+real(8), allocatable :: rfmt(:,:)
+call omp_hold(natmtot,nthd)
+allocate(rfmt(npcmtmax,0:nthd-1))
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt,is,nrc,nrci,npc,idm)
+!$OMP PRIVATE(ithd,is,nrc) &
+!$OMP PRIVATE(nrci,npc,idm) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
-  allocate(rfmt(npcmtmax))
+  ithd=omp_get_thread_num()
   is=idxis(ias)
   nrc=nrcmt(is)
   nrci=nrcmti(is)
   npc=npcmt(is)
 ! convert the density to spherical harmonics
-  rfmt(1:npc)=rhomt(1:npc,ias)
-  call rfsht(nrc,nrci,rfmt,rhomt(:,ias))
+  call dcopy(npc,rhomt(:,ias),1,rfmt(:,ithd),1)
+  call rfsht(nrc,nrci,rfmt(:,ithd),rhomt(:,ias))
 ! convert magnetisation to spherical harmonics
   do idm=1,ndmag
-    rfmt(1:npc)=magmt(1:npc,ias,idm)
-    call rfsht(nrc,nrci,rfmt,magmt(:,ias,idm))
+    call dcopy(npc,magmt(:,ias,idm),1,rfmt(:,ithd),1)
+    call rfsht(nrc,nrci,rfmt(:,ithd),magmt(:,ias,idm))
   end do
-  deallocate(rfmt)
 end do
 !$OMP END DO
 !$OMP END PARALLEL
+deallocate(rfmt)
+call omp_free(nthd)
 return
 end subroutine
 !EOC
