@@ -25,8 +25,8 @@ call readstate
 ! write the density plot to file
 select case(task)
 case(31)
-  open(50,file='RHO1D.OUT',action='WRITE',form='FORMATTED')
-  open(51,file='RHOLINES.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='RHO1D.OUT',form='FORMATTED')
+  open(51,file='RHOLINES.OUT',form='FORMATTED')
   call plot1d(50,51,1,rhomt,rhoir)
   close(50)
   close(51)
@@ -35,13 +35,13 @@ case(31)
   write(*,'(" 1D density plot written to RHO1D.OUT")')
   write(*,'(" vertex location lines written to RHOLINES.OUT")')
 case(32)
-  open(50,file='RHO2D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='RHO2D.OUT',form='FORMATTED')
   call plot2d(50,1,rhomt,rhoir)
   close(50)
   write(*,*)
   write(*,'("Info(rhoplot): 2D density plot written to RHO2D.OUT")')
 case(33)
-  open(50,file='RHO3D.OUT',action='WRITE',form='FORMATTED')
+  open(50,file='RHO3D.OUT',form='FORMATTED')
   call plot3d(50,1,rhomt,rhoir)
   close(50)
   write(*,*)
