@@ -46,33 +46,30 @@ implicit none
 ! arguments
 integer, intent(in) :: p
 real(8), intent(in) :: ang(3)
-integer, intent(in) :: lmax
-integer, intent(in) :: ld
+integer, intent(in) :: lmax,ld
 real(8), intent(out) :: d(ld,*)
 ! local variables
-integer lmmax,l,m1,m2,lm,lm0
+integer l,m1,m2,lm,lm0
 real(8), parameter :: sqtwo=1.4142135623730950488d0
 real(8) s1,s2,t1,t2,t3,t4,t5,t6,t7,t8
 ! automatic arrays
 integer lmi(-lmax:lmax)
 real(8) ca(lmax),sa(lmax),cg(lmax),sg(lmax)
-! allocatable arrays
-real(8), allocatable :: dy(:,:)
+! automatic arrays
+real(8) dy(ld,ld)
 if (lmax.lt.0) then
   write(*,*)
   write(*,'("Error(rlmrot): lmax < 0 : ",I8)') lmax
   write(*,*)
   stop
 end if
-lmmax=(lmax+1)**2
-allocate(dy(lmmax,lmmax))
 ! generate the complex spherical harmonic rotation matrix about the y-axis
-call ylmroty(ang(2),lmax,lmmax,dy)
+call ylmroty(ang(2),lmax,ld,dy)
 do m1=1,lmax
-  ca(m1)=cos(dble(m1)*ang(1))
-  sa(m1)=sin(dble(m1)*ang(1))
-  cg(m1)=cos(dble(m1)*ang(3))
-  sg(m1)=sin(dble(m1)*ang(3))
+  ca(m1)=cos(m1*ang(1))
+  sa(m1)=sin(m1*ang(1))
+  cg(m1)=cos(m1*ang(3))
+  sg(m1)=sin(m1*ang(3))
 end do
 lm=0
 do l=0,lmax
@@ -116,7 +113,6 @@ do l=0,lmax
     end do
   end if
 end do
-deallocate(dy)
 return
 end subroutine
 !EOC
