@@ -5,33 +5,36 @@
 
 complex(8) function rzfinp(rfmt,rfir,zfmt,zfir)
 use modmain
+use modomp
 implicit none
 ! arguments
 real(8), intent(in) :: rfmt(npcmtmax,natmtot),rfir(ngtot)
 complex(8), intent(in) :: zfmt(npcmtmax,natmtot),zfir(ngtot)
 ! local variables
-integer ias,is,ir
-complex(8) zsum
+integer is,ias,ir,nthd
 ! external functions
 complex(8) rzfmtinp
 external rzfmtinp
-zsum=0.d0
 ! interstitial contribution
-do ir=1,ngtot
-  zsum=zsum+(cfunir(ir)*rfir(ir))*zfir(ir)
+rzfinp=(cfunir(1)*rfir(1))*zfir(1)
+do ir=2,ngtot
+  rzfinp=rzfinp+(cfunir(ir)*rfir(ir))*zfir(ir)
 end do
-zsum=zsum*(omega/dble(ngtot))
+rzfinp=rzfinp*(omega/dble(ngtot))
 ! muffin-tin contribution
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is) REDUCTION(+:zsum)
+call omp_hold(natmtot,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(is) REDUCTION(+:rzfinp) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
-  zsum=zsum+rzfmtinp(nrcmt(is),nrcmti(is),rcmt(:,is),r2cmt(:,is),rfmt(:,ias), &
-   zfmt(:,ias))
+  rzfinp=rzfinp+rzfmtinp(nrcmt(is),nrcmti(is),rcmt(:,is),r2cmt(:,is), &
+   rfmt(:,ias),zfmt(:,ias))
 end do
 !$OMP END DO
 !$OMP END PARALLEL
-rzfinp=zsum
+call omp_free(nthd)
 return
 end function
 
