@@ -12,34 +12,33 @@ real(8), intent(in) :: r(nr),r2(nr)
 real(8), intent(in) :: rfmt(*)
 complex(8), intent(in) :: zfmt(*)
 ! local variables
-integer ir,i0,i1
-real(8) a,b,t1
+integer n,ir,i
+real(8) t1
 complex(8) z1
 ! automatic arrays
 real(8) fr1(nr),fr2(nr)
 ! external functions
-real(8) fintgt
-external fintgt
-i1=0
+real(8) splint
+external splint
+n=lmmaxi-1
+i=1
 do ir=1,nri
-  i0=i1+1
-  i1=i1+lmmaxi
-  z1=dot_product(rfmt(i0:i1),zfmt(i0:i1))*r2(ir)
+  z1=dot_product(rfmt(i:i+n),zfmt(i:i+n))*r2(ir)
   fr1(ir)=dble(z1)
   fr2(ir)=aimag(z1)
+  i=i+lmmaxi
 end do
 t1=dble(lmmaxi)/dble(lmmaxo)
+n=lmmaxo-1
 do ir=nri+1,nr
-  i0=i1+1
-  i1=i1+lmmaxo
-  z1=dot_product(rfmt(i0:i1),zfmt(i0:i1))*(t1*r2(ir))
+  z1=dot_product(rfmt(i:i+n),zfmt(i:i+n))*(t1*r2(ir))
   fr1(ir)=dble(z1)
   fr2(ir)=aimag(z1)
+  i=i+lmmaxo
 end do
-! integrate
-a=fintgt(-1,nr,r,fr1)
-b=fintgt(-1,nr,r,fr2)
-rzfmtinp=(fourpi/dble(lmmaxi))*cmplx(a,b,8)
+! integrate over r
+t1=fourpi/dble(lmmaxi)
+rzfmtinp=t1*cmplx(splint(nr,r,fr1),splint(nr,r,fr2),8)
 return
 end function
 
