@@ -14,7 +14,7 @@ integer is,ias
 ! allocatable arrays
 complex(8), allocatable :: zfmt(:,:,:)
 allocate(zfmt(lmmaxo,nrmtmax,natmtot))
-open(50,file='DVS'//trim(fext),action='WRITE',form='UNFORMATTED')
+open(50,file='DVS'//trim(fext),form='UNFORMATTED')
 write(50) version
 write(50) nspecies
 write(50) lmmaxo
