@@ -34,13 +34,21 @@ real(8) efg(3,3),a(3,3)
 real(8) w(3),work(lwork)
 ! allocatable arrays
 real(8), allocatable :: rfmt(:),grfmt1(:,:),grfmt2(:,:)
+if (lmaxi.lt.2) then
+  write(*,*)
+  write(*,'("Error(writeefg): lmaxi too small for calculating the EFG : ",&
+   &I4)') lmaxi
+  write(*,'(" Run the ground-state calculation again with lmaxi >= 2")')
+  write(*,*)
+  stop
+end if
 ! initialise universal variables
 call init0
 ! read density and potentials from file
 call readstate
 ! allocate local arrays
 allocate(rfmt(npmtmax),grfmt1(npmtmax,3),grfmt2(npmtmax,3))
-open(50,file='EFG.OUT',action='WRITE',form='FORMATTED')
+open(50,file='EFG.OUT',form='FORMATTED')
 write(50,*)
 write(50,'("(electric field gradient tensor is in Cartesian coordinates)")')
 do is=1,nspecies
