@@ -5,9 +5,10 @@
 
 subroutine writeevbse
 use modmain
+use modomp
 implicit none
 ! local variables
-integer ik,a
+integer ik,a,nthd
 integer iostat,nmbse_
 integer lwork,info
 ! allocatable arrays
@@ -31,8 +32,7 @@ allocate(evalbse(nmbse))
 if (allocated(hmlbse)) deallocate(hmlbse)
 allocate(hmlbse(nmbse,nmbse))
 ! read in BSE Hamiltonian matrix
-open(50,file='HMLBSE.OUT',action='READ',form='UNFORMATTED',status='OLD', &
- iostat=iostat)
+open(50,file='HMLBSE.OUT',form='UNFORMATTED',status='OLD',iostat=iostat)
 if (iostat.ne.0) then
   write(*,*)
   write(*,'("Error(writeevbse): error opening HMLBSE.OUT")')
@@ -58,7 +58,12 @@ if (bsefull) then
   allocate(vl(1,1),vr(nmbse,nmbse))
   lwork=2*nmbse
   allocate(rwork(lwork),work(lwork))
+! enable MKL parallelism
+  call omp_hold(maxthd,nthd)
+  call mkl_set_num_threads(nthd)
   call zgeev('N','V',nmbse,hmlbse,nmbse,w,vl,1,vr,nmbse,work,lwork,rwork,info)
+  call omp_free(nthd)
+  call mkl_set_num_threads(1)
   if (info.ne.0) then
     write(*,*)
     write(*,'("Error(writeevbse): diagonalisation failed")')
@@ -71,27 +76,16 @@ if (bsefull) then
   deallocate(vl,vr,rwork,work)
 else
 ! Hermitian block only
-  allocate(rwork(3*nmbse))
-  lwork=2*nmbse
-  allocate(work(lwork))
-  call zheev('V','U',nmbse,hmlbse,nmbse,evalbse,work,lwork,rwork,info)
-  if (info.ne.0) then
-    write(*,*)
-    write(*,'("Error(writeevbse): diagonalisation failed")')
-    write(*,'(" ZHEEV returned INFO = ",I8)') info
-    write(*,*)
-    stop
-  end if
-  deallocate(rwork,work)
+  call eveqnz(nmbse,nmbse,hmlbse,evalbse)
 end if
 ! write the BSE eigenvectors and eigenvalues to file
-open(50,file='EVBSE.OUT',action='WRITE',form='UNFORMATTED')
+open(50,file='EVBSE.OUT',form='UNFORMATTED')
 write(50) nmbse
 write(50) evalbse
 write(50) hmlbse
 close(50)
 ! write the BSE eigenvalues to file
-open(50,file='EIGVAL_BSE.OUT',action='WRITE',form='FORMATTED')
+open(50,file='EIGVAL_BSE.OUT',form='FORMATTED')
 write(50,'(I6," : nmbse")') nmbse
 if (bsefull) then
   do a=1,nmbse
