@@ -8,9 +8,9 @@
 ! !INTERFACE:
 subroutine z2mctm(a,b,c)
 ! !INPUT/OUTPUT PARAMETERS:
-!   a   : input matrix 1 (in,complex(2,2))
-!   b   : input matrix 2 (in,complex(2,2))
-!   c   : output matrix (out,complex(2,2))
+!   a : input matrix 1 (in,complex(2,2))
+!   b : input matrix 2 (in,complex(2,2))
+!   c : output matrix (out,complex(2,2))
 ! !DESCRIPTION:
 !   Multiplies the conjugate transpose of one complex $2\times 2$ matrix with
 !   another. Note that the output matrix cannot be one of the input matrices.
@@ -21,15 +21,13 @@ subroutine z2mctm(a,b,c)
 !BOC
 implicit none
 ! arguments
-complex(8), intent(in) :: a(2,2)
-complex(8), intent(in) :: b(2,2)
+complex(8), intent(in) :: a(2,2),b(2,2)
 complex(8), intent(out) :: c(2,2)
 c(1,1)=conjg(a(1,1))*b(1,1)+conjg(a(2,1))*b(2,1)
-c(1,2)=conjg(a(1,1))*b(1,2)+conjg(a(2,1))*b(2,2)
 c(2,1)=conjg(a(1,2))*b(1,1)+conjg(a(2,2))*b(2,1)
+c(1,2)=conjg(a(1,1))*b(1,2)+conjg(a(2,1))*b(2,2)
 c(2,2)=conjg(a(1,2))*b(1,2)+conjg(a(2,2))*b(2,2)
 return
 end subroutine
 !EOC
 
-
