@@ -10,22 +10,19 @@ integer, intent(in) :: nd,n(nd),sgn
 complex(8), intent(inout) :: z(*)
 ! local variables
 integer, parameter :: FFTW_ESTIMATE=64
-integer i,p
+integer p
 integer(8) plan
 real(8) t1
 ! interface to FFTW version 3
-!$OMP CRITICAL
+!$OMP CRITICAL(zfftifc_)
 call dfftw_plan_dft(plan,nd,n,z,z,sgn,FFTW_ESTIMATE)
-!$OMP END CRITICAL
+!$OMP END CRITICAL(zfftifc_)
 call dfftw_execute(plan)
-!$OMP CRITICAL
+!$OMP CRITICAL(zfftifc_)
 call dfftw_destroy_plan(plan)
-!$OMP END CRITICAL
+!$OMP END CRITICAL(zfftifc_)
 if (sgn.eq.-1) then
-  p=1
-  do i=1,nd
-    p=p*n(i)
-  end do
+  p=product(n(:))
   t1=1.d0/dble(p)
   call zdscal(p,t1,z,1)
 end if
