@@ -9,15 +9,16 @@
 complex(8) function zfinp(zfmt1,zfir1,zfmt2,zfir2)
 ! !USES:
 use modmain
+use modomp
 ! !INPUT/OUTPUT PARAMETERS:
 !   zfmt1 : first complex function in spherical harmonics/coordinates for all
 !           muffin-tins (in,complex(npcmtmax,natmtot))
 !   zfir1 : first complex interstitial function in real-space
-!           (in,complex(ngtot))
+!           (in,complex(ngtc))
 !   zfmt2 : second complex function in spherical harmonics/coordinates for all
 !           muffin-tins (in,complex(npcmtmax,natmtot))
 !   zfir2 : second complex interstitial function in real-space
-!           (in,complex(ngtot))
+!           (in,complex(ngtc))
 ! !DESCRIPTION:
 !   Calculates the inner product of two complex fuctions over the entire unit
 !   cell. The muffin-tin functions should be stored on the coarse radial grid.
@@ -31,31 +32,33 @@ use modmain
 !BOC
 implicit none
 ! arguments
-complex(8), intent(in) :: zfmt1(npcmtmax,natmtot),zfir1(ngtot)
-complex(8), intent(in) :: zfmt2(npcmtmax,natmtot),zfir2(ngtot)
+complex(8), intent(in) :: zfmt1(npcmtmax,natmtot),zfir1(ngtc)
+complex(8), intent(in) :: zfmt2(npcmtmax,natmtot),zfir2(ngtc)
 ! local variables
-integer ias,is,ir
-complex(8) zsum
+integer is,ias,ir,nthd
 ! external functions
 complex(8) zfmtinp
 external zfmtinp
-zsum=0.d0
 ! interstitial contribution
-do ir=1,ngtot
-  zsum=zsum+cfunir(ir)*conjg(zfir1(ir))*zfir2(ir)
+zfinp=cfrc(1)*conjg(zfir1(1))*zfir2(1)
+do ir=2,ngtc
+  zfinp=zfinp+cfrc(ir)*conjg(zfir1(ir))*zfir2(ir)
 end do
-zsum=zsum*(omega/dble(ngtot))
+zfinp=zfinp*(omega/dble(ngtc))
 ! muffin-tin contribution
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is) REDUCTION(+:zsum)
+call omp_hold(natmtot,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(is) REDUCTION(+:zfinp) &
+!$OMP NUM_THREADS(nthd)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
-  zsum=zsum+zfmtinp(nrcmt(is),nrcmti(is),rcmt(:,is),r2cmt(:,is),zfmt1(:,ias), &
-   zfmt2(:,ias))
+  zfinp=zfinp+zfmtinp(nrcmt(is),nrcmti(is),rcmt(:,is),r2cmt(:,is), &
+   zfmt1(:,ias),zfmt2(:,ias))
 end do
 !$OMP END DO
 !$OMP END PARALLEL
-zfinp=zsum
+call omp_free(nthd)
 return
 end function
 !EOC
