@@ -38,33 +38,42 @@ integer, intent(in) :: nr,nri
 real(8), intent(in) :: r(nr),r2(nr)
 complex(8), intent(in) :: zfmt1(*),zfmt2(*)
 ! local variables
-integer ir,i0,i1
-real(8) a,b
+integer ir,i
 complex(8) z1
 ! automatic arrays
 real(8) fr1(nr),fr2(nr)
 ! external functions
-real(8) fintgt
-external fintgt
-i1=0
-do ir=1,nri
-  i0=i1+1
-  i1=i1+lmmaxi
-  z1=dot_product(zfmt1(i0:i1),zfmt2(i0:i1))*r2(ir)
-  fr1(ir)=dble(z1)
-  fr2(ir)=aimag(z1)
-end do
+real(8) splint
+complex(8) zdotc
+external splint,zdotc
+! compute the dot-products for each radial point
+i=1
+if (lmaxi.eq.1) then
+  do ir=1,nri
+    z1=(conjg(zfmt1(i))*zfmt2(i) &
+       +conjg(zfmt1(i+1))*zfmt2(i+1) &
+       +conjg(zfmt1(i+2))*zfmt2(i+2) &
+       +conjg(zfmt1(i+3))*zfmt2(i+3))*r2(ir)
+    fr1(ir)=dble(z1)
+    fr2(ir)=aimag(z1)
+    i=i+4
+  end do
+else
+  do ir=1,nri
+    z1=zdotc(lmmaxi,zfmt1(i),1,zfmt2(i),1)*r2(ir)
+    fr1(ir)=dble(z1)
+    fr2(ir)=aimag(z1)
+    i=i+lmmaxi
+  end do
+end if
 do ir=nri+1,nr
-  i0=i1+1
-  i1=i1+lmmaxo
-  z1=dot_product(zfmt1(i0:i1),zfmt2(i0:i1))*r2(ir)
+  z1=zdotc(lmmaxo,zfmt1(i),1,zfmt2(i),1)*r2(ir)
   fr1(ir)=dble(z1)
   fr2(ir)=aimag(z1)
+  i=i+lmmaxo
 end do
-! integrate
-a=fintgt(-1,nr,r,fr1)
-b=fintgt(-1,nr,r,fr2)
-zfmtinp=cmplx(a,b,8)
+! integrate over r
+zfmtinp=cmplx(splint(nr,r,fr1),splint(nr,r,fr2),8)
 return
 end function
 !EOC
