@@ -55,8 +55,8 @@ complex(8) ylm(lmmaxo)
 ! allocatable arrays
 complex(8), allocatable :: zfft(:),zfmt(:,:)
 ! external functions
-real(8) fintgt
-external fintgt
+real(8) splint
+external splint
 allocate(zfft(ngtot),zfmt(npcmtmax,natmtot))
 ! zero the coefficients
 zfp(:)=0.d0
@@ -180,8 +180,8 @@ do ip=1,npv
         fr2(irc)=aimag(zsum1)
         if (irc.eq.nrci) lmax=lmaxo
       end do
-      t1=fintgt(-1,nrc,rcmt(:,is),fr1)
-      t2=fintgt(-1,nrc,rcmt(:,is),fr2)
+      t1=splint(nrc,rcmt(:,is),fr1)
+      t2=splint(nrc,rcmt(:,is),fr2)
 ! conjugate structure factor
       t3=-dot_product(vpc(:,ip),atposc(:,ia,is))
       z1=t0*cmplx(cos(t3),sin(t3),8)
