@@ -80,10 +80,10 @@ do l=0,lmaxi
       f3(ir)=t1*r4(ir); f4(ir)=t2*r4(ir)
       i=i+lmmaxo
     end do
-    call fderiv(-1,nr,r,f1,f5)
-    call fderiv(-1,nr,r,f2,f1)
-    call fderiv(-1,nr,r,f3,f2)
-    call fderiv(-1,nr,r,f4,f3)
+    call splintp(nr,r,f1,f5)
+    call splintp(nr,r,f2,f1)
+    call splintp(nr,r,f3,f2)
+    call splintp(nr,r,f4,f3)
     t1=f2(nr); t2=f3(nr)
     i=lm
     do ir=1,nri
@@ -118,10 +118,10 @@ do l=lmaxi+1,lmaxo
       f3(ir)=t1*r4(ir); f4(ir)=t2*r4(ir)
       i=i+lmmaxo
     end do
-    call fderiv(-1,nro,r(iro),f1(iro),f5(iro))
-    call fderiv(-1,nro,r(iro),f2(iro),f1(iro))
-    call fderiv(-1,nro,r(iro),f3(iro),f2(iro))
-    call fderiv(-1,nro,r(iro),f4(iro),f3(iro))
+    call splintp(nro,r(iro),f1(iro),f5(iro))
+    call splintp(nro,r(iro),f2(iro),f1(iro))
+    call splintp(nro,r(iro),f3(iro),f2(iro))
+    call splintp(nro,r(iro),f4(iro),f3(iro))
     t1=f2(nr); t2=f3(nr)
     i=npi+lm
     do ir=iro,nr
